(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    195429,       4864]
NotebookOptionsPosition[    186822,       4720]
NotebookOutlinePosition[    187344,       4740]
CellTagsIndexPosition[    187301,       4737]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Differential equations for displacement correction \[ScriptZ]", "Title",
 CellChangeTimes->{{3.877579626855694*^9, 3.8775796534559593`*^9}, 
   3.87757974502632*^9, {3.8775808560112267`*^9, 3.8775808697724543`*^9}, {
   3.877586096009865*^9, 3.87758611049076*^9}, {3.877586252278063*^9, 
   3.8775862527354317`*^9}, {3.877586389819551*^9, 3.8775863927720537`*^9}, {
   3.877586423665546*^9, 
   3.87758643139788*^9}},ExpressionUUID->"454d7575-22f2-4c20-befb-\
6f73f7b89361"],

Cell["\<\
Supplementary material for \[OpenCurlyDoubleQuote]Asymptotic derivation of a \
higher-order one-dimensional model for tape springs; Arun Kumar, Basile \
Audoly, Claire Lestringant\[CloseCurlyDoubleQuote]\
\>", "Subtitle",
 CellChangeTimes->{{3.8775864731831017`*^9, 3.877586497494802*^9}, {
  3.877586540646413*^9, 
  3.8775865421323633`*^9}},ExpressionUUID->"4339e4dd-4963-4ec2-80d7-\
e3d53dd8024f"],

Cell[BoxData[
 RowBox[{"(*", " ", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
   "We", " ", "derive", " ", "the", " ", "differential", " ", "equations", 
    " ", "for", " ", "displacement", " ", "correction", " ", "z", " ", "in", 
    " ", "this", " ", 
    RowBox[{"file", ".", " ", "We"}], " ", "take", " ", "the", " ", "energy", 
    " ", "expressions", " ", "given", " ", "in", " ", "section", " ", "5", 
    RowBox[{"(", "c", ")"}]}], ",", 
   RowBox[{
   "calculate", " ", "the", " ", "potential", " ", "and", " ", "take", " ", 
    "its", " ", "variations", " ", "to", " ", "get", " ", "the", " ", 
    "differential", " ", "equations", " ", "for", " ", "zv"}], ",", " ", 
   RowBox[{"zu", " ", "and", " ", 
    RowBox[{"zw", ".", " ", "Specifically"}]}], ",", " ", 
   RowBox[{
    RowBox[{
    "we", " ", "get", " ", "the", " ", "first", " ", "order", " ", 
     "differential", " ", "equations", " ", "for", " ", "zv", " ", "and", " ",
      "zu", " ", "which", " ", "can", " ", "be", " ", "written", " ", 
     RowBox[{"as", ":", "\[IndentingNewLine]", " ", 
      SubscriptBox["zv", 
       RowBox[{",", "T"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["zv", 
       RowBox[{",", "T"}]], 
      RowBox[{"(", 
       RowBox[{"T", ",", " ", 
        SubscriptBox["\[Kappa]", "i"], ",", " ", 
        RowBox[{
         SubscriptBox["\[Kappa]", "i"], "\[Dagger]"}], ",", " ", "zw", ",", 
        " ", 
        SubscriptBox["zw", 
         RowBox[{",", "T"}]]}], ")"}], " ", "and", " ", 
      SubscriptBox["zu", 
       RowBox[{",", "T", " "}]]}], "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["zu", 
        RowBox[{",", "T"}]], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"T", ",", " ", 
          SubscriptBox["\[Kappa]", "i"], ",", " ", 
          RowBox[{
           SubscriptBox["\[Kappa]", "i"], "\[Dagger]"}], ",", " ", "zw", ",", 
          " ", 
          SubscriptBox["zw", 
           RowBox[{",", "T"}]]}], ")"}], ".", " ", "\[IndentingNewLine]", " ",
         "We"}], " ", "employ", " ", "these", " ", "equations", " ", "to", 
       " ", "obtain", " ", "the", " ", "fourth", " ", "order", " ", 
       "differential", " ", "equation", " ", "for", " ", 
       RowBox[{"zw", ":", "\[IndentingNewLine]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"zw", "''''"}], "[", "T", "]"}], " ", "+", " ", 
         RowBox[{"coefzw", " ", 
          RowBox[{"zw", "[", "T", "]"}]}]}]}]}], " ", "=", " ", 
      RowBox[{
       RowBox[{"nonHomzw", "[", "T", "]"}], " ", "+", " ", 
       FractionBox["fN", "Db"], " ", "+", " ", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{"T", " ", "gN"}], "Db"], ".", "\[IndentingNewLine]", 
         "The"}], " ", "differential", " ", "equations", " ", "are", " ", 
        "not", " ", "included", " ", "in", " ", "the", " ", 
        RowBox[{"paper", ".", " ", "They"}], " ", "can", " ", "be", " ", 
        "exported", " ", "from", " ", "the", " ", "current", " ", 
        "mathematica", " ", "file"}]}]}]}]}], ",", " ", 
   RowBox[{"e", ".", "g", "."}], ",", " ", 
   RowBox[{
   "to", " ", "verify", " ", "a", " ", "numerical", " ", "implementation", 
    " ", "of", " ", "our", " ", "1", "D", " ", 
    RowBox[{"model", "."}]}]}], "\[IndentingNewLine]", "*)"}]], "Input",
 CellChangeTimes->{{3.8775805325770817`*^9, 3.877580534529344*^9}, {
   3.877582298290193*^9, 3.877582302471785*^9}, {3.877582914668853*^9, 
   3.877582917057206*^9}, {3.877583850426365*^9, 3.87758386641551*^9}, {
   3.877584091549672*^9, 3.877584112537434*^9}, 3.877586451720078*^9, 
   3.877586495252919*^9, {3.877587569636963*^9, 3.877587640967347*^9}, {
   3.877587675893759*^9, 3.87758797868635*^9}, {3.877592155605489*^9, 
   3.877592244568149*^9}, {3.8775952356215982`*^9, 3.877595274721583*^9}, {
   3.8775982296337757`*^9, 3.877598394851027*^9}, {3.877598582234289*^9, 
   3.877598615486472*^9}, {3.877601628509066*^9, 3.877601641840103*^9}, {
   3.877602750484775*^9, 3.8776027688971033`*^9}, {3.877670777689021*^9, 
   3.877670804708497*^9}, {3.8786364320283203`*^9, 3.878636433301652*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"5376c61e-4e9a-433c-ac0f-566b8de80917"],

Cell[CellGroupData[{

Cell["Preliminaries", "Section",
 CellChangeTimes->{{3.876476267438961*^9, 3.8764762677765923`*^9}, {
   3.877372146512374*^9, 3.877372199594759*^9}, 3.8773722480335817`*^9, {
   3.8774071133870296`*^9, 3.877407119244853*^9}, {3.877412418553198*^9, 
   3.877412423233988*^9}, {3.8775798424542503`*^9, 
   3.8775798945390167`*^9}},ExpressionUUID->"c9bcd3b3-cca4-4b42-9ab7-\
7edb766bdeb3"],

Cell[BoxData[{
 RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ClearAll", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FrontEndTokenExecute", "[", "\"\<DeleteGeneratedCells\>\"", "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.876476267438961*^9, 3.8764762677765923`*^9}, {
   3.877372146512374*^9, 3.877372199594759*^9}, 3.8773722480335817`*^9, {
   3.8774071133870296`*^9, 3.877407119244853*^9}, {3.877412418553198*^9, 
   3.877412423233988*^9}, 3.8775798424542503`*^9, {3.877581266508078*^9, 
   3.877581267568302*^9}, 3.877586155264432*^9, 3.8775867207362967`*^9, 
   3.8775984154429083`*^9, {3.882606281951621*^9, 3.882606283707821*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"a2653600-1e1d-44a6-9f4e-8cf04dd607c9"],

Cell[CellGroupData[{

Cell["want to do sanity/consistency checks?", "Subsection",
 CellChangeTimes->{{3.8764763032689457`*^9, 3.876476325898991*^9}, {
   3.876817320245174*^9, 3.8768173988178883`*^9}, {3.876817462707177*^9, 
   3.876817468708086*^9}, {3.8768205463995943`*^9, 3.876820548123602*^9}, {
   3.876930629672821*^9, 3.876930654441105*^9}, {3.8769668818346653`*^9, 
   3.87696692980023*^9}, {3.877136909545273*^9, 3.877136942430546*^9}, {
   3.8771454933674707`*^9, 3.8771454991956863`*^9}, {3.877145556561166*^9, 
   3.877145622419488*^9}, {3.877150561311514*^9, 3.877150586255044*^9}, {
   3.8771518461109133`*^9, 3.877151863799665*^9}, {3.877156185468029*^9, 
   3.877156197001549*^9}, {3.877156314961116*^9, 3.8771563261535177`*^9}, {
   3.877164385209506*^9, 3.877164393207386*^9}, {3.877320049061372*^9, 
   3.877320059192683*^9}, {3.877324665196436*^9, 3.877324672893216*^9}, {
   3.8774070746507187`*^9, 3.877407084900752*^9}, {3.877409617772169*^9, 
   3.8774096249922743`*^9}, {3.8774102302181892`*^9, 
   3.8774102390809813`*^9}, {3.877412193443966*^9, 3.8774122011587877`*^9}, {
   3.877414168433618*^9, 3.8774141698424597`*^9}, {3.877414212210051*^9, 
   3.877414253765003*^9}, {3.877508318027193*^9, 3.877508343060432*^9}, 
   3.8775087934421883`*^9, {3.877509252269079*^9, 3.877509285279415*^9}, {
   3.8775105847872*^9, 3.877510586658449*^9}, {3.877529055086195*^9, 
   3.8775290668863688`*^9}, {3.877529211844797*^9, 3.8775292180691967`*^9}, {
   3.877581158454818*^9, 
   3.877581169162779*^9}},ExpressionUUID->"0d39e317-472f-4783-927c-\
b4a17221c0cb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"doSanityCheck", " ", "=", " ", "True"}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"set", " ", "doSanityCheck", " ", "to", " ", 
    RowBox[{"True", "/", "False"}], " ", "if", " ", "you", " ", 
    RowBox[{"want", "/", "do"}], " ", "not", " ", "want", " ", "to", " ", 
    "perform", " ", "the", " ", "consistency", " ", "checks"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"On", "[", "Assert", "]"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "A", " ", "function", " ", "to", " ", "do", " ", "consistency", " ", 
    "checks"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CheckSanity", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Check", "[", 
      RowBox[{
       RowBox[{"Assert", "[", "#", "]"}], ",", " ", 
       RowBox[{"Abort", "[", "]"}]}], "]"}], "&"}], ")"}]}], ";"}]}], "Input",\

 CellChangeTimes->{{3.8764763032689457`*^9, 3.876476325898991*^9}, {
   3.876817320245174*^9, 3.8768173988178883`*^9}, {3.876817462707177*^9, 
   3.876817468708086*^9}, {3.8768205463995943`*^9, 3.876820548123602*^9}, {
   3.876930629672821*^9, 3.876930654441105*^9}, {3.8769668818346653`*^9, 
   3.87696692980023*^9}, {3.877136909545273*^9, 3.877136942430546*^9}, {
   3.8771454933674707`*^9, 3.8771454991956863`*^9}, {3.877145556561166*^9, 
   3.877145622419488*^9}, {3.877150561311514*^9, 3.877150586255044*^9}, {
   3.8771518461109133`*^9, 3.877151863799665*^9}, {3.877156185468029*^9, 
   3.877156197001549*^9}, {3.877156314961116*^9, 3.8771563261535177`*^9}, {
   3.877164385209506*^9, 3.877164393207386*^9}, {3.877320049061372*^9, 
   3.877320059192683*^9}, {3.877324665196436*^9, 3.877324672893216*^9}, {
   3.8774070746507187`*^9, 3.877407084900752*^9}, {3.877409617772169*^9, 
   3.8774096249922743`*^9}, {3.8774102302181892`*^9, 
   3.8774102390809813`*^9}, {3.877412193443966*^9, 3.8774122011587877`*^9}, {
   3.877414168433618*^9, 3.8774141698424597`*^9}, {3.877414212210051*^9, 
   3.877414253765003*^9}, {3.877508318027193*^9, 3.877508343060432*^9}, 
   3.8775087934421883`*^9, {3.877509252269079*^9, 3.877509285279415*^9}, {
   3.8775105847872*^9, 3.877510586658449*^9}, {3.877529055086195*^9, 
   3.8775290668863688`*^9}, {3.877529211844797*^9, 3.8775292180691967`*^9}, {
   3.877581158454818*^9, 3.877581161205698*^9}, {3.877586844501862*^9, 
   3.877586872898407*^9}, {3.877592346587762*^9, 3.8775923532593937`*^9}, {
   3.877592862093699*^9, 3.8775928749196978`*^9}, {3.877592908892601*^9, 
   3.8775929698401814`*^9}, {3.877594123143318*^9, 3.877594160831707*^9}, {
   3.877594363105192*^9, 3.877594398473055*^9}, {3.877594503187998*^9, 
   3.877594513154117*^9}, {3.877594564180243*^9, 3.8775945773698187`*^9}, {
   3.877594747117682*^9, 3.8775947529851713`*^9}, {3.87759479774496*^9, 
   3.877594901581863*^9}, {3.8775953618808804`*^9, 3.8775953765853043`*^9}, {
   3.877595701666438*^9, 3.877595705799818*^9}, {3.877595737626886*^9, 
   3.8775957724921017`*^9}, {3.87759665362574*^9, 3.8775966554818897`*^9}, {
   3.877617186093432*^9, 3.8776171887942123`*^9}, {3.8786387769937153`*^9, 
   3.8786387792847757`*^9}, {3.882618051560479*^9, 3.882618053410165*^9}, {
   3.883986526108376*^9, 3.8839865281895237`*^9}, {3.8839958174263287`*^9, 
   3.883995819064467*^9}, {3.884086055775055*^9, 3.8840860579347687`*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"df70e129-ee60-437d-8859-9a2f3ec89a90"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"$Assumptions", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Yw", "[", "T", "]"}], "|", 
         RowBox[{"Yv", "[", "T", "]"}], "|", 
         RowBox[{"Yu", "[", "T", "]"}], "|", " ", 
         RowBox[{"iYw", "[", "T", "]"}], "|", 
         RowBox[{"iYu", "[", "T", "]"}], "|", 
         RowBox[{"iYv", "[", "T", "]"}], "|", 
         RowBox[{"dYw", "[", "T", "]"}], "|", 
         RowBox[{"dYv", "[", "T", "]"}], "|", 
         RowBox[{"dYu", "[", "T", "]"}], "|", "\[Kappa]1", "|", "\[Kappa]2", 
         "|", "\[Kappa]3", "|", "c", "|", "\[Epsilon]", "|", 
         RowBox[{"iTiYw", "[", "T", "]"}], "|", 
         RowBox[{"iTSqYw", "[", "T", "]"}], "|", 
         RowBox[{"in0SS", "[", "T", "]"}], "|", 
         RowBox[{"dYw", "[", "T", "]"}], "|", 
         RowBox[{"idYw", "[", "T", "]"}], "|", 
         RowBox[{"iTidYw", "[", "T", "]"}], "|", 
         RowBox[{"dYv", "[", "T", "]"}], "|", 
         RowBox[{"dn0SS", "[", "T", "]"}], "|", 
         RowBox[{"idn0SS", "[", "T", "]"}]}], " ", "\[IndentingNewLine]", 
        ")"}], "\[Element]", "Reals"}], ",", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "|", "ks"}], ")"}], ">", "0"}], ",", " ", 
      RowBox[{"0", "<", "t", "<", "a"}], ",", " ", 
      RowBox[{"0", "<", "\[Nu]", "<", "0.5"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[Nu]", "2"]}], "<", "0"}]}], "}"}]}], ";"}], 
  " "}]], "Input",
 CellChangeTimes->{{3.8764763032689457`*^9, 3.876476325898991*^9}, {
   3.876817320245174*^9, 3.8768173988178883`*^9}, {3.876817462707177*^9, 
   3.876817468708086*^9}, {3.8768205463995943`*^9, 3.876820548123602*^9}, 
   3.876930629672821*^9, {3.876930818328162*^9, 3.876930821252952*^9}, {
   3.877100382560156*^9, 3.8771004177322483`*^9}, {3.8771004875141497`*^9, 
   3.8771004933320436`*^9}, 3.8771005346734333`*^9, {3.8771429122890253`*^9, 
   3.8771429158514833`*^9}, {3.877155187241674*^9, 3.877155187496827*^9}, 
   3.8772274464580593`*^9, {3.87722749945474*^9, 3.877227563607544*^9}, {
   3.877227682717112*^9, 3.877227684421707*^9}, {3.87722920350893*^9, 
   3.877229210514008*^9}, {3.8773193261066513`*^9, 3.8773193273516607`*^9}, {
   3.8773194042876453`*^9, 3.877319462953988*^9}, {3.8773194971767807`*^9, 
   3.8773195102161503`*^9}, {3.877319594905588*^9, 3.877319619261712*^9}, {
   3.877322716188107*^9, 3.877322718464775*^9}, {3.87752416790392*^9, 
   3.877524168432547*^9}, 3.877581205090877*^9},
 CellLabel->"In[8]:=",ExpressionUUID->"3e963411-ec00-4897-a619-31463d9a4578"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Notation used in this  file", "Subsection",
 CellChangeTimes->{{3.8764763032689457`*^9, 3.876476325898991*^9}, {
   3.876817320245174*^9, 3.8768173988178883`*^9}, {3.876817462707177*^9, 
   3.876817468708086*^9}, {3.8768205463995943`*^9, 3.876820548123602*^9}, 
   3.876930629672821*^9, {3.876930818328162*^9, 3.876930821252952*^9}, {
   3.877100382560156*^9, 3.8771004177322483`*^9}, {3.8771004875141497`*^9, 
   3.8771004933320436`*^9}, {3.8771005346734333`*^9, 
   3.8771006619325323`*^9}, {3.877100700840889*^9, 3.877100803606545*^9}, {
   3.8771008410709352`*^9, 3.8771008650446033`*^9}, {3.877100936731655*^9, 
   3.877101138787685*^9}, {3.877101262053821*^9, 3.87710132690692*^9}, {
   3.877105739972723*^9, 3.87710574526723*^9}, {3.877105854495693*^9, 
   3.877106022482705*^9}, {3.87710669220485*^9, 3.877106704168757*^9}, {
   3.877108354141328*^9, 3.877108359375945*^9}, {3.8771084773272257`*^9, 
   3.87710848308984*^9}, {3.8771085947952833`*^9, 3.877108638740376*^9}, {
   3.87710893794389*^9, 3.877109022309369*^9}, {3.877136840032823*^9, 
   3.877136862829431*^9}, {3.8771405090013943`*^9, 3.8771405100357656`*^9}, 
   3.877140949770193*^9, {3.8771431774093523`*^9, 3.8771432004274607`*^9}, {
   3.877143276332111*^9, 3.877143290216323*^9}, {3.877227619389901*^9, 
   3.877227653811565*^9}, {3.877227695335451*^9, 3.877227696762123*^9}, {
   3.8774070971215477`*^9, 3.8774070973081713`*^9}, {3.8775814555197678`*^9, 
   3.877581470974639*^9}},ExpressionUUID->"df72384d-429e-46dc-8ea1-\
541080dd4b93"],

Cell[BoxData[
 RowBox[{"(*", "  ", "\[IndentingNewLine]", GridBox[{
    {
     RowBox[{"iYw", "[", "T", "]"}], 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", "0"], "T"], 
      RowBox[{
       RowBox[{"Yw", "[", "m", "]"}], " ", "dm"}]}]},
    {
     RowBox[{"iTiYw", "[", "T", "]"}], 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", "0"], "T"], 
      RowBox[{"m", " ", 
       RowBox[{"iYw", "[", "m", "]"}], " ", "dm"}]}]},
    {
     RowBox[{"iTSqYw", "[", "T", "]"}], 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", "0"], "T"], 
      RowBox[{
       SuperscriptBox["m", "2"], " ", 
       RowBox[{"Yw", "[", "m", "]"}], " ", "dm"}]}]},
    {
     RowBox[{"in0SS", "[", "T", "]"}], 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", "0"], "T"], 
      RowBox[{
       RowBox[{"n0SS", "[", "m", "]"}], " ", "dm"}]}]},
    {
     RowBox[{"dYw", "[", "T", "]"}], 
     RowBox[{" ", 
      RowBox[{"h\[Dagger]", ".", " ", 
       RowBox[{
        SubscriptBox["\[Del]", "h"], 
        RowBox[{"Yw", "[", "T", "]"}]}]}]}]},
    {
     RowBox[{"idYw", "[", "T", "]"}], 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", "0"], "T"], 
      RowBox[{
       RowBox[{"dYw", "[", "m", "]"}], " ", "dm"}]}]},
    {
     RowBox[{"iTidYw", "[", "T", "]"}], 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", "0"], "T"], 
      RowBox[{"m", " ", 
       RowBox[{"idYw", "[", "m", "]"}], " ", "dm"}]}]},
    {
     RowBox[{"dYv", "[", "T", "]"}], 
     RowBox[{" ", 
      RowBox[{"h\[Dagger]", ".", " ", 
       RowBox[{
        SubscriptBox["\[Del]", "h"], 
        RowBox[{"Yv", "[", "T", "]"}]}]}]}]},
    {
     RowBox[{"dYu", "[", "T", "]"}], 
     RowBox[{" ", 
      RowBox[{"h\[Dagger]", ".", " ", 
       RowBox[{
        SubscriptBox["\[Del]", "h"], 
        RowBox[{"Yu", "[", "T", "]"}]}]}]}]},
    {
     RowBox[{"dn0SS", "[", "T", "]"}], 
     RowBox[{" ", 
      RowBox[{"h\[Dagger]", ".", " ", 
       RowBox[{
        SubscriptBox["\[Del]", "h"], 
        RowBox[{"n0SS", "[", "T", "]"}]}]}]}]},
    {
     RowBox[{"idn0SS", "[", "T", "]"}], 
     RowBox[{" ", 
      RowBox[{"h\[Dagger]", ".", " ", 
       RowBox[{
        SubscriptBox["\[Del]", "h"], 
        RowBox[{"in0SS", "[", "T", "]"}]}]}]}]}
   },
   GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}}], 
  "\[IndentingNewLine]", "*)"}]], "Input",
 CellChangeTimes->{{3.8764763032689457`*^9, 3.876476325898991*^9}, {
   3.876817320245174*^9, 3.8768173988178883`*^9}, {3.876817462707177*^9, 
   3.876817468708086*^9}, {3.8768205463995943`*^9, 3.876820548123602*^9}, 
   3.876930629672821*^9, {3.876930818328162*^9, 3.876930821252952*^9}, {
   3.877100382560156*^9, 3.8771004177322483`*^9}, {3.8771004875141497`*^9, 
   3.8771004933320436`*^9}, {3.8771005346734333`*^9, 
   3.8771006619325323`*^9}, {3.877100700840889*^9, 3.877100803606545*^9}, {
   3.8771008410709352`*^9, 3.8771008650446033`*^9}, {3.877100936731655*^9, 
   3.877101138787685*^9}, {3.877101262053821*^9, 3.87710132690692*^9}, {
   3.877105739972723*^9, 3.87710574526723*^9}, {3.877105854495693*^9, 
   3.877106022482705*^9}, {3.87710669220485*^9, 3.877106704168757*^9}, {
   3.877108354141328*^9, 3.877108359375945*^9}, {3.8771084773272257`*^9, 
   3.87710848308984*^9}, {3.8771085947952833`*^9, 3.877108638740376*^9}, {
   3.87710893794389*^9, 3.877109022309369*^9}, {3.877136840032823*^9, 
   3.877136862829431*^9}, {3.8771405090013943`*^9, 3.8771405100357656`*^9}, 
   3.877140949770193*^9, {3.8771431774093523`*^9, 3.8771432004274607`*^9}, {
   3.877143276332111*^9, 3.877143290216323*^9}, {3.877227619389901*^9, 
   3.877227653811565*^9}, {3.877227695335451*^9, 3.877227696762123*^9}, {
   3.8774070971215477`*^9, 3.8774070973081713`*^9}, {3.8775814555197678`*^9, 
   3.8775814587838078`*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"2f745f26-46cf-49b1-bcf8-f32bfad1c392"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"stiffnesses", "'"}], " ", "expressions"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"KmExp", " ", "=", 
     FractionBox[
      RowBox[{"Y", " ", "t"}], 
      RowBox[{"1", "-", 
       SuperscriptBox["\[Nu]", "2"]}]]}], " ", ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DbExp", " ", "=", 
     FractionBox[
      RowBox[{"Y", " ", 
       SuperscriptBox["t", "3"]}], 
      RowBox[{"12", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["\[Nu]", "2"]}], ")"}]}]]}], " ", ";"}]}]}]], "Input",\

 CellChangeTimes->{{3.87681749790352*^9, 3.876817505665374*^9}, 
   3.876931424389435*^9, {3.876968551716156*^9, 3.8769685538183813`*^9}, {
   3.87697009310639*^9, 3.87697009344176*^9}, {3.8770055108594418`*^9, 
   3.877005511574963*^9}, {3.877088515916668*^9, 3.877088537722622*^9}, {
   3.877089217277742*^9, 3.87708921755291*^9}, 3.877139947573279*^9, {
   3.877141989053913*^9, 3.8771419910161877`*^9}, {3.877151519641608*^9, 
   3.87715152249244*^9}, {3.8771523020060987`*^9, 3.87715230322244*^9}, {
   3.8774153371500807`*^9, 3.877415425416506*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"1492f9e4-6e91-48b8-b131-151b43441f76"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"non", " ", "dimensional", " ", "strain"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ksExp", " ", "=", " ", 
    FractionBox["t", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"12", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox["\[Nu]", "2"]}], ")"}]}], ")"}], 
       FractionBox["1", "2"]]}]]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.87681749790352*^9, 3.876817505665374*^9}, 
   3.876931424389435*^9, {3.876968551716156*^9, 3.8769685538183813`*^9}, {
   3.87697009310639*^9, 3.87697009344176*^9}, {3.8770055108594418`*^9, 
   3.877005511574963*^9}, {3.877088515916668*^9, 3.877088537722622*^9}, {
   3.877089217277742*^9, 3.87708921755291*^9}, 3.877139947573279*^9, {
   3.877141989053913*^9, 3.8771419910161877`*^9}, {3.877151519641608*^9, 
   3.87715152249244*^9}, {3.8771523020060987`*^9, 3.877152313692169*^9}, {
   3.877415437820889*^9, 3.877415548357358*^9}, 3.877415643456785*^9},
 CellLabel->"In[12]:=",ExpressionUUID->"f21aca84-7b48-41fb-a4c0-b93aaac0452a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "nondimensional", " ", "function", " ", "for", " ", "leading", " ", 
    "order", " ", "displacment", " ", "solution"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "function", " ", "has", " ", "been", " ", "tested", " ", "in",
     " ", "the", " ", "Mathematica", " ", "file", " ", "for", " ", "leading", 
    " ", "order", " ", "energy"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Rho]", "[", 
      RowBox[{"\[Mu]_", ",", "T_"}], "]"}], "=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Lambda]", " ", "=", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            FractionBox["\[Mu]", "4"], ")"}], 
           FractionBox["1", "4"]]}], ",", " ", "p1", ",", " ", "p2"}], "}"}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"p1", "=", " ", 
         RowBox[{
          RowBox[{"Cos", "[", 
           FractionBox["\[Lambda]", "2"], "]"}], " ", 
          RowBox[{"Sinh", "[", 
           FractionBox["\[Lambda]", "2"], "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"p2", "=", " ", 
         RowBox[{
          RowBox[{"Sin", "[", 
           FractionBox["\[Lambda]", "2"], "]"}], " ", 
          RowBox[{"Cosh", "[", 
           FractionBox["\[Lambda]", "2"], "]"}]}]}], ";", 
        "\[IndentingNewLine]", " ", 
        RowBox[{
         FractionBox["1", "\[Mu]"], 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"\[Lambda]", " ", "T"}], "]"}], " ", 
              RowBox[{"Cosh", "[", 
               RowBox[{"\[Lambda]", " ", "T"}], "]"}], 
              RowBox[{"(", 
               RowBox[{"p1", "-", "p2"}], ")"}]}], " ", "+", " ", 
             RowBox[{
              RowBox[{"Sin", "[", 
               RowBox[{"\[Lambda]", " ", "T"}], "]"}], " ", 
              RowBox[{"Sinh", "[", 
               RowBox[{"\[Lambda]", " ", "T"}], "]"}], 
              RowBox[{"(", 
               RowBox[{"p1", "+", "p2"}], ")"}], " "}]}], 
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Sin", "[", "\[Lambda]", "]"}], " ", "+", " ", 
               RowBox[{"Sinh", "[", "\[Lambda]", "]"}]}], ")"}]}]], " ", "-", 
           " ", 
           RowBox[{
            FractionBox["1", "2"], 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["T", "2"], " ", "-", " ", 
              FractionBox["1", "12"]}], ")"}]}]}], ")"}]}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "leading", " ", "order", " ", "displacement", " ", "along", " ", 
     "director", " ", "d1"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"YwExp", "[", "T_", "]"}], " ", "=", " ", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Alpha]", ",", " ", "\[Beta]", ",", " ", "\[Mu]"}], "}"}], 
       ",", " ", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"\[Alpha]", " ", "=", " ", 
         RowBox[{"c", "-", " ", 
          RowBox[{"\[Nu]", " ", "\[Kappa]2"}]}]}], " ", ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Beta]", " ", "=", " ", 
         FractionBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["\[Kappa]2", "2"], " ", 
             RowBox[{"(", " ", 
              RowBox[{"c", "-", " ", 
               RowBox[{"\[Nu]", " ", "\[Kappa]2"}]}], ")"}]}], " ", "-", " ", 
            
            RowBox[{"\[Kappa]2", "  ", 
             SuperscriptBox["\[Kappa]3", "2"]}]}], ")"}], 
          SuperscriptBox["ks", "2"]]}], ";", "\[IndentingNewLine]", 
        RowBox[{"\[Mu]", "=", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["\[Kappa]2", "ks"], ")"}], "2"]}], ";", 
        "\[IndentingNewLine]", " ", 
        RowBox[{
         SuperscriptBox["a", "2"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox["\[Alpha]", "2"], 
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               SuperscriptBox["T", "2"], 
               SuperscriptBox["a", "2"]], "-", 
              FractionBox["1", "12"]}], ")"}]}], " ", "+", " ", 
           RowBox[{"\[Beta]", " ", 
            RowBox[{"\[Rho]", "[", 
             RowBox[{"\[Mu]", ",", 
              FractionBox["T", "a"]}], "]"}]}]}], ")"}]}]}]}], "]"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.876819152522875*^9, 3.876819163473029*^9}, {
   3.876819223100175*^9, 3.876819353095829*^9}, {3.876819395244372*^9, 
   3.876819401030746*^9}, {3.876819514170251*^9, 3.876819579278193*^9}, {
   3.8768196770219383`*^9, 3.8768200259865913`*^9}, 3.8768201398769817`*^9, {
   3.8768201827740307`*^9, 3.8768201857124033`*^9}, {3.876821054431963*^9, 
   3.876821054697229*^9}, {3.876931224171596*^9, 3.876931224959942*^9}, {
   3.876931589936034*^9, 3.876931590997046*^9}, {3.876931624955536*^9, 
   3.876931630084735*^9}, {3.876931696943776*^9, 3.876931728271325*^9}, 
   3.8769668097284403`*^9, {3.877152332782919*^9, 3.877152342628995*^9}, {
   3.877416748207823*^9, 3.8774168038203297`*^9}, {3.877416877526847*^9, 
   3.877416897503439*^9}, 3.8775091717013702`*^9, {3.877522165968698*^9, 
   3.8775222026875772`*^9}, {3.877522240573745*^9, 3.877522247710515*^9}, {
   3.8775986812081833`*^9, 3.877598726413308*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"0c9e1c71-c829-454b-9890-6d2489ea7fb7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "stress", " ", "and", " ", "strains", " ", "at", " ", "leading", " ", 
    "order"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"n0SS", "[", "T_", "]"}], " ", "=", 
     RowBox[{
      FractionBox["1", "2"], " ", "t", " ", "Y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "\[Epsilon]"}], "+", 
        RowBox[{"T", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Kappa]1"}], "+", 
           RowBox[{"T", " ", 
            SuperscriptBox["\[Kappa]3", "2"]}]}], ")"}]}], "-", 
        RowBox[{"2", " ", "\[Kappa]2", " ", 
         RowBox[{"Yw", "[", "T", "]"}]}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"E0SS", "[", "T_", "]"}], "=", 
     RowBox[{"\[Epsilon]", "+", 
      RowBox[{"T", " ", "\[Kappa]1"}], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["T", "2"], " ", 
        SuperscriptBox["\[Kappa]3", "2"]}], "2"], "-", 
      RowBox[{"\[Kappa]2", " ", 
       RowBox[{"Yw", "[", "T", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"m0SS", "[", "T_", "]"}], "=", " ", 
     RowBox[{"Db", " ", 
      RowBox[{"(", 
       RowBox[{"\[Kappa]2", "-", 
        RowBox[{"c", " ", "\[Nu]"}], "+", 
        RowBox[{"\[Nu]", " ", 
         RowBox[{
          RowBox[{"Yw", "''"}], "[", "T", "]"}]}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"B0SS", "[", "T_", "]"}], "=", "\[Kappa]2"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"m0ST", "[", "T_", "]"}], "=", " ", 
     RowBox[{
      RowBox[{"-", "Db"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Nu]"}], ")"}], " ", "\[Kappa]3"}]}], " ", ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"B0ST", "[", "T_", "]"}], "=", 
     RowBox[{"-", "\[Kappa]3"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"m0TT", "[", "T_", "]"}], "=", " ", 
     RowBox[{"Db", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "c"}], "+", 
        RowBox[{"\[Kappa]2", " ", "\[Nu]"}], "+", 
        RowBox[{
         RowBox[{"Yw", "''"}], "[", "T", "]"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"B0TT", "[", "T_", "]"}], "=", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{
       RowBox[{"Yw", "''"}], "[", "T", "]"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.876968612008811*^9, 3.876968801510522*^9}, {
   3.876971191496477*^9, 3.876971195699588*^9}, {3.876971234586986*^9, 
   3.876971254069565*^9}, 3.877139914330255*^9, 3.877141147305276*^9, 
   3.877142210747314*^9, 3.877142303208866*^9, {3.8771423407010527`*^9, 
   3.877142342131057*^9}, {3.877142447918782*^9, 3.877142449916073*^9}, {
   3.877145438039093*^9, 3.877145451571044*^9}, {3.877151533777832*^9, 
   3.877151534120825*^9}, {3.877531583269767*^9, 3.877531593618022*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"26e0bcd8-5d38-47be-b4bf-298130cce3c0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"canonical", " ", "representation"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "dagger", " ", "symbol", " ", "used", " ", "in", " ", "the", " ", "paper",
      " ", "confuses", " ", "with", " ", "plus", " ", "symbol", " ", "in", 
     " ", 
     RowBox[{"Mathematica", ".", " ", "To"}], " ", "overcome", " ", "it"}], 
    ",", " ", 
    RowBox[{
    "we", " ", "denote", " ", "the", " ", "value", " ", "of", " ", 
     "longitudinal", " ", "strain", " ", "gradients", " ", "in", " ", "a", 
     " ", "cross", " ", "section", " ", "by", " ", 
     SubscriptBox["d\[Kappa]", "i"]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"h", "  ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
      "\[Epsilon]", ",", "\[Kappa]1", ",", "\[Kappa]2", ",", "\[Kappa]3"}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dh", "=", " ", 
     RowBox[{"{", 
      RowBox[{
      "d\[Epsilon]", ",", "d\[Kappa]1", ",", "d\[Kappa]2", ",", 
       "d\[Kappa]3"}], "}"}]}], " ", ";"}]}]}]], "Input",
 CellChangeTimes->{{3.87696978218681*^9, 3.876969805610215*^9}, {
   3.8769703641717567`*^9, 3.876970473106339*^9}, {3.8771370819114532`*^9, 
   3.877137086484332*^9}, {3.877140468372661*^9, 3.877140476359717*^9}, {
   3.877140519229653*^9, 3.8771405490031567`*^9}, 3.877141994823835*^9, {
   3.877151546884131*^9, 3.8771515473911457`*^9}, 3.87740717194207*^9},
 CellLabel->"In[23]:=",ExpressionUUID->"935759a6-2c84-49af-a612-72f5c8f890dd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "We", " ", "write", " ", "the", " ", "following", " ", "functions", " ", 
    "in", " ", "implict", " ", "form"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Yvfn", "[", "T_", "]"}], " ", "=", 
     RowBox[{"\[Kappa]3", " ", 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"T", " ", 
         RowBox[{"Yw", "[", "T", "]"}]}], " ", "-", " ", 
        RowBox[{"2", " ", 
         RowBox[{"iYw", "[", "T", "]"}]}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"dYvfn", "[", "T_", "]"}], " ", "=", 
     RowBox[{
      RowBox[{"d\[Kappa]3", " ", 
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{"T", " ", 
          RowBox[{"Yw", "[", "T", "]"}]}], " ", "-", " ", 
         RowBox[{"2", " ", 
          RowBox[{"iYw", "[", "T", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"\[Kappa]3", " ", 
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{"T", " ", 
          RowBox[{"dYw", "[", "T", "]"}]}], " ", "-", " ", 
         RowBox[{"2", " ", 
          RowBox[{"idYw", "[", "T", "]"}]}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"in0SSfn", "[", "T_", "]"}], "=", 
     RowBox[{
      FractionBox["1", "2"], " ", "t", " ", "Y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Integrate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"2", " ", "\[Epsilon]"}], "+", 
           RowBox[{"T", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "\[Kappa]1"}], "+", 
              RowBox[{"T", " ", 
               SuperscriptBox["\[Kappa]3", "2"]}]}], ")"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"T", ",", "0", ",", "T"}], "}"}]}], "]"}], "-", 
        RowBox[{"2", " ", "\[Kappa]2", " ", 
         RowBox[{"iYw", "[", "T", "]"}]}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"dm0STfn", "[", "T_", "]"}], "=", 
     RowBox[{
      RowBox[{"dm0STExp", "[", "T_", "]"}], "=", 
      RowBox[{
       RowBox[{"-", "Db"}], " ", "d\[Kappa]3", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Nu]"}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"dn0SSfn", "[", "T_", "]"}], "=", 
     RowBox[{
      FractionBox["1", "2"], " ", "t", " ", "Y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "d\[Epsilon]"}], "+", 
        RowBox[{"T", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "d\[Kappa]1"}], "+", 
           RowBox[{"2", " ", "T", " ", "\[Kappa]3", " ", "d\[Kappa]3"}]}], 
          ")"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"d\[Kappa]2", " ", 
            RowBox[{"Yw", "[", "T", "]"}]}], "+", 
           RowBox[{"\[Kappa]2", " ", 
            RowBox[{"dYw", "[", "T", "]"}]}]}], ")"}]}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"idn0SSfn", "[", "T_", "]"}], "=", 
     RowBox[{
      FractionBox["1", "2"], " ", "t", " ", "Y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "T", " ", "d\[Epsilon]"}], "+", 
        RowBox[{
         SuperscriptBox["T", "2"], " ", "d\[Kappa]1"}], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["T", "3"], " ", "\[Kappa]3", " ", "d\[Kappa]3"}], 
         "3"], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Kappa]2", " ", 
            RowBox[{"idYw", "[", "T", "]"}]}], "+", 
           RowBox[{"d\[Kappa]2", " ", 
            RowBox[{"iYw", "[", "T", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8769693268089933`*^9, 3.876969393013617*^9}, {
   3.876969578481927*^9, 3.8769695830088453`*^9}, {3.876969624254148*^9, 
   3.876969638152968*^9}, {3.8769697121808863`*^9, 3.8769697591965837`*^9}, {
   3.8769698034093246`*^9, 3.876969839562067*^9}, {3.876970735385333*^9, 
   3.876970768290411*^9}, {3.877000141583839*^9, 3.877000232677216*^9}, 
   3.877003084015959*^9, {3.877091458366316*^9, 3.8770914632356863`*^9}, {
   3.877141523084687*^9, 3.877141532722419*^9}, 3.8771420203023233`*^9, {
   3.877142521546213*^9, 3.877142526083795*^9}, {3.877142661369566*^9, 
   3.877142663591486*^9}, 3.877143143109827*^9, {3.877143318295703*^9, 
   3.8771433408719807`*^9}, {3.877151572628834*^9, 3.877151572886726*^9}, {
   3.8775987419581957`*^9, 3.8775987524788103`*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"33c23470-a8fa-48d5-8982-a10a194079ea"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "explicit", " ", "expressions", " ", "for", " ", "functions", 
    " ", "above", " ", "are", " ", "calculated", " ", "below", " ", "and", 
    " ", "used", " ", "only", " ", "for", " ", "the", " ", "sanity", " ", 
    "checks"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"If", "[", 
   RowBox[{"doSanityCheck", ",", " ", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"iYwExp", "[", "T_", "]"}], "=", " ", 
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"YwExp", "[", "m", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"m", ",", "0", ",", "T"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"YvExp", "[", "T_", "]"}], " ", "=", 
      RowBox[{
       RowBox[{"Yvfn", "[", "T", "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Yw", "->", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"YwExp", "[", "#", "]"}], "&"}], ")"}]}], ",", " ", 
         RowBox[{"iYw", " ", "->", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"iYwExp", "[", "#", "]"}], "&"}], ")"}]}]}], "}"}]}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"YuExp", "[", "T_", "]"}], "=", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[Nu]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"T", " ", "\[Epsilon]"}], "  ", "+", " ", 
           RowBox[{
            FractionBox["\[Kappa]1", "2"], 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["T", "2"], "-", 
              FractionBox[
               SuperscriptBox["a", "2"], "12"]}], ")"}]}], "+", " ", 
           RowBox[{
            FractionBox[
             SuperscriptBox["\[Kappa]3", "2"], "6"], 
            SuperscriptBox["T", "3"]}]}], ")"}]}], "+", " ", 
        RowBox[{"(", 
         RowBox[{"\[Nu]", " ", "\[Kappa]2", " ", 
          RowBox[{"iYwExp", "[", "T", "]"}]}], " ", ")"}], " ", "-", 
        RowBox[{
         FractionBox["1", "2"], 
         RowBox[{"Integrate", "[", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             RowBox[{"YwExp", "'"}], "[", "m", "]"}], "2"], ",", 
           RowBox[{"{", 
            RowBox[{"m", ",", "0", ",", "T"}], "}"}]}], "]"}]}]}], ")"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"dn0SSExp", "[", "T_", "]"}], "=", 
      RowBox[{"dh", ".", 
       RowBox[{"Grad", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"n0SS", "[", "T", "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{"Yw", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"YwExp", "[", "#", "]"}], "&"}], ")"}]}], "}"}]}], ",", 
         "h"}], " ", "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"in0SSExp", "[", "m_", "]"}], "=", " ", 
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"n0SS", "[", "T", "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{"Yw", "->", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"YwExp", "[", "#", "]"}], "&"}], ")"}]}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"T", ",", "0", ",", "m"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"idn0SSExp", "[", "T_", "]"}], "=", 
      RowBox[{"dh", ".", 
       RowBox[{"Grad", "[", 
        RowBox[{
         RowBox[{"in0SSExp", "[", "T", "]"}], ",", "h"}], " ", "]"}]}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"dYwExp", "[", "T_", "]"}], "=", 
      RowBox[{"dh", ".", 
       RowBox[{"Grad", "[", 
        RowBox[{
         RowBox[{"YwExp", "[", "T", "]"}], ",", "h"}], " ", "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"idYwExp", "[", "m_", "]"}], "=", " ", 
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"dYwExp", "[", "T", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"T", ",", "0", ",", "m"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"iTiYwExp", "[", "m_", "]"}], "=", "  ", 
      RowBox[{"Integrate", "[", " ", 
       RowBox[{
        RowBox[{"T", " ", 
         RowBox[{"iYwExp", "[", "T", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"T", ",", "0", ",", "m"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"iTidYwExp", "[", "m_", "]"}], "=", "  ", 
      RowBox[{"Integrate", "[", " ", 
       RowBox[{
        RowBox[{"T", " ", 
         RowBox[{"idYwExp", "[", "T", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"T", ",", "0", ",", "m"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"iTSqYwExp", "[", "m_", "]"}], "=", "  ", 
      RowBox[{"Integrate", "[", " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["T", "2"], " ", 
         RowBox[{"YwExp", "[", "T", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"T", ",", "0", ",", "m"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"dYvExp", "[", "T_", "]"}], " ", "=", " ", 
      RowBox[{"dh", ".", 
       RowBox[{"Grad", "[", 
        RowBox[{
         RowBox[{"YvExp", "[", "T", "]"}], ",", "h"}], " ", "]"}]}]}], 
     ";"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.8769693268089933`*^9, 3.876969393013617*^9}, {
   3.876969578481927*^9, 3.8769695830088453`*^9}, {3.876969624254148*^9, 
   3.876969638152968*^9}, {3.8769697121808863`*^9, 3.8769697591965837`*^9}, {
   3.8769698034093246`*^9, 3.876969839562067*^9}, {3.876970735385333*^9, 
   3.876970768290411*^9}, {3.877000141583839*^9, 3.877000232677216*^9}, {
   3.877003084015959*^9, 3.8770030852103558`*^9}, {3.877003239141836*^9, 
   3.877003334852416*^9}, {3.877003380694316*^9, 3.877003415320134*^9}, {
   3.877003638003354*^9, 3.877003703794965*^9}, {3.8770566854687233`*^9, 
   3.877056715936049*^9}, {3.877060631793907*^9, 3.8770606714814177`*^9}, 
   3.8770775825772343`*^9, {3.8771063639640017`*^9, 3.8771063776074667`*^9}, {
   3.877106440469431*^9, 3.877106474257674*^9}, {3.877106565246604*^9, 
   3.877106617693007*^9}, {3.877108371217656*^9, 3.877108380518605*^9}, {
   3.8771405212529182`*^9, 3.877140554547408*^9}, {3.8771408961059*^9, 
   3.877140901144218*^9}, {3.8771420406908197`*^9, 3.877142058791802*^9}, {
   3.877142212401903*^9, 3.877142215117024*^9}, {3.877142527444941*^9, 
   3.87714253086303*^9}, {3.8771433561422873`*^9, 3.877143390136867*^9}, {
   3.877150809604753*^9, 3.877150810777814*^9}, {3.877151595807292*^9, 
   3.877151596672255*^9}, {3.877406826068851*^9, 3.87740683592338*^9}, {
   3.877521664121552*^9, 3.877521705871958*^9}, {3.877521824870363*^9, 
   3.877521826976726*^9}, {3.877524613021923*^9, 3.87752461506975*^9}, {
   3.877532298099519*^9, 3.877532309841197*^9}, {3.877594841274852*^9, 
   3.877594846530267*^9}, {3.877595395635993*^9, 3.877595404707922*^9}, {
   3.877598761437397*^9, 3.8775987981025867`*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"22612f94-e04f-4c73-b765-4a9ae246f463"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["First order gradient term:  A.h\[Dagger]", "Section",
 CellChangeTimes->{{3.876988155478589*^9, 3.876988227990621*^9}, {
   3.876999390562511*^9, 3.876999392481991*^9}, {3.877000990999222*^9, 
   3.8770010581157312`*^9}, {3.877002637655897*^9, 3.877002662141382*^9}, {
   3.8770037802488337`*^9, 3.877003785126947*^9}, {3.87700382117379*^9, 
   3.877003842141083*^9}, {3.8770038768998203`*^9, 3.877003910644436*^9}, {
   3.8770785845931873`*^9, 3.8770785907850027`*^9}, 3.877141510542817*^9, {
   3.877142060157757*^9, 3.8771420611238327`*^9}, 3.877142216563416*^9, {
   3.8771423486926537`*^9, 3.877142350019465*^9}, {3.877143396787369*^9, 
   3.877143410086153*^9}, 3.8771460491241617`*^9, {3.877152592826062*^9, 
   3.877152629946349*^9}, {3.877407220202856*^9, 3.877407229941571*^9}, {
   3.877409163790168*^9, 3.877409165523478*^9}, {3.877409576614655*^9, 
   3.877409579202549*^9}, 3.8775092318732758`*^9, {3.877524657596272*^9, 
   3.877524660667697*^9}, {3.877532335431019*^9, 3.877532341291176*^9}, {
   3.877579931536787*^9, 
   3.877579964356049*^9}},ExpressionUUID->"d35ec7dd-91c4-4d43-aa49-\
1de38f793db1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "simplified", " ", "expression", " ", "proposed", " ", "in", " ", "the", 
     " ", "paper"}], ",", " ", 
    RowBox[{"see", " ", 
     RowBox[{"Eq", ".", " ", "5.10"}], " ", "in", " ", "the", " ", 
     "paper"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Adh", " ", "=", " ", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"t", " ", "T", " ", "Y", " ", "\[Kappa]1", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"dYv", "[", "T", "]"}], "-", 
         RowBox[{"T", " ", "\[Kappa]3", " ", 
          RowBox[{"dYw", "[", "T", "]"}]}]}], ")"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"T", ",", 
        RowBox[{
         RowBox[{"-", "a"}], "/", "2"}], ",", 
        RowBox[{"a", "/", "2"}]}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"raw", " ", "result"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rawAdh", " ", "=", " ", 
     RowBox[{"Integrate", "[", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"n0SS", "[", "T", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"dYv", "[", "T", "]"}], "-", " ", 
            RowBox[{"T", "  ", "\[Kappa]3", " ", 
             RowBox[{"dYw", "[", "T", "]"}]}]}], ")"}]}], "-", " ", 
         RowBox[{
          RowBox[{"m0SS", "[", "T", "]"}], " ", "T", " ", "d\[Kappa]3"}], " ",
          "+", " ", 
         RowBox[{"2", " ", 
          RowBox[{"m0ST", "[", "T", "]"}], "  ", 
          RowBox[{
           RowBox[{"dYw", "'"}], "[", "T", "]"}]}]}], ")"}], ",", 
       RowBox[{"{", 
        RowBox[{"T", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}], ",", 
         RowBox[{"a", "/", "2"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "sanity", " ", "check", " ", "for", " ", "the", " ", "equivalence", " ", 
     "of", " ", "the", " ", "raw", " ", "expression", " ", 
     RowBox[{"(", 
      RowBox[{"Eq", ".", " ", "5.9"}], ")"}], " ", "and", " ", "the", " ", 
     "expression", " ", "proposed", " ", "in", " ", "the", " ", "paper", " ", 
     
     RowBox[{"(", 
      RowBox[{"Eq", ".", " ", "5.10"}], ")"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"If", "[", 
    RowBox[{"doSanityCheck", ",", " ", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"rawAdh", "-", "Adh"}], ")"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Yw", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"YwExp", "[", "#", "]"}], "&"}], ")"}]}], ",", 
           RowBox[{"dYv", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"dYvExp", "[", "#", "]"}], "&"}], ")"}]}], ",", " ", 
           RowBox[{"dYw", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"dYwExp", "[", "#", "]"}], "&"}], ")"}]}]}], "}"}]}], 
        "]"}], "==", "0"}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.876988155478589*^9, 3.876988227990621*^9}, {
   3.876999390562511*^9, 3.876999392481991*^9}, {3.877000990999222*^9, 
   3.8770010581157312`*^9}, {3.877002637655897*^9, 3.877002662141382*^9}, {
   3.8770037802488337`*^9, 3.877003785126947*^9}, {3.87700382117379*^9, 
   3.877003842141083*^9}, {3.8770038768998203`*^9, 3.877003910644436*^9}, {
   3.8770785845931873`*^9, 3.8770785907850027`*^9}, 3.877141510542817*^9, {
   3.877142060157757*^9, 3.8771420611238327`*^9}, 3.877142216563416*^9, {
   3.8771423486926537`*^9, 3.877142350019465*^9}, {3.877143396787369*^9, 
   3.877143410086153*^9}, 3.8771460491241617`*^9, {3.877152592826062*^9, 
   3.877152629946349*^9}, {3.877407220202856*^9, 3.877407229941571*^9}, {
   3.877409163790168*^9, 3.877409165523478*^9}, {3.877409576614655*^9, 
   3.877409579202549*^9}, 3.8775092318732758`*^9, {3.877524657596272*^9, 
   3.877524660667697*^9}, {3.877532335431019*^9, 3.877532341291176*^9}, {
   3.877579931536787*^9, 3.877579938102283*^9}, 3.8775927199128428`*^9, {
   3.877594193174444*^9, 3.877594217860663*^9}, {3.877594919007449*^9, 
   3.877594928889104*^9}, {3.877595409547923*^9, 3.877595422477371*^9}, {
   3.8775985279364033`*^9, 3.877598530308009*^9}, {3.8775988082865353`*^9, 
   3.877598879177938*^9}, {3.878636585084553*^9, 3.878636611580408*^9}, {
   3.8786385588177834`*^9, 3.8786385610075912`*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"565403d9-4fa1-4a62-8cf7-a59053ff8c31"],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["\[Integral]", 
   RowBox[{"-", 
    FractionBox["a", "2"]}], 
   FractionBox["a", "2"]], 
  RowBox[{
   RowBox[{"t", " ", "T", " ", "Y", " ", "\[Kappa]1", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"dYv", "[", "T", "]"}], "-", 
      RowBox[{"T", " ", "\[Kappa]3", " ", 
       RowBox[{"dYw", "[", "T", "]"}]}]}], ")"}]}], 
   RowBox[{"\[DifferentialD]", "T"}]}]}]], "Output",
 CellChangeTimes->{3.884086358950461*^9},
 CellLabel->"Out[32]=",ExpressionUUID->"a3ecadad-8f5b-4539-9a1c-24702c09793d"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Second order terms gradients (",
 Cell[BoxData[
  RowBox[{"h\[Dagger]", ".", " ", 
   SuperscriptBox["B", 
    RowBox[{"(", "1", ")"}]], ".", "z"}]],
  CellChangeTimes->{{3.876999716308838*^9, 3.876999719778428*^9}, {
    3.876999791262299*^9, 3.876999823148569*^9}, {3.876999966091852*^9, 
    3.876999988263636*^9}, {3.877000433521043*^9, 3.877000488885623*^9}, 
    3.877000838898486*^9, {3.877000890497925*^9, 3.877000919651627*^9}, {
    3.877002339293315*^9, 3.8770023412681837`*^9}, {3.8770024505128307`*^9, 
    3.877002455383127*^9}, {3.877002517741177*^9, 3.877002546092609*^9}, {
    3.877004056312842*^9, 3.877004115625627*^9}, {3.877004363315894*^9, 
    3.877004367884698*^9}, {3.877139755814892*^9, 3.877139757053953*^9}, {
    3.877142533228709*^9, 3.877142535111288*^9}, 3.877142665138546*^9, {
    3.877143419382751*^9, 3.87714343321734*^9}, {3.877143588609045*^9, 
    3.8771435899496098`*^9}, {3.877151616170932*^9, 3.877151616698037*^9}, {
    3.877324735567295*^9, 3.877324747264461*^9}, 3.877407822630435*^9, {
    3.8775223267905903`*^9, 3.877522361274061*^9}, 3.877524398091016*^9, {
    3.8775245021792803`*^9, 3.8775245198434763`*^9}, {3.8775246700027657`*^9, 
    3.877524682418738*^9}, {3.877532353741651*^9, 3.877532476873117*^9}, 
    3.877532509859695*^9, 3.8775799869985857`*^9},ExpressionUUID->
  "6d822f35-e309-4dd6-a5de-4416f760514a"],
 "  and  ",
 Cell[BoxData[
  RowBox[{"z", ".", " ", 
   SuperscriptBox["B", 
    RowBox[{"(", "2", ")"}]], ".", "z"}]],
  CellChangeTimes->{{3.8770006992073383`*^9, 3.877000707115068*^9}, {
    3.87700074290419*^9, 3.87700076226318*^9}, 3.877000798426526*^9, {
    3.8770008308440027`*^9, 3.8770008885164413`*^9}, {3.8770043294986*^9, 
    3.8770043505298033`*^9}, {3.877004567821703*^9, 3.8770045769380693`*^9}, {
    3.877004616275828*^9, 3.87700464266265*^9}, 3.877004673251775*^9, {
    3.877004717221848*^9, 3.877004725624597*^9}, {3.8770048353123837`*^9, 
    3.877004896227014*^9}, {3.877078603904949*^9, 3.877078623694674*^9}, {
    3.8771397590443087`*^9, 3.8771397602536383`*^9}, {3.877324711851568*^9, 
    3.877324727080205*^9}, {3.8775218354877987`*^9, 3.877521909865629*^9}, {
    3.877522379852137*^9, 3.8775224281916103`*^9}, {3.877522459645728*^9, 
    3.877522476259976*^9}, {3.877524690741798*^9, 3.877524706409527*^9}, {
    3.877532512959372*^9, 3.877532545849325*^9}, {3.8775328282943563`*^9, 
    3.877532829520975*^9}, {3.877532900227874*^9, 3.877532942604125*^9}, {
    3.877533113666583*^9, 3.8775331223748913`*^9}, {3.877533212250414*^9, 
    3.8775332134082193`*^9}},ExpressionUUID->
  "8b61518b-c4ba-4ee8-8d89-4e7cf77c3dee"],
 ")"
}], "Section",
 CellChangeTimes->{{3.876999716308838*^9, 3.876999719778428*^9}, {
   3.876999791262299*^9, 3.876999823148569*^9}, {3.876999966091852*^9, 
   3.876999988263636*^9}, {3.877000433521043*^9, 3.877000488885623*^9}, 
   3.877000838898486*^9, {3.877000890497925*^9, 3.877000919651627*^9}, {
   3.877002339293315*^9, 3.8770023412681837`*^9}, {3.8770024505128307`*^9, 
   3.877002455383127*^9}, {3.877002517741177*^9, 3.877002546092609*^9}, {
   3.877004056312842*^9, 3.877004115625627*^9}, {3.877004363315894*^9, 
   3.877004367884698*^9}, {3.877139755814892*^9, 3.877139757053953*^9}, {
   3.877142533228709*^9, 3.877142535111288*^9}, 3.877142665138546*^9, {
   3.877143419382751*^9, 3.87714343321734*^9}, {3.877143588609045*^9, 
   3.8771435899496098`*^9}, {3.877151616170932*^9, 3.877151616698037*^9}, {
   3.877324735567295*^9, 3.877324747264461*^9}, 3.877407822630435*^9, {
   3.8775223267905903`*^9, 3.877522361274061*^9}, 3.877524398091016*^9, {
   3.8775245021792803`*^9, 3.8775245198434763`*^9}, {3.8775246700027657`*^9, 
   3.877524682418738*^9}, {3.877532353741651*^9, 3.877532476873117*^9}, 
   3.877532509859695*^9, {3.8775799869985857`*^9, 3.877580029808872*^9}, {
   3.87758062199095*^9, 3.877580701041357*^9}, {3.877580832086339*^9, 
   3.877580832086488*^9}},ExpressionUUID->"8210c24d-24d5-4e23-8cbb-\
76ba0290b39e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"h\[Dagger]B1z", " ", "=", " ", 
     RowBox[{"h\[Dagger]", ".", 
      SuperscriptBox["B", 
       RowBox[{"(", "1", ")"}]], ".", "z"}]}], ",", "  ", 
    RowBox[{
     RowBox[{"terms", " ", "linear", " ", "in", " ", "z"}], ";", " ", 
     RowBox[{"see", " ", 
      RowBox[{"Eq", ".", " ", "5.13"}], " ", "in", " ", "the", " ", 
      "paper"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"first", "-", 
    RowBox[{"line", " ", "terms", " ", "in", " ", 
     RowBox[{"Eq", ".", " ", "5.13"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"t1dhB1z", " ", "=", " ", 
     RowBox[{"(", 
      RowBox[{"Km", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"dYv", "[", "T", "]"}], "-", 
         RowBox[{"T", " ", "\[Kappa]3", " ", 
          RowBox[{"dYw", "[", "T", "]"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "\[Kappa]2"}], " ", 
          RowBox[{"zw", "[", "T", "]"}]}], " ", "+", " ", 
         RowBox[{"\[Nu]", 
          RowBox[{"(", " ", 
           RowBox[{
            RowBox[{
             RowBox[{"zu", "'"}], "[", "T", "]"}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"Yw", "'"}], "[", "T", "]"}], 
             RowBox[{
              RowBox[{"zw", "'"}], "[", "T", "]"}]}]}], ")"}]}]}], ")"}]}], 
      ")"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"second", "-", 
     RowBox[{"line", " ", "terms", " ", "in", " ", 
      RowBox[{"Eq", ".", " ", "5.13"}]}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"t2dhB1z", " ", "=", 
     RowBox[{"(", "  ", 
      RowBox[{
       RowBox[{
        FractionBox["Km", "2"], "  ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Nu]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"dYu", "[", "T", "]"}], "+", " ", 
          RowBox[{
           RowBox[{"dYw", "[", "T", "]"}], 
           RowBox[{
            RowBox[{"Yw", "'"}], "[", "T", "]"}]}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"zv", "'"}], "[", "T", "]"}], "+", 
          RowBox[{"\[Kappa]3", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"zw", "[", "T", "]"}], "-", 
             RowBox[{"T", " ", 
              RowBox[{
               RowBox[{"zw", "'"}], "[", "T", "]"}]}]}], ")"}]}]}], ")"}]}], 
       "-", 
       RowBox[{"Db", " ", "\[Nu]", " ", "T", " ", "d\[Kappa]3", " ", 
        RowBox[{
         RowBox[{"zw", "''"}], "[", "T", "]"}]}]}], ")"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"third", "-", 
     RowBox[{"line", " ", "terms", " ", "in", " ", 
      RowBox[{"Eq", ".", " ", "5.13"}]}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"t3dhB1z", " ", "=", " ", 
     RowBox[{"-", 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"dn0SS", "[", "T", "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"zv", "[", "T", "]"}], "-", 
           RowBox[{"T", " ", "\[Kappa]3", " ", 
            RowBox[{"zw", "[", "T", "]"}]}]}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"n0SS", "[", "T", "]"}], "   ", "T", "  ", "d\[Kappa]3", " ", 
         RowBox[{"zw", "[", "T", "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"dm0ST", "[", "T", "]"}], 
         RowBox[{
          RowBox[{"zw", "'"}], "[", "T", "]"}]}]}], " ", ")"}]}]}], " ", 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.876999716308838*^9, 3.876999719778428*^9}, {
   3.876999791262299*^9, 3.876999823148569*^9}, {3.876999966091852*^9, 
   3.876999988263636*^9}, {3.877000433521043*^9, 3.877000488885623*^9}, 
   3.877000838898486*^9, {3.877000890497925*^9, 3.877000919651627*^9}, {
   3.877002339293315*^9, 3.8770023412681837`*^9}, {3.8770024505128307`*^9, 
   3.877002455383127*^9}, {3.877002517741177*^9, 3.877002546092609*^9}, {
   3.877004056312842*^9, 3.877004115625627*^9}, {3.877004363315894*^9, 
   3.877004367884698*^9}, {3.877139755814892*^9, 3.877139757053953*^9}, {
   3.877142533228709*^9, 3.877142535111288*^9}, 3.877142665138546*^9, {
   3.877143419382751*^9, 3.87714343321734*^9}, {3.877143588609045*^9, 
   3.8771435899496098`*^9}, {3.877151616170932*^9, 3.877151616698037*^9}, {
   3.877324735567295*^9, 3.877324747264461*^9}, 3.877407822630435*^9, {
   3.8775223267905903`*^9, 3.877522361274061*^9}, 3.877524398091016*^9, {
   3.8775245021792803`*^9, 3.8775245198434763`*^9}, {3.8775246700027657`*^9, 
   3.877524682418738*^9}, {3.877532353741651*^9, 3.877532476873117*^9}, 
   3.877532509859695*^9, 3.8775799869985857`*^9, {3.877580895083741*^9, 
   3.877580896322308*^9}, {3.877598895838613*^9, 3.877598937826038*^9}, {
   3.877608857106135*^9, 3.8776088728826847`*^9}, {3.878636625737328*^9, 
   3.8786366632608356`*^9}, {3.878636790778452*^9, 3.878636796854105*^9}, {
   3.87863860607104*^9, 3.878638614293393*^9}, 3.878639032003621*^9, 
   3.883986601319972*^9},
 CellLabel->"In[35]:=",ExpressionUUID->"e2aa353f-43fe-4f5a-802b-6feab5e6c672"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"zB2z", " ", "=", " ", 
     RowBox[{"z", ".", 
      SuperscriptBox["B", 
       RowBox[{"(", "2", ")"}]], ".", "z"}]}], ",", " ", 
    RowBox[{
     RowBox[{"terms", " ", "quadratic", " ", "in", " ", "z"}], ";", " ", 
     RowBox[{"see", " ", 
      RowBox[{"Eq", ".", " ", "5.14"}], " ", "in", " ", "the", " ", 
      "paper"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"first", "-", 
    RowBox[{"line", " ", "terms", " ", "in", " ", 
     RowBox[{"Eq", ".", " ", "5.14"}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"t1zB2z", " ", "=", " ", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Km", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"\[Kappa]2", " ", 
              RowBox[{"zw", "[", "T", "]"}]}], ")"}], "2"], " ", "+", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"zu", "'"}], "[", "T", "]"}], "+", 
              RowBox[{
               RowBox[{
                RowBox[{"Yw", "'"}], "[", "T", "]"}], " ", 
               RowBox[{
                RowBox[{"zw", "'"}], "[", "T", "]"}]}]}], ")"}], "2"]}], 
          ")"}]}], " ", "+", 
        RowBox[{"Db", " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"zw", "''"}], "[", "T", "]"}], "2"]}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"second", "-", 
     RowBox[{"line", " ", "terms", " ", "in", " ", 
      RowBox[{"Eq", ".", " ", "5.14"}]}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"t2zB2z", "=", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["Km", "2"], 
         RowBox[{"(", 
          RowBox[{"1", "-", "\[Nu]"}], ")"}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"zv", "'"}], "[", "T", "]"}], " ", "+", 
            RowBox[{"\[Kappa]3", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"zw", "[", "T", "]"}], "-", 
               RowBox[{"T", " ", 
                RowBox[{
                 RowBox[{"zw", "'"}], "[", "T", "]"}]}]}], ")"}]}]}], ")"}], 
          "2"]}], " ", "-", 
        RowBox[{"2", " ", "Km", " ", "\[Nu]", " ", "\[Kappa]2", " ", 
         RowBox[{"zw", "[", "T", "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"zu", "'"}], "[", "T", "]"}], "+", 
           RowBox[{
            RowBox[{
             RowBox[{"Yw", "'"}], "[", "T", "]"}], 
            RowBox[{
             RowBox[{"zw", "'"}], "[", "T", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8770006992073383`*^9, 3.877000707115068*^9}, {
   3.87700074290419*^9, 3.87700076226318*^9}, 3.877000798426526*^9, {
   3.8770008308440027`*^9, 3.8770008885164413`*^9}, {3.8770043294986*^9, 
   3.8770043505298033`*^9}, {3.877004567821703*^9, 3.8770045769380693`*^9}, {
   3.877004616275828*^9, 3.87700464266265*^9}, 3.877004673251775*^9, {
   3.877004717221848*^9, 3.877004725624597*^9}, {3.8770048353123837`*^9, 
   3.877004896227014*^9}, {3.877078603904949*^9, 3.877078623694674*^9}, {
   3.8771397590443087`*^9, 3.8771397602536383`*^9}, {3.877324711851568*^9, 
   3.877324727080205*^9}, {3.8775218354877987`*^9, 3.877521909865629*^9}, {
   3.877522379852137*^9, 3.8775224281916103`*^9}, {3.877522459645728*^9, 
   3.877522476259976*^9}, {3.877524690741798*^9, 3.877524706409527*^9}, {
   3.877532512959372*^9, 3.877532545849325*^9}, {3.8775328282943563`*^9, 
   3.877532829520975*^9}, {3.877532900227874*^9, 3.877532942604125*^9}, {
   3.877533113666583*^9, 3.8775331223748913`*^9}, {3.877533212250414*^9, 
   3.8775332134082193`*^9}, {3.8775989195921793`*^9, 3.877598933768714*^9}, {
   3.877608875574029*^9, 3.8776088800324507`*^9}, {3.878637870506062*^9, 
   3.878637906039126*^9}, {3.87863836704571*^9, 3.878638373337205*^9}, {
   3.8786388242952137`*^9, 3.87863883341726*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"a4d7ab47-70ad-4391-b38a-8ba96cfb794f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Derivation of differential equations", "Section",
 CellChangeTimes->{{3.877005105606927*^9, 3.877005157218639*^9}, {
   3.877006344512466*^9, 3.8770063867872257`*^9}, {3.877006472930174*^9, 
   3.8770064779212503`*^9}, {3.877011324028507*^9, 3.877011324626033*^9}, {
   3.877057769896278*^9, 3.877057781973106*^9}, 3.877141553355358*^9, {
   3.87714607089791*^9, 3.8771461119040413`*^9}, {3.877580049069813*^9, 
   3.8775800653410883`*^9}},ExpressionUUID->"e66c51fb-032a-45ae-8802-\
26cac61b4b95"],

Cell[CellGroupData[{

Cell["Potential and its variation", "Subsection",
 CellChangeTimes->{{3.877005105606927*^9, 3.877005157218639*^9}, {
   3.877006344512466*^9, 3.8770063867872257`*^9}, {3.877006472930174*^9, 
   3.8770064779212503`*^9}, {3.877011324028507*^9, 3.877011324626033*^9}, {
   3.877057769896278*^9, 3.877057781973106*^9}, 3.877141553355358*^9, {
   3.87714607089791*^9, 3.8771461119040413`*^9}, 3.877580049069813*^9, {
   3.877580924993475*^9, 
   3.877580936245672*^9}},ExpressionUUID->"6b3ee279-e312-4d6a-9500-\
2bcd09f3f139"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "potential", " ", "to", " ", "minimize", " ", "for", " ", "the", " ", "z", 
    " ", "solution"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"potToMinimize", "=", 
    RowBox[{
    "t1dhB1z", "+", "t2dhB1z", "+", "t3dhB1z", "+", "t1zB2z", "+", "t2zB2z", 
     "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"fS", " ", 
        RowBox[{"zv", "[", "T", "]"}]}], " ", "+", " ", 
       RowBox[{"fT", " ", 
        RowBox[{"zu", "[", "T", "]"}]}], " ", "+", " ", 
       RowBox[{"fN", " ", 
        RowBox[{"zw", "[", "T", "]"}]}], " ", "+", " ", 
       RowBox[{"gN", " ", "T", " ", 
        RowBox[{"zw", "[", "T", "]"}]}]}], ")"}]}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.877005105606927*^9, 3.877005157218639*^9}, {
   3.877006344512466*^9, 3.8770063867872257`*^9}, {3.877006472930174*^9, 
   3.8770064779212503`*^9}, {3.877011324028507*^9, 3.877011324626033*^9}, {
   3.877057769896278*^9, 3.877057781973106*^9}, 3.877141553355358*^9, {
   3.87714607089791*^9, 3.8771461119040413`*^9}, 3.877580049069813*^9, {
   3.877580924993475*^9, 3.877580932860489*^9}, 3.878637937686851*^9, {
   3.878639874640077*^9, 3.878639878734626*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"837230d0-cc4c-424e-a2b5-de9d8ba3fd55"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"minimize", " ", "rules"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"repRulesEta", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"zw", "->", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"zw", "[", "#", "]"}], "+", " ", 
           RowBox[{"\[Eta]", " ", 
            RowBox[{"\[Delta]zw", "[", "#", "]"}]}]}], ")"}], " ", "&"}], 
        ")"}]}], ",", 
      RowBox[{"zu", "->", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"zu", "[", "#", "]"}], "+", " ", 
           RowBox[{"\[Eta]", " ", 
            RowBox[{"\[Delta]zu", "[", "#", "]"}]}]}], ")"}], " ", "&"}], 
        ")"}]}], ",", " ", 
      RowBox[{"zv", "->", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"zv", "[", "#", "]"}], "+", " ", 
           RowBox[{"\[Eta]", " ", 
            RowBox[{"\[Delta]zv", "[", "#", "]"}]}]}], ")"}], " ", "&"}], 
        ")"}]}]}], "}"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.877005307986816*^9, 3.877005383834833*^9}, {
  3.8770063201274147`*^9, 3.8770063367915707`*^9}, {3.8770068724595613`*^9, 
  3.877006886830921*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"d21f47d6-285f-4c7b-b2c3-0cb9ae648818"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"variation", " ", "of", " ", "the", " ", "potential"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"eqToSolveForZ", "=", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"potToMinimize", "/.", "repRulesEta"}], ",", "\[Eta]"}], "]"}],
      "/.", 
     RowBox[{"{", 
      RowBox[{"\[Eta]", "->", " ", "0"}], "}"}]}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.877005307986816*^9, 3.877005383834833*^9}, {
   3.8770063201274147`*^9, 3.8770063367915707`*^9}, {3.8770068724595613`*^9, 
   3.87700688707023*^9}, 3.8770785240679617`*^9, {3.8771461002007437`*^9, 
   3.87714611870623*^9}, {3.8771516475685387`*^9, 3.877151647989135*^9}, {
   3.877599145960487*^9, 3.877599148503373*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"3fb1818b-244d-4fef-833c-375dbb0c4734"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Terms with \[Delta]zv and its derivatives ", "Subsection",
 CellChangeTimes->{{3.877580118511471*^9, 
  3.8775801478891172`*^9}},ExpressionUUID->"ecf546f6-ebcd-433c-b7ab-\
da15b3be26ed"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "collect", " ", "coefficients", " ", "of", " ", "\[Delta]zv", " ", "and", 
    " ", "its", " ", "derivatives", " ", "in", " ", "the", " ", "variation", 
    " ", "of", " ", "potential"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"eqZv", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{"eqToSolveForZ", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Delta]zw", "->", " ", 
           RowBox[{"(", 
            RowBox[{"0", "&"}], ")"}]}], ",", 
          RowBox[{"\[Delta]zu", "->", " ", 
           RowBox[{"(", 
            RowBox[{"0", "&"}], ")"}]}]}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Delta]zv", "[", "T", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Delta]zv", "'"}], "[", "T", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Delta]zv", "''"}], "[", "T", "]"}]}], "}"}], ",", 
      "FullSimplify"}], "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.8770056461077957`*^9, 3.877005667192342*^9}, {
   3.877005705558473*^9, 3.877005806394244*^9}, {3.877006190355116*^9, 
   3.8770061918453827`*^9}, {3.877022485481937*^9, 3.877022500781509*^9}, {
   3.8770532577413177`*^9, 3.877053272967491*^9}, {3.877061650480495*^9, 
   3.87706166296099*^9}, {3.877078498203377*^9, 3.877078512635633*^9}, {
   3.877139919058017*^9, 3.877139920464994*^9}, 3.877145268202771*^9, {
   3.877151655864447*^9, 3.877151656206232*^9}, 3.877151729471819*^9, {
   3.87740787150173*^9, 3.87740787720282*^9}, {3.877533052393346*^9, 
   3.8775330740924463`*^9}, 3.877533173831106*^9, {3.877533362001687*^9, 
   3.87753337480195*^9}, {3.8775801113961*^9, 3.877580114547283*^9}, {
   3.8776089615252657`*^9, 3.8776089772051563`*^9}, {3.8786384320982924`*^9, 
   3.8786384410401697`*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"18f8083a-5e7e-415a-acfc-96ef2e8c108f"],

Cell[BoxData[
 RowBox[{"(*", " ", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
     "Calculation", " ", "of", " ", "differential", " ", "equation", " ", 
      "for", " ", 
      RowBox[{"zv", ":", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Integral]", 
           RowBox[{
            RowBox[{"-", "a"}], "/", "2"}]], 
          RowBox[{"a", "/", "2"}]], " ", 
         RowBox[{"gv0", " ", "\[Delta]zv"}]}], " ", "+", " ", 
        RowBox[{"gv1", " ", 
         SubscriptBox["\[Delta]zv", 
          RowBox[{",", "T"}]], " ", "dT"}]}]}]}], "=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", 
        RowBox[{
         RowBox[{"-", "a"}], "/", "2"}]], 
       RowBox[{"a", "/", "2"}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"gv0", " ", "\[Delta]zv"}], " ", "+", " ", 
         SubscriptBox[
          RowBox[{"(", 
           RowBox[{"gv1", " ", "\[Delta]zv"}], ")"}], 
          RowBox[{",", "T"}]], " ", "-", 
         RowBox[{
          SubscriptBox["gv1", 
           RowBox[{",", "T"}]], " ", "\[Delta]zv"}]}], ")"}], " ", "dT"}]}], 
     "=", "0"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"gv0", " ", "-", 
          SubscriptBox["gv1", 
           RowBox[{",", "T"}]]}], ")"}], " ", "\[Delta]zv", " ", "dT"}]}], 
      " ", "+", "  ", 
      SuperscriptBox[
       SubscriptBox[
        RowBox[{"[", 
         RowBox[{"gv1", " ", "\[Delta]zv"}], "]"}], 
        RowBox[{
         RowBox[{"-", "a"}], "/", "2"}]], 
       RowBox[{"a", "/", "2"}]]}], "=", "0"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
     "we", " ", "get", " ", "natural", " ", "boundary", " ", "conditions", 
      " ", 
      RowBox[{"as", ":", " ", 
       RowBox[{"gv1", "[", 
        RowBox[{
         RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}]}], "=", "0"}]}], 
   ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "and", " ", "the", " ", "differential", " ", "equation", " ", "as", 
       "\[IndentingNewLine]", "gv0"}], " ", "-", 
      SubscriptBox["gv1", 
       RowBox[{",", "T"}]]}], " ", "=", "0"}], ";", "\[IndentingNewLine]", 
    RowBox[{"on", " ", "integrating"}]}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"we", " ", "get", "\[IndentingNewLine]", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["\[Integral]", "0"], "T"], 
        RowBox[{
         RowBox[{"gv0", "[", "m", "]"}], " ", "dm"}]}]}], " ", "-", " ", 
      "gv1", " ", "+", " ", "cv"}], " ", "=", "0"}], ";", " ", 
    RowBox[{
     RowBox[{"where", " ", "cv"}], " ", "=", " ", 
     RowBox[{"constant", " ", "of", " ", "integration"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"at", " ", "T"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "\[IndentingNewLine]", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Integral]", "0"], 
          RowBox[{"a", "/", "2"}]], 
         RowBox[{
          RowBox[{"gv0", "[", "m", "]"}], " ", "dm"}]}]}], " ", "-", " ", 
       RowBox[{"gv1", "[", 
        RowBox[{"a", "/", "2"}], "]"}], " ", "+", " ", "cv"}], " ", "=", " ", 
      "0"}]}], " ", ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", "0"], 
        RowBox[{
         RowBox[{"-", "a"}], "/", "2"}]], 
       RowBox[{
        RowBox[{"gv0", "[", "m", "]"}], " ", "dm"}]}], " ", "-", " ", 
      RowBox[{"gv1", "[", 
       RowBox[{
        RowBox[{"-", "a"}], "/", "2"}], "]"}], " ", "+", " ", "cv"}], " ", 
     "=", " ", "0"}], " ", ";", "\[IndentingNewLine]", 
    RowBox[{
    "using", " ", "the", " ", "natural", " ", "boundry", " ", 
     "conditions"}]}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"it", " ", "boils", " ", "to", "\[IndentingNewLine]", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["\[Integral]", "0"], 
         RowBox[{"a", "/", "2"}]], 
        RowBox[{
         RowBox[{"gv0", "[", "m", "]"}], " ", "dm"}]}]}], " ", "+", " ", 
      "cv"}], " ", "=", " ", "0"}], " ", ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", "0"], 
        RowBox[{
         RowBox[{"-", "a"}], "/", "2"}]], 
       RowBox[{
        RowBox[{"gv0", "[", "m", "]"}], " ", "dm"}]}], " ", "+", " ", "cv"}], 
     " ", "=", " ", "0"}], " ", ";", "\[IndentingNewLine]", 
    RowBox[{
    "we", " ", "use", " ", "these", " ", "boundary", " ", "conditions", " ", 
     "to", " ", "solve", " ", "for", " ", "cv", " ", "and", " ", "fS", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"contained", " ", "in", " ", "gv0"}], ")"}], "."}]}]}]}], 
  "\[IndentingNewLine]", "*)"}]], "Input",
 CellChangeTimes->{{3.8770056461077957`*^9, 3.877005667192342*^9}, {
   3.877005705558473*^9, 3.877005806394244*^9}, {3.877006190355116*^9, 
   3.8770061918453827`*^9}, {3.877022485481937*^9, 3.877022500781509*^9}, {
   3.8770532577413177`*^9, 3.877053272967491*^9}, {3.877061650480495*^9, 
   3.87706166296099*^9}, {3.877078498203377*^9, 3.877078512635633*^9}, {
   3.877139919058017*^9, 3.877139920464994*^9}, 3.877145268202771*^9, {
   3.877151655864447*^9, 3.877151656206232*^9}, 3.877151729471819*^9, {
   3.87740787150173*^9, 3.877407885380485*^9}},
 CellLabel->"In[44]:=",ExpressionUUID->"d806f8eb-1376-4abc-8581-6544c250fdc9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Identify", " ", "coefficients", " ", "of", " ", 
    RowBox[{"\[Delta]zv", "[", "T", "]"}], " ", "and", " ", 
    RowBox[{
     RowBox[{"\[Delta]zv", "'"}], "[", "T", "]"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"gv0", "=", " ", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"eqZv", ",", 
      RowBox[{"\[Delta]zv", "[", "T", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gv1", "=", " ", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"eqZv", ",", 
       RowBox[{
        RowBox[{"\[Delta]zv", "'"}], "[", "T", "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"sanity", " ", 
     RowBox[{"check", ":", " ", 
      RowBox[{"only", " ", "two", " ", "terms", " ", 
       RowBox[{"(", 
        RowBox[{"gv0", ",", " ", "gv1"}], ")"}], " ", "are", " ", 
       "associated", " ", "with", " ", "\[Delta]zv", " ", "and", " ", "its", 
       " ", "derivatives"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"If", "[", 
    RowBox[{"doSanityCheck", ",", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"gv0", "  ", 
          RowBox[{"\[Delta]zv", "[", "T", "]"}]}], "  ", "+", " ", 
         RowBox[{"gv1", " ", 
          RowBox[{
           RowBox[{"\[Delta]zv", "'"}], "[", "T", "]"}]}], "-", "eqZv"}], 
        "]"}], "==", "0"}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8770056461077957`*^9, 3.877005667192342*^9}, {
   3.877005705558473*^9, 3.877005806394244*^9}, {3.877006190355116*^9, 
   3.8770061918453827`*^9}, {3.877022485481937*^9, 3.877022500781509*^9}, {
   3.8770532577413177`*^9, 3.877053272967491*^9}, {3.877061650480495*^9, 
   3.87706166296099*^9}, {3.877078498203377*^9, 3.877078512635633*^9}, {
   3.877139919058017*^9, 3.877139920464994*^9}, 3.877145268202771*^9, {
   3.877151655864447*^9, 3.877151656206232*^9}, 3.877151729471819*^9, {
   3.87740787150173*^9, 3.877407885380485*^9}, {3.877408781538498*^9, 
   3.877408783007053*^9}, {3.877408973913196*^9, 3.877408984837072*^9}, {
   3.877409036826066*^9, 3.877409037184092*^9}, 3.877509233179229*^9, {
   3.877533175416244*^9, 3.877533178239052*^9}, {3.8775955162338457`*^9, 
   3.87759552211724*^9}, {3.8776001812839403`*^9, 3.877600281829035*^9}, {
   3.877609068025791*^9, 3.877609068692906*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"8031dd7d-2318-41bb-84a6-00643ed43f94"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "fS"}], "-", 
  RowBox[{"dn0SS", "[", "T", "]"}]}]], "Output",
 CellChangeTimes->{3.88408688896983*^9},
 CellLabel->"Out[45]=",ExpressionUUID->"79a7d843-e3f9-4a06-96fe-b20deadb5adf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"we", " ", "write", " ", "igv0"}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["\[Integral]", "0"], "T"], " ", 
     RowBox[{
      RowBox[{"gv0", "[", "m", "]"}], " ", "dm"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"igv0", "[", "T_", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "T"}], " ", "fS"}], " ", "-", " ", 
    RowBox[{"idn0SS", "[", "T", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.877022513712929*^9, 3.877022516973556*^9}, {
   3.877053704553198*^9, 3.877053878151829*^9}, {3.877053927770347*^9, 
   3.8770539708771276`*^9}, {3.877054005678164*^9, 3.8770540984145823`*^9}, {
   3.877054172339796*^9, 3.8770542044057407`*^9}, {3.877054272363752*^9, 
   3.877054361658428*^9}, {3.8770544146945953`*^9, 3.877054629323852*^9}, {
   3.8770547469068613`*^9, 3.877054754411489*^9}, {3.8770547845039253`*^9, 
   3.87705481982298*^9}, {3.8770548715690413`*^9, 3.877054893102345*^9}, {
   3.877054928676278*^9, 3.8770549923643303`*^9}, {3.877055023972196*^9, 
   3.877055172801949*^9}, 3.8770553087096243`*^9, {3.877055987277916*^9, 
   3.877055993380925*^9}, {3.87705606612225*^9, 3.8770560699863253`*^9}, {
   3.877056152687504*^9, 3.877056263910925*^9}, {3.877056316465229*^9, 
   3.877056334521469*^9}, {3.877056389953575*^9, 3.877056517645081*^9}, {
   3.877056596651601*^9, 3.8770566681631327`*^9}, {3.877056909972349*^9, 
   3.877056938805242*^9}, {3.877057635329927*^9, 3.877057684988014*^9}, {
   3.877059894787829*^9, 3.87705989536189*^9}, {3.877139860995453*^9, 
   3.877139862297923*^9}, 3.877142550440325*^9, {3.8771435074330997`*^9, 
   3.877143511619226*^9}, 3.8771436621533747`*^9, {3.8771519346215677`*^9, 
   3.877151935119718*^9}, {3.8771558866910057`*^9, 3.8771558873151627`*^9}, {
   3.877156148243258*^9, 3.877156150835207*^9}, 3.8772278918089867`*^9},
 CellLabel->"In[48]:=",ExpressionUUID->"07b23b9b-58eb-48ed-a764-18cae13f6a1b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "fS"}], " ", "T"}], "-", 
  RowBox[{"idn0SS", "[", "T", "]"}]}]], "Output",
 CellChangeTimes->{3.884086888972191*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"37ac0217-ffb7-47fc-86f2-fb039397432f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"we", " ", "solve", " ", "for", " ", "fS", " ", 
     RowBox[{"(", 
      RowBox[{"gv0", " ", "contains", " ", "fS"}], ")"}], " ", "and", " ", 
     "Cv"}], ",", " ", 
    RowBox[{"and", " ", "obtain", " ", "them", " ", "as"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"cvExpCalculated", "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"cv", "/.", 
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"igv0", "[", 
               RowBox[{"a", "/", "2"}], "]"}], "+", " ", "cv"}], "==", "0"}], 
            ",", 
            RowBox[{
             RowBox[{
              RowBox[{"igv0", "[", 
               RowBox[{
                RowBox[{"-", "a"}], "/", "2"}], "]"}], "+", " ", "cv"}], "==",
              "0"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"cv", ",", "fS"}], "}"}], ",", 
          RowBox[{"Assumptions", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"a", ">", "0"}], "}"}]}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fSExpCalculated", "=", " ", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"fS", "/.", 
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"igv0", "[", 
               RowBox[{"a", "/", "2"}], "]"}], "+", " ", "cv"}], "==", "0"}], 
            ",", 
            RowBox[{
             RowBox[{
              RowBox[{"igv0", "[", 
               RowBox[{
                RowBox[{"-", "a"}], "/", "2"}], "]"}], "+", " ", "cv"}], "==",
              "0"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"cv", ",", "fS"}], "}"}], ",", 
          RowBox[{"Assumptions", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"a", ">", "0"}], "}"}]}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.877022513712929*^9, 3.877022516973556*^9}, {
   3.877053704553198*^9, 3.877053878151829*^9}, {3.877053927770347*^9, 
   3.8770539708771276`*^9}, {3.877054005678164*^9, 3.8770540984145823`*^9}, {
   3.877054172339796*^9, 3.8770542044057407`*^9}, {3.877054272363752*^9, 
   3.877054361658428*^9}, {3.8770544146945953`*^9, 3.877054629323852*^9}, {
   3.8770547469068613`*^9, 3.877054754411489*^9}, {3.8770547845039253`*^9, 
   3.87705481982298*^9}, {3.8770548715690413`*^9, 3.877054893102345*^9}, {
   3.877054928676278*^9, 3.8770549923643303`*^9}, {3.877055023972196*^9, 
   3.877055172801949*^9}, 3.8770553087096243`*^9, {3.877055987277916*^9, 
   3.877055993380925*^9}, {3.87705606612225*^9, 3.8770560699863253`*^9}, {
   3.877056152687504*^9, 3.877056164781526*^9}, {3.877057448436517*^9, 
   3.877057582965824*^9}, {3.877057629974504*^9, 3.877057631151331*^9}, {
   3.877059711294903*^9, 3.87705973313157*^9}, {3.877059836723999*^9, 
   3.877059864150763*^9}, {3.877059900639308*^9, 3.877059920500038*^9}, {
   3.877060159856443*^9, 3.8770601745690947`*^9}, {3.877061190857645*^9, 
   3.8770611929640408`*^9}, {3.877061243325235*^9, 3.8770612611415997`*^9}, {
   3.877142088895666*^9, 3.8771420898572206`*^9}, {3.877143528035759*^9, 
   3.877143530858358*^9}, {3.8771521904316797`*^9, 3.877152200743718*^9}, 
   3.8776003021243687`*^9, 3.883987101600708*^9},
 CellLabel->"In[49]:=",ExpressionUUID->"5264fe7f-6cf4-4645-b76a-6d14a08f9b29"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"proposed", " ", "cv"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"cvExp", " ", "=", 
     RowBox[{
      FractionBox["1", "8"], " ", "t", " ", "Y", " ", 
      SuperscriptBox["a", "2"], " ", "d\[Kappa]1"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"If", "[", 
    RowBox[{"doSanityCheck", ",", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"cvExp", " ", "-", " ", "cvExpCalculated"}], "/.", 
         RowBox[{"{", 
          RowBox[{"idn0SS", "->", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"idn0SSExp", "[", "#", "]"}], "&"}], ")"}]}], "}"}]}], 
        "]"}], "==", "0"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"proposed", " ", "fS"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fSExp", "=", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "12"]}], " ", "t", " ", "Y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"12", " ", "d\[Epsilon]"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "d\[Kappa]3", " ", "\[Kappa]3"}]}], 
       ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"proposed", " ", "and", " ", "calculated", " ", "values", " ", 
     RowBox[{"equal", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"If", "[", 
    RowBox[{"doSanityCheck", ",", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"fSExp", "-", "fSExpCalculated"}], ")"}], "/.", 
         RowBox[{"{", 
          RowBox[{"idn0SS", "->", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"idn0SSExp", "[", "#", "]"}], "&"}], ")"}]}], "}"}]}], 
        "]"}], "==", "0"}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.877060043824081*^9, 3.877060073160631*^9}, {
   3.877060107925115*^9, 3.877060140491888*^9}, {3.8770603605650806`*^9, 
   3.8770603911685057`*^9}, {3.87706049377262*^9, 3.877060606804925*^9}, {
   3.877060722562911*^9, 3.877060760612526*^9}, {3.877060944236978*^9, 
   3.8770609476989527`*^9}, {3.877061100787385*^9, 3.877061185053154*^9}, {
   3.877076662887693*^9, 3.877076663625435*^9}, {3.877142095634777*^9, 
   3.877142103667554*^9}, {3.877142563775569*^9, 3.877142566514224*^9}, {
   3.87714369347083*^9, 3.877143696668911*^9}, {3.87750923433976*^9, 
   3.877509235700244*^9}, {3.877595529525285*^9, 3.877595541841855*^9}, {
   3.877600311340048*^9, 3.877600341804401*^9}, 3.8839871132179613`*^9},
 CellLabel->"In[51]:=",ExpressionUUID->"f4837019-e190-49ff-857e-b1a011aa50f4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "setting", " ", "the", " ", "expressions", " ", "of", " ", "cv", " ", 
     "and", " ", "fS", " ", "back", " ", "in", " ", "the", " ", "differntial",
      " ", "equation", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Integral]", "0"], "T"], 
         RowBox[{
          RowBox[{"gv0", "[", "m", "]"}], " ", "dm"}]}], " ", "-", " ", "gv1",
         " ", "+", " ", "Cv"}], " ", "=", "0"}], ")"}]}], ",", " ", 
    RowBox[{"we", " ", 
     RowBox[{"get", ":"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"diffEqnZv", " ", "=", " ", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"igv0", "[", "T", "]"}], "-", "gv1", "+", "cvExp"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fS", "->", " ", "fSExp"}], ",", " ", 
         RowBox[{"idn0SS", "->", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"idn0SSfn", "[", "#", "]"}], "&"}], ")"}]}]}], "}"}]}], 
      "]"}], ",", 
     RowBox[{
      RowBox[{"zv", "'"}], "[", "T", "]"}], ",", "FullSimplify"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.877022513712929*^9, 3.877022516973556*^9}, {
   3.877053704553198*^9, 3.877053878151829*^9}, {3.877053927770347*^9, 
   3.8770539708771276`*^9}, {3.877054005678164*^9, 3.8770540984145823`*^9}, {
   3.877054172339796*^9, 3.8770542044057407`*^9}, {3.877054272363752*^9, 
   3.877054361658428*^9}, {3.8770544146945953`*^9, 3.877054629323852*^9}, {
   3.8770547469068613`*^9, 3.877054754411489*^9}, {3.8770547845039253`*^9, 
   3.87705481982298*^9}, {3.8770548715690413`*^9, 3.877054893102345*^9}, {
   3.877054928676278*^9, 3.8770549923643303`*^9}, {3.877055023972196*^9, 
   3.877055172801949*^9}, 3.8770553087096243`*^9, {3.877055987277916*^9, 
   3.877055993380925*^9}, {3.87705606612225*^9, 3.8770560699863253`*^9}, {
   3.877056152687504*^9, 3.877056164781526*^9}, {3.877057448436517*^9, 
   3.877057582965824*^9}, 3.877057629974504*^9, 3.877061239038818*^9, {
   3.877061535943677*^9, 3.877061537599843*^9}, {3.8770766985244217`*^9, 
   3.877076812499345*^9}, {3.877076903820915*^9, 3.87707695883564*^9}, {
   3.877077309118314*^9, 3.877077319939056*^9}, {3.87707793574288*^9, 
   3.877077937712892*^9}, {3.877142105241219*^9, 3.877142106546664*^9}, {
   3.877142569927475*^9, 3.877142570658235*^9}, {3.877143708002226*^9, 
   3.8771437088654737`*^9}, {3.877409047394799*^9, 3.877409047760593*^9}, 
   3.877532895131559*^9, {3.8776003590983477`*^9, 3.877600360004822*^9}},
 CellLabel->"In[55]:=",ExpressionUUID->"a041d4d2-6491-4c4c-9c02-a694097a3560"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "Km", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[Nu]"}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["zv", "\[Prime]",
     MultilineFunction->None], "[", "T", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "24"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"t", " ", "Y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["T", "2"]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "d\[Kappa]1"}], "+", 
           RowBox[{"2", " ", "d\[Kappa]3", " ", "T", " ", "\[Kappa]3"}]}], 
          ")"}]}], "+", 
        RowBox[{"24", " ", "\[Kappa]2", " ", 
         RowBox[{"idYw", "[", "T", "]"}]}], "+", 
        RowBox[{"24", " ", "d\[Kappa]2", " ", 
         RowBox[{"iYw", "[", "T", "]"}]}]}], ")"}]}], "+", 
     RowBox[{"12", " ", "Km", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Nu]"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"dYu", "[", "T", "]"}], "+", 
        RowBox[{"\[Kappa]3", " ", 
         RowBox[{"zw", "[", "T", "]"}]}], "+", 
        RowBox[{
         RowBox[{"dYw", "[", "T", "]"}], " ", 
         RowBox[{
          SuperscriptBox["Yw", "\[Prime]",
           MultilineFunction->None], "[", "T", "]"}]}], "-", 
        RowBox[{"T", " ", "\[Kappa]3", " ", 
         RowBox[{
          SuperscriptBox["zw", "\[Prime]",
           MultilineFunction->None], "[", "T", "]"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.8840868892036877`*^9},
 CellLabel->"Out[55]=",ExpressionUUID->"5f5dc54a-cd81-457e-95da-04d87dea650a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "In", " ", "the", " ", "above", " ", "differential", " ", "equation"}], 
    ",", " ", 
    RowBox[{"we", " ", "collect", " ", 
     SubscriptBox["zv", 
      RowBox[{",", "T"}]], " ", "on", " ", "left", " ", "hand", " ", "side", 
     " ", "and", " ", "rest", " ", "of", " ", "the", " ", "terms", " ", "on", 
     " ", "right", " ", "hand", " ", "side", " ", "as"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"zvDT", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"zv", "'"}], "[", "T", "]"}], "/.", 
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Collect", "[", 
            RowBox[{
             RowBox[{"Simplify", "[", 
              RowBox[{"diffEqnZv", "/", " ", 
               RowBox[{"(", 
                RowBox[{
                 FractionBox["1", "2"], " ", "Km", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "\[Nu]"}], ")"}]}], " ", ")"}]}], 
              "]"}], ",", 
             RowBox[{
              RowBox[{"zv", "'"}], "[", "T", "]"}], ",", "FullSimplify"}], 
            "]"}], "==", "0"}], ",", 
          RowBox[{
           RowBox[{"zv", "'"}], "[", "T", "]"}], ",", 
          RowBox[{"Assumptions", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Km", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "\[Nu]"}], ")"}]}], "\[NotEqual]", 
             "0"}], "}"}]}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"zw", "[", "T", "]"}], ",", 
        RowBox[{
         RowBox[{"zw", "'"}], "[", "T", "]"}], ",", 
        RowBox[{
         RowBox[{"zw", "''"}], "[", "T", "]"}]}], "}"}], ",", 
      "FullSimplify"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "We", " ", "have", " ", "a", "  ", "first", " ", "order", " ", 
      "differential", " ", 
      RowBox[{"equation", ".", " ", "Once"}], " ", "zw", " ", "is", " ", 
      "known"}], ",", " ", 
     RowBox[{
      RowBox[{
      "we", " ", "can", " ", "solve", " ", "it", " ", "in", " ", "conjuction",
        " ", "with", " ", "the", " ", "integral", " ", "constraint", " ", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["\[Integral]", 
          RowBox[{
           RowBox[{"-", "a"}], "/", "2"}]], 
         RowBox[{"a", "/", "2"}]], " ", 
        RowBox[{"zv", " ", "dT"}]}]}], " ", "=", " ", 
      RowBox[{"0", "  ", "for", " ", "zv"}]}]}], " ", "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.877077485266654*^9, 3.877077512618775*^9}, {
   3.87707764985079*^9, 3.87707777119314*^9}, {3.877077940731495*^9, 
   3.8770779427916517`*^9}, {3.8770820685160646`*^9, 
   3.8770820724413347`*^9}, {3.877151913837326*^9, 3.877151914370894*^9}, 
   3.877532519302927*^9, 3.877532549915806*^9, 3.8775328974578047`*^9, {
   3.8776003733064823`*^9, 3.877600462095469*^9}},
 CellLabel->"In[56]:=",ExpressionUUID->"2fe3840e-93d2-4d76-8599-4fab340d5363"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"dYu", "[", "T", "]"}]}], "-", 
  FractionBox[
   RowBox[{"t", " ", "Y", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["T", "2"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "d\[Kappa]1"}], "+", 
         RowBox[{"2", " ", "d\[Kappa]3", " ", "T", " ", "\[Kappa]3"}]}], 
        ")"}]}], "+", 
      RowBox[{"24", " ", "\[Kappa]2", " ", 
       RowBox[{"idYw", "[", "T", "]"}]}], "+", 
      RowBox[{"24", " ", "d\[Kappa]2", " ", 
       RowBox[{"iYw", "[", "T", "]"}]}]}], ")"}]}], 
   RowBox[{"12", " ", "Km", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Nu]"}], ")"}]}]], "-", 
  RowBox[{"\[Kappa]3", " ", 
   RowBox[{"zw", "[", "T", "]"}]}], "-", 
  RowBox[{
   RowBox[{"dYw", "[", "T", "]"}], " ", 
   RowBox[{
    SuperscriptBox["Yw", "\[Prime]",
     MultilineFunction->None], "[", "T", "]"}]}], "+", 
  RowBox[{"T", " ", "\[Kappa]3", " ", 
   RowBox[{
    SuperscriptBox["zw", "\[Prime]",
     MultilineFunction->None], "[", "T", "]"}]}]}]], "Output",
 CellChangeTimes->{3.884086889760161*^9},
 CellLabel->"Out[56]=",ExpressionUUID->"5a7304ca-0d58-4f35-82e9-b119e4f0e82b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Terms with \[Delta]zu and its derivatives ", "Subsection",
 CellChangeTimes->{{3.877077814628242*^9, 3.877077832239193*^9}, {
  3.877078007699695*^9, 3.877078022770813*^9}, {3.877078463882415*^9, 
  3.87707847019411*^9}, {3.8770788337372713`*^9, 3.877078856901472*^9}, {
  3.8770792699972754`*^9, 3.877079283634603*^9}, {3.87708059214437*^9, 
  3.877080746281103*^9}, {3.877080784083632*^9, 3.877080873180328*^9}, {
  3.877080977334309*^9, 3.8770809985672626`*^9}, {3.877081100754863*^9, 
  3.87708115591438*^9}, {3.8773699785780487`*^9, 3.8773699790535088`*^9}, {
  3.877407296966362*^9, 3.877407298637247*^9}, {3.8774079646721582`*^9, 
  3.87740797257723*^9}, {3.877523017657322*^9, 3.87752304904379*^9}, {
  3.877580168300372*^9, 
  3.877580184541004*^9}},ExpressionUUID->"9b7feb6f-bab4-421b-991f-\
7e76ae3ff93f"],

Cell[BoxData[
 RowBox[{"(*", " ", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
     "calculation", " ", "of", " ", "differential", " ", "equation", " ", 
      "for", " ", 
      RowBox[{"zu", ":", " ", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Integral]", 
           RowBox[{
            RowBox[{"-", "a"}], "/", "2"}]], 
          RowBox[{"a", "/", "2"}]], " ", 
         RowBox[{
          RowBox[{"-", "fT"}], " ", "\[Delta]zu"}]}], " ", "+", " ", 
        RowBox[{"gu1", " ", 
         SubscriptBox["\[Delta]zu", 
          RowBox[{",", "T"}]], " ", "dT"}]}]}]}], " ", "=", " ", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"fT", " ", "+", " ", 
           SubscriptBox["gu1", 
            RowBox[{",", "T"}]]}], ")"}]}], " ", "\[Delta]zu", " ", "dT"}]}], 
      "+", " ", 
      SuperscriptBox[
       SubscriptBox[
        RowBox[{"[", 
         RowBox[{"gu1", " ", "\[Delta]zu"}], "]"}], 
        RowBox[{
         RowBox[{"-", "a"}], "/", "2"}]], 
       RowBox[{"a", "/", "2"}]]}], " ", "=", " ", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
     "we", " ", "get", " ", "natural", " ", "boundary", " ", "conditions", 
      " ", 
      RowBox[{"as", ":", " ", 
       RowBox[{"gu1", "[", 
        RowBox[{
         RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}]}], "=", "0"}]}], 
   ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "and", " ", "the", " ", "differential", " ", "equation", " ", "as", 
      "\[IndentingNewLine]", "fT"}], "+", " ", 
     SubscriptBox["gu1", 
      RowBox[{",", "T"}]]}], " ", "=", " ", 
    RowBox[{"0.", "\[IndentingNewLine]", "On", " ", "integrating"}]}], ",", 
   " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"we", " ", "get", "\[IndentingNewLine]", "fT", " ", "T"}], " ", 
      "+", " ", "gu1", " ", "+", " ", "cu"}], " ", "=", "0"}], ";", " ", 
    RowBox[{
     RowBox[{"where", " ", "cu"}], " ", "=", " ", 
     RowBox[{"constant", " ", "of", " ", "integration"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"at", " ", "T"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "\[IndentingNewLine]", 
        "fT", " ", 
        RowBox[{"(", 
         FractionBox["a", "2"], ")"}]}], " ", "+", " ", 
       RowBox[{"gu1", "[", 
        FractionBox["a", "2"], "]"}], " ", "+", " ", "cu"}], " ", "=", " ", 
      "0"}]}], " ", ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"fT", " ", 
       RowBox[{"(", 
        RowBox[{"-", 
         FractionBox["a", "2"]}], ")"}]}], " ", "+", " ", 
      RowBox[{"gu1", "[", 
       RowBox[{"-", 
        FractionBox["a", "2"]}], "]"}], " ", "+", " ", "cu"}], " ", "=", " ", 
     "0"}], " ", ";", "\[IndentingNewLine]", 
    RowBox[{
    "using", " ", "the", " ", "natural", " ", "boundary", " ", 
     "conditions"}]}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"it", " ", "boils", " ", "to", "\[IndentingNewLine]", "fT", " ", 
       RowBox[{"(", 
        FractionBox["a", "2"], ")"}]}], "  ", "+", " ", "cu"}], " ", "=", " ",
      "0"}], " ", ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"fT", " ", 
       RowBox[{"(", 
        RowBox[{"-", 
         FractionBox["a", "2"]}], ")"}]}], " ", "+", " ", "cu"}], " ", "=", 
     " ", "0"}], " ", ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"which", " ", "gives", " ", "us", " ", "fT"}], " ", "=", " ", 
     "0"}]}], ",", " ", 
   RowBox[{
    RowBox[{"cu", " ", "=", " ", "0"}], ";", " ", 
    RowBox[{
     RowBox[{
     "and", " ", "therefore", " ", "the", " ", "differential", " ", 
      "equation", " ", "\[IndentingNewLine]", "gu1"}], " ", "=", " ", 
     RowBox[{
     "0.", "\[IndentingNewLine]", "It", " ", "is", " ", "a", " ", "first", 
      " ", "order", " ", "differential", " ", 
      RowBox[{"equation", ".", " ", "Once"}], " ", "zw", " ", "is", " ", 
      "known"}]}]}], ",", " ", 
   RowBox[{
    RowBox[{
    "we", " ", "can", " ", "solve", " ", "it", " ", "in", " ", "conjuction", 
     " ", "with", " ", "the", " ", "integral", " ", "constraint", " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", 
        RowBox[{
         RowBox[{"-", "a"}], "/", "2"}]], 
       RowBox[{"a", "/", "2"}]], " ", 
      RowBox[{"zu", " ", "dT"}]}]}], " ", "=", " ", "0"}]}], " ", 
  "\[IndentingNewLine]", "*)"}]], "Input",
 CellChangeTimes->{{3.877077814628242*^9, 3.877077832239193*^9}, {
   3.877078007699695*^9, 3.877078022770813*^9}, {3.877078463882415*^9, 
   3.87707847019411*^9}, {3.8770788337372713`*^9, 3.877078856901472*^9}, {
   3.8770792699972754`*^9, 3.877079283634603*^9}, {3.87708059214437*^9, 
   3.877080746281103*^9}, {3.877080784083632*^9, 3.877080873180328*^9}, {
   3.877080977334309*^9, 3.8770809985672626`*^9}, {3.877081100754863*^9, 
   3.87708115591438*^9}, {3.8773699785780487`*^9, 3.8773699790535088`*^9}, {
   3.877407296966362*^9, 3.877407298637247*^9}, {3.8774079646721582`*^9, 
   3.87740797257723*^9}, {3.877523017657322*^9, 3.87752304904379*^9}, 
   3.877580168300372*^9, {3.8776004976064043`*^9, 3.877600526246148*^9}, {
   3.88398731396736*^9, 3.883987316958315*^9}},
 CellLabel->"In[57]:=",ExpressionUUID->"d9d8002a-5b39-41b4-a548-ffbd4c07c1b4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"eqZu", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{"eqToSolveForZ", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Delta]zw", "->", " ", 
           RowBox[{"(", 
            RowBox[{"0", "&"}], ")"}]}], ",", 
          RowBox[{"\[Delta]zv", "->", " ", 
           RowBox[{"(", 
            RowBox[{"0", "&"}], ")"}]}]}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Delta]zu", "[", "T", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Delta]zu", "'"}], "[", "T", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Delta]zu", "''"}], "[", "T", "]"}]}], "}"}], ",", 
      "FullSimplify"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"collect", " ", "coefficient", " ", "of", " ", 
    SubscriptBox["\[Delta]zu", 
     RowBox[{",", "T"}]], " ", "in", " ", "the", " ", "variation", " ", "of", 
    " ", "potential"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gu1", "=", " ", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"eqZu", ",", 
      RowBox[{
       RowBox[{"\[Delta]zu", "'"}], "[", "T", "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"sanity", " ", 
    RowBox[{"check", ":", " ", 
     RowBox[{"only", " ", "two", " ", "terms", " ", 
      RowBox[{"(", 
       RowBox[{"gu0", ",", " ", "fT"}], ")"}], " ", "are", " ", "associated", 
      " ", "with", " ", "\[Delta]zu", " ", "and", " ", "its", " ", 
      "derivatives", " ", "in", " ", "the", " ", "variation", " ", "of", " ", 
      "potential"}]}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"If", "[", 
  RowBox[{"doSanityCheck", ",", 
   RowBox[{"CheckSanity", "[", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"gu1", " ", 
        RowBox[{
         RowBox[{"\[Delta]zu", "'"}], "[", "T", "]"}]}], "-", 
       RowBox[{"fT", " ", 
        RowBox[{"\[Delta]zu", "[", "T", "]"}]}], "-", "eqZu"}], "]"}], "==", 
     "0"}], "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.877077814628242*^9, 3.877077832239193*^9}, {
   3.877078007699695*^9, 3.877078022770813*^9}, {3.877078463882415*^9, 
   3.877078470701952*^9}, {3.877081949186699*^9, 3.877081966588032*^9}, {
   3.8770820514589443`*^9, 3.877082052840279*^9}, {3.877082340558381*^9, 
   3.8770823889757*^9}, {3.8770827262357407`*^9, 3.877082760095502*^9}, {
   3.8770828076886253`*^9, 3.8770828140086193`*^9}, 3.877509236874682*^9, {
   3.8775327654136267`*^9, 3.8775327814347973`*^9}, {3.877595545709523*^9, 
   3.8775955572249737`*^9}, {3.8776005557086763`*^9, 3.877600579864785*^9}, {
   3.877600841409259*^9, 3.877600934616497*^9}, {3.8776089860044727`*^9, 
   3.877608989234077*^9}},
 CellLabel->"In[58]:=",ExpressionUUID->"0fe2909e-1d14-4177-b189-c68e840bf172"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "In", " ", "the", " ", "differential", " ", "equation", " ", "gu1"}], 
     " ", "=", " ", "0"}], ",", " ", 
    RowBox[{"we", " ", "collect", " ", 
     SubscriptBox["zu", 
      RowBox[{",", "T"}]], " ", "on", " ", "left", " ", "hand", " ", "side", 
     " ", "and", " ", "rest", " ", "of", " ", "the", " ", "terms", " ", "on", 
     " ", "right", " ", "hand", " ", "side", " ", "as"}]}], " ", "*)"}], " ", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"zuDTCalculated", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"zu", "'"}], "[", "T", "]"}], "/.", 
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Simplify", "[", 
             RowBox[{"gu1", "/", "Km"}], "]"}], "==", "0"}], ",", 
           RowBox[{
            RowBox[{"zu", "'"}], "[", "T", "]"}]}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"a", ">", "0"}], ",", 
          RowBox[{"0", "<", "t", "<", "a"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"we", " ", "propose", " ", "expression", " ", "for", " ", 
     SubscriptBox["zu", 
      RowBox[{",", "T"}]]}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"zuDT", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", " ", "\[Nu]"}], " ", 
       RowBox[{"dYv", "[", "T", "]"}]}], "+", 
      RowBox[{"T", " ", "\[Kappa]3", " ", "\[Nu]", " ", 
       RowBox[{"dYw", "[", "T", "]"}]}], "+", 
      RowBox[{"\[Kappa]2", " ", "\[Nu]", " ", 
       RowBox[{"zw", "[", "T", "]"}]}], "-", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Yw", "'"}], "[", "T", "]"}], " ", 
       RowBox[{
        RowBox[{"zw", "'"}], "[", "T", "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Are", " ", "proposed", " ", "and", " ", "calculated", " ", "expressions",
      " ", 
     RowBox[{"equal", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"If", "[", 
    RowBox[{"doSanityCheck", ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"CheckSanity", "[", 
       RowBox[{
        RowBox[{"Simplify", "[", 
         RowBox[{"zuDT", "-", "zuDTCalculated"}], "]"}], "==", "0"}], "]"}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"CheckSanity", "[", 
       RowBox[{
        RowBox[{"Simplify", "[", 
         RowBox[{"gu1", "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"zu", "'"}], "[", "T", "]"}], "->", " ", "zuDT"}], 
           "}"}]}], "]"}], "==", "0"}], "]"}], ";"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"The", " ", "equation", " ", "above", "  ", 
      RowBox[{"(", 
       RowBox[{"zuDT", "=", " ", ".."}], " ", ")"}], " ", "is", " ", "a", " ",
       "first", " ", "order", " ", "differential", " ", 
      RowBox[{"equation", ".", " ", "Once"}], " ", "zw", " ", "is", " ", 
      "known"}], ",", " ", 
     RowBox[{
      RowBox[{
      "we", " ", "can", " ", "solve", " ", "it", " ", "in", " ", "conjuction",
        " ", "with", " ", "the", " ", "integral", " ", "constraint", " ", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["\[Integral]", 
          RowBox[{
           RowBox[{"-", "a"}], "/", "2"}]], 
         RowBox[{"a", "/", "2"}]], " ", 
        RowBox[{"zu", " ", "dT"}]}]}], " ", "=", " ", "0"}]}], " ", 
    "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.877082469528946*^9, 3.877082479368155*^9}, {
   3.877082663395711*^9, 3.877082708936462*^9}, 3.877082784839858*^9, 
   3.8770828190243807`*^9, {3.8770828510190887`*^9, 3.877082901968637*^9}, 
   3.8770829834442377`*^9, {3.8770848112526007`*^9, 3.8770848152221603`*^9}, {
   3.877085419627633*^9, 3.8770854243477993`*^9}, {3.877143735567498*^9, 
   3.877143736827957*^9}, {3.877407990784181*^9, 3.877407993263714*^9}, {
   3.877509238068417*^9, 3.877509238825152*^9}, {3.877522585820162*^9, 
   3.877522647004404*^9}, {3.877522688783001*^9, 3.8775226897825413`*^9}, {
   3.877522760915906*^9, 3.877522817324583*^9}, {3.8775228667942553`*^9, 
   3.877522868803897*^9}, {3.877527979478216*^9, 3.877527985434971*^9}, 
   3.877532825458088*^9, {3.877595548542282*^9, 3.877595583864842*^9}, {
   3.877596520559433*^9, 3.877596528493775*^9}, {3.8776006499041147`*^9, 
   3.877600772121039*^9}, {3.877609435291217*^9, 3.877609447223303*^9}, 
   3.883987340974844*^9, {3.883987477103303*^9, 3.8839874799688168`*^9}},
 CellLabel->"In[61]:=",ExpressionUUID->"930a1df0-08b1-4d53-9205-e3141fd3b2b4"],

Cell[BoxData[
 TemplateBox[{
  "Solve", "ratnz", 
   "\"Solve was unable to solve the system with inexact coefficients. The \
answer was obtained by solving a corresponding exact system and numericizing \
the result.\"", 2, 61, 2, 32786905637616642930, "ThirdLocalKernel"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8840868898108397`*^9},
 CellLabel->
  "During evaluation of \
In[61]:=",ExpressionUUID->"532ac196-4fcd-4be9-9397-2bb14f8d5bf8"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Terms with \[Delta]zw and its derivatives ", "Subsection",
 CellChangeTimes->{{3.877580247097794*^9, 3.877580249752614*^9}, {
  3.877580718496022*^9, 3.87758071870638*^9}, {3.877580838682148*^9, 
  3.877580838858305*^9}, {3.877599340320403*^9, 
  3.877599350099618*^9}},ExpressionUUID->"074a7824-3fd7-47d2-ab15-\
6274917cf98c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "variation", " ", "terms", " ", "that", " ", "involve", " ", 
    "\[Delta]zw", " ", "and", " ", "its", " ", "derivatives"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eqZw", "=", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{"eqToSolveForZ", "/.", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Delta]zu", "->", 
            RowBox[{"(", 
             RowBox[{"0", "&"}], ")"}]}], ",", 
           RowBox[{"\[Delta]zv", "->", 
            RowBox[{"(", 
             RowBox[{"0", "&"}], ")"}]}]}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Delta]zw", "[", "T", "]"}], ",", 
         RowBox[{
          RowBox[{"\[Delta]zw", "'"}], "[", "T", "]"}], ",", 
         RowBox[{
          RowBox[{"\[Delta]zw", "''"}], "[", "T", "]"}]}], "}"}], ",", 
       "FullSimplify"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"sanity", " ", 
      RowBox[{"check", ":", " ", 
       RowBox[{
       "Have", " ", "included", " ", "all", " ", "the", " ", "terms", " ", 
        "of", " ", "variation", " ", "of", " ", "potential", " ", "in", " ", 
        "the", " ", "three", " ", "equations", " ", "eqZu"}]}]}], ",", " ", 
     "eqZv", ",", " ", 
     RowBox[{"and", " ", 
      RowBox[{"eqZw", "?"}]}]}], " ", "*)"}], "\n", 
   RowBox[{"If", "[", 
    RowBox[{"doSanityCheck", ",", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"eqZu", "+", "eqZv", "+", "eqZw"}], ")"}], "-", 
         "eqToSolveForZ"}], "]"}], "==", "0"}], "]"}]}], "]"}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"reorganize", " ", "eqZw"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqZw", "=", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"eqZw", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"zu", "'"}], "[", "T", "]"}], "->", "zuDT"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"zv", "'"}], "[", "T", "]"}], "->", "zvDT"}]}], "}"}]}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Delta]zw", "[", "T", "]"}], ",", 
         RowBox[{
          RowBox[{"\[Delta]zw", "'"}], "[", "T", "]"}], ",", 
         RowBox[{
          RowBox[{"\[Delta]zw", "''"}], "[", "T", "]"}]}], "}"}], ",", 
       "FullSimplify"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8770832512980013`*^9, 3.877083258242156*^9}, {
   3.877083644876461*^9, 3.8770836735219717`*^9}, {3.877085437627351*^9, 
   3.877085453979806*^9}, {3.877085580733629*^9, 3.877085675922286*^9}, {
   3.877085710125102*^9, 3.877085853811496*^9}, {3.877085925894361*^9, 
   3.877085968998953*^9}, {3.877086098699175*^9, 3.877086272203559*^9}, {
   3.877086306402602*^9, 3.8770863657026567`*^9}, {3.877086514753149*^9, 
   3.8770866800938797`*^9}, {3.877086747648378*^9, 3.8770868146774893`*^9}, {
   3.877086858044056*^9, 3.877086872467382*^9}, {3.87708696448761*^9, 
   3.877086973860702*^9}, {3.877087080053789*^9, 3.877087080689988*^9}, {
   3.877087116417864*^9, 3.877087284882596*^9}, {3.877087327523135*^9, 
   3.877087458990073*^9}, {3.877087737120924*^9, 3.8770879730724573`*^9}, {
   3.877088003441382*^9, 3.8770883601528*^9}, {3.8770884083492126`*^9, 
   3.877088427246805*^9}, {3.877089819355278*^9, 3.877089844373837*^9}, {
   3.8770899517052794`*^9, 3.87708997878941*^9}, {3.8770900210095863`*^9, 
   3.8770900328150253`*^9}, 3.8770906151099577`*^9, {3.877318574387721*^9, 
   3.877318577931019*^9}, {3.87737005160135*^9, 3.87737005386684*^9}, {
   3.8775219924596252`*^9, 3.877522017281509*^9}, 3.87758022088621*^9, {
   3.877582660014113*^9, 3.877582666717863*^9}, {3.877599355390893*^9, 
   3.877599368964357*^9}, 3.877600785606792*^9, {3.8776009677777033`*^9, 
   3.8776011613280697`*^9}, {3.877609637454549*^9, 3.877609639578185*^9}, {
   3.8839874213583384`*^9, 3.8839874226178303`*^9}},
 CellLabel->"In[64]:=",ExpressionUUID->"3d94a17c-4154-4565-aec8-ed65dd39a88e"],

Cell[BoxData[
 RowBox[{"(*", " ", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
     "Calculation", " ", "of", " ", "differential", " ", "equation", " ", 
      "for", " ", 
      RowBox[{"zw", ":", "\[IndentingNewLine]", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["\[Integral]", 
          RowBox[{
           RowBox[{"-", "a"}], "/", "2"}]], 
         RowBox[{"a", "/", "2"}]], " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"gw0", " ", "\[Delta]zw"}], " ", "+", " ", 
           RowBox[{"gw1", " ", 
            SubscriptBox["\[Delta]zw", 
             RowBox[{",", "T"}]]}], " ", "+", " ", 
           RowBox[{"gw2", " ", 
            SubscriptBox["\[Delta]zw", 
             RowBox[{",", "TT"}]]}]}], ")"}], " ", "dT"}]}]}]}], "=", "0"}], 
    ";", " ", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"we", " ", "can", " ", "write", " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{"gw2", " ", 
        SubscriptBox["\[Delta]zw", 
         RowBox[{",", "TT"}]], " ", "dT", " ", "as", "\[IndentingNewLine]", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Integral]", 
           RowBox[{
            RowBox[{"-", "a"}], "/", "2"}]], 
          RowBox[{"a", "/", "2"}]], " ", 
         RowBox[{"gw2", " ", 
          SubscriptBox["\[Delta]zw", 
           RowBox[{",", "TT"}]], " ", "dT"}]}]}]}]}], " ", "=", "  ", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{
        SubscriptBox[
         RowBox[{"(", 
          RowBox[{"gw2", " ", 
           SubscriptBox["\[Delta]zw", 
            RowBox[{",", "T"}]]}], ")"}], 
         RowBox[{",", "T"}]], " ", "dT"}]}], " ", "-", " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{
        SubscriptBox["gw2", 
         RowBox[{",", "T"}]], " ", 
        SubscriptBox["\[Delta]zw", 
         RowBox[{",", "T"}]], " ", "dT"}]}]}]}]}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["\[Integral]", 
       RowBox[{
        RowBox[{"-", "a"}], "/", "2"}]], 
      RowBox[{"a", "/", "2"}]], " ", 
     RowBox[{"gw2", " ", 
      SubscriptBox["\[Delta]zw", 
       RowBox[{",", "TT"}]], " ", "dT"}]}], " ", "=", "  ", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox[
       RowBox[{"[", 
        RowBox[{"gw2", " ", 
         SubscriptBox["\[Delta]zw", 
          RowBox[{",", "T"}]]}], "]"}], 
       RowBox[{
        RowBox[{"-", "a"}], "/", "2"}]], 
      RowBox[{"a", "/", "2"}]], " ", "-", " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", 
        RowBox[{
         RowBox[{"-", "a"}], "/", "2"}]], 
       RowBox[{"a", "/", "2"}]], " ", 
      RowBox[{
       SubscriptBox["gw2", 
        RowBox[{",", "T"}]], " ", 
       SubscriptBox["\[Delta]zw", 
        RowBox[{",", "T"}]], " ", "dT"}]}]}]}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "this", " ", "gives", " ", "first", " ", "natural", " ", "boundary", " ", 
     "condition", " ", "as", " ", 
     RowBox[{"gw2", "[", 
      RowBox[{
       RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}], " ", "=", " ", 
    "0"}], ",", " ", 
   RowBox[{"on", " ", "clubbing", " ", "terms"}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "which", " ", "can", " ", "be", " ", "rewritten", " ", "as", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"zw", "''"}], "[", 
       RowBox[{
        RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}], " ", "=", " ", 
     RowBox[{"D2zwBc", "[", 
      RowBox[{
       RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}], ";", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"on", " ", "setting", " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{"gw2", " ", 
        SubscriptBox["\[Delta]zw", 
         RowBox[{",", "TT"}]], " ", "dT"}]}]}], " ", "=", 
     RowBox[{"-", " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{
        SubscriptBox["gw2", 
         RowBox[{",", "T"}]], " ", 
        SubscriptBox["\[Delta]zw", 
         RowBox[{",", "T"}]], " ", "dT", " ", "in", " ", "the", " ", 
        "initial", " ", "equation", " ", "above", " ", "and", " ", "clubbing",
         " ", "the", " ", "terms", " ", "with", " ", "factor", " ", 
        SubscriptBox["\[Delta]zw", 
         RowBox[{",", "T"}]]}]}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"we", " ", "get", " ", "\[IndentingNewLine]", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"gw1", " ", "-", " ", 
          SubscriptBox["gw2", 
           RowBox[{",", "T"}]]}], ")"}], " ", 
        SubscriptBox["\[Delta]zw", 
         RowBox[{",", "T"}]], " ", "dT"}]}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["gw2", 
           RowBox[{",", "TT"}]], "-", " ", 
          SubscriptBox["gw1", 
           RowBox[{",", "T"}]]}], ")"}], " ", "\[Delta]zw", " ", "dT"}]}], 
      " ", "-", "  ", 
      SuperscriptBox[
       SubscriptBox[
        RowBox[{"[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["gw2", 
             RowBox[{",", "T"}]], "-", " ", "gw1"}], ")"}], "\[Delta]zw"}], 
         "]"}], 
        RowBox[{
         RowBox[{"-", "a"}], "/", "2"}]], 
       RowBox[{"a", "/", "2"}]]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
      "this", " ", "gives", " ", "the", " ", "second", " ", "natural", " ", 
       "boundary", " ", "condition", " ", "as", " ", 
       SubscriptBox["gw2", 
        RowBox[{",", "T"}]]}], "-", " ", "gw1"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"0", " ", "at", " ", "T"}], "=", 
      RowBox[{
       RowBox[{"\[PlusMinus]", "a"}], "/", "2"}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"which", " ", "can", " ", "be", " ", "rewritten", " ", "as", "  ", 
      RowBox[{
       RowBox[{"zw", "'''"}], "[", 
       RowBox[{
        RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}], " ", "=", " ", 
     RowBox[{"D3zwBc", "[", 
      RowBox[{
       RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"on", " ", "using", " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"gw1", " ", "-", " ", 
          SubscriptBox["gw2", 
           RowBox[{",", "T"}]]}], ")"}], " ", 
        SubscriptBox["\[Delta]zw", 
         RowBox[{",", "T"}]], " ", "dT"}]}]}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", 
        RowBox[{
         RowBox[{"-", "a"}], "/", "2"}]], 
       RowBox[{"a", "/", "2"}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["gw2", 
          RowBox[{",", "TT"}]], "-", " ", 
         SubscriptBox["gw1", 
          RowBox[{",", "T"}]]}], ")"}], " ", "\[Delta]zw", " ", "dT"}]}]}]}], 
   ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "we", " ", "can", " ", "rewrite", " ", "the", " ", "inital", " ", 
      "equation", " ", "as", "\[IndentingNewLine]", "  ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"gw0", " ", "-", " ", 
          SubscriptBox["gw1", 
           RowBox[{",", "T"}]], " ", "+", " ", 
          SubscriptBox["gw2", 
           RowBox[{",", "TT"}]]}], ")"}], "\[Delta]zw", "  ", "dT"}]}]}], "=",
      "0"}], ";", "\[IndentingNewLine]", 
    RowBox[{"on", " ", "rearranging", " ", "the", " ", "terms"}]}], ",", " ", 
   
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "we", " ", "get", " ", "the", " ", "differential", " ", "equation", " ",
        "for", " ", "zw", " ", "as", "  ", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"zw", "''''"}], "[", "T", "]"}]}], " ", "+", " ", 
      RowBox[{"coefzw", " ", 
       RowBox[{"zw", "[", "T", "]"}]}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{"nonHomzw", "[", "T", "]"}], " ", "+", " ", 
      FractionBox["fN", "Db"], " ", "+", " ", 
      FractionBox[
       RowBox[{"T", " ", "gN"}], "Db"]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
      "intergrating", " ", "the", " ", "above", " ", "equation", " ", "along",
        " ", "T", " ", "from"}], " ", "-", 
      RowBox[{
       RowBox[{"a", "/", "2"}], " ", "to", " ", 
       RowBox[{"a", "/", "2"}], " ", "and", " ", "using", " ", "the", " ", 
       "first", " ", "natural", " ", "boundary", " ", "condition", " ", "and",
        " ", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["\[Integral]", 
          RowBox[{
           RowBox[{"-", "a"}], "/", "2"}]], 
         RowBox[{"a", "/", "2"}]], 
        RowBox[{"zw", " ", "dT"}]}]}]}], " ", "=", " ", "0"}]}], ",", " ", 
   RowBox[{
    RowBox[{
    "we", " ", "calculate", " ", "fN", " ", "\[IndentingNewLine]", "fN"}], 
    "=", " ", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox[
       RowBox[{
        RowBox[{"(", 
         FractionBox["Db", "a"], ")"}], "[", 
        RowBox[{
         RowBox[{
          RowBox[{"zw", "'''"}], "[", "T", "]"}], "-", 
         RowBox[{"inonHomzw", "[", "T", "]"}]}], "]"}], 
       RowBox[{
        RowBox[{"-", "a"}], "/", "2"}]], 
      RowBox[{"a", "/", "2"}]], " ", "=", " ", 
     SuperscriptBox[
      SubscriptBox[
       RowBox[{
        RowBox[{"(", 
         FractionBox["Db", "a"], ")"}], "[", 
        RowBox[{
         RowBox[{"D3zwBc", "[", "T", "]"}], "-", 
         RowBox[{"inonHomzw", "[", "T", "]"}]}], "]"}], 
       RowBox[{
        RowBox[{"-", "a"}], "/", "2"}]], 
      RowBox[{"a", "/", "2"}]]}]}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"where", " ", 
      RowBox[{"inonHomzw", "[", "T", "]"}]}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", "0"], "T"], " ", 
      RowBox[{
       RowBox[{"nonHomzw", "[", "m", "]"}], " ", "dm"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
      "we", " ", "multiply", " ", "the", " ", "differential", " ", "equation",
        " ", "by", " ", "T", "\[IndentingNewLine]", "T", " ", 
       RowBox[{
        RowBox[{"zw", "''''"}], "[", "T", "]"}]}], " ", "+", " ", 
      RowBox[{"T", " ", "coefzw", " ", 
       RowBox[{"zw", "[", "T", "]"}]}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{"T", " ", 
       RowBox[{"nonHomzw", "[", "T", "]"}]}], " ", "+", " ", 
      FractionBox[
       RowBox[{"T", " ", "fN"}], "Db"], " ", "+", " ", 
      FractionBox[
       RowBox[{
        SuperscriptBox["T", "2"], " ", "gN"}], "Db"]}]}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox[
      RowBox[{"(", 
       RowBox[{"T", " ", 
        RowBox[{
         RowBox[{"zw", "'''"}], "[", "T", "]"}]}], ")"}], 
      RowBox[{",", "T"}]], " ", "-", " ", 
     RowBox[{
      RowBox[{"zw", "''"}], "[", "T", "]"}], " ", "-", " ", 
     RowBox[{"T", " ", 
      RowBox[{"nonHomzw", "[", "T", "]"}]}], " ", "+", " ", 
     RowBox[{"T", " ", "coefzw", " ", 
      RowBox[{"zw", "[", "T", "]"}]}]}], " ", " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"T", " ", "fN"}], "Db"], " ", "+", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["T", "2"], " ", "gN"}], "Db"]}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
     "on", " ", "integrating", " ", "the", " ", "above", " ", "equation", " ",
       "along", " ", "T", " ", "from"}], " ", "-", 
     RowBox[{
      RowBox[{"a", "/", "2"}], " ", "to", " ", 
      RowBox[{"a", "/", "2"}], " ", "and", " ", "using", " ", "the", " ", 
      "first", " ", "natural", " ", "and", " ", "second", " ", "boundary", 
      " ", "conditions", " ", "and", " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{"T", " ", "zw", " ", "dT"}]}]}]}], " ", "=", " ", "0"}], ",", 
   " ", 
   RowBox[{
    RowBox[{"we", " ", "get", " ", "gN", " ", "\[IndentingNewLine]", "gN"}], 
    " ", "=", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       SubscriptBox[
        RowBox[{
         FractionBox[
          RowBox[{"12", " ", "Db"}], 
          SuperscriptBox["a", "3"]], " ", "[", 
         RowBox[{
          RowBox[{"T", " ", 
           RowBox[{"D3zwBc", "[", "T", "]"}]}], " ", "-", " ", 
          RowBox[{"D2zwBc", "[", "T", "]"}], " ", "-", " ", 
          RowBox[{"iTnonHomzw", "[", "T", "]"}]}], "]"}], 
        RowBox[{
         RowBox[{"-", "a"}], "/", "2"}]], 
       RowBox[{"a", "/", "2"}]], " ", "where", "  ", 
      RowBox[{"iTnonHomzw", "[", "T", "]"}]}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", "0"], "T"], " ", 
      RowBox[{"m", " ", 
       RowBox[{"nonHomzw", "[", "m", "]"}], " ", "dm"}]}]}]}]}], 
  "\[IndentingNewLine]", "*)"}]], "Input",
 CellChangeTimes->{{3.8770832512980013`*^9, 3.877083258242156*^9}, {
   3.877083644876461*^9, 3.8770836735219717`*^9}, {3.877085437627351*^9, 
   3.877085453979806*^9}, {3.877085580733629*^9, 3.877085675922286*^9}, {
   3.877085710125102*^9, 3.877085853811496*^9}, {3.877085925894361*^9, 
   3.877085968998953*^9}, {3.877086098699175*^9, 3.877086272203559*^9}, {
   3.877086306402602*^9, 3.8770863657026567`*^9}, {3.877086514753149*^9, 
   3.8770866800938797`*^9}, {3.877086747648378*^9, 3.8770868146774893`*^9}, {
   3.877086858044056*^9, 3.877086872467382*^9}, {3.87708696448761*^9, 
   3.877086973860702*^9}, {3.877087080053789*^9, 3.877087080689988*^9}, {
   3.877087116417864*^9, 3.877087284882596*^9}, {3.877087327523135*^9, 
   3.877087458990073*^9}, {3.877087737120924*^9, 3.8770879730724573`*^9}, {
   3.877088003441382*^9, 3.8770883601528*^9}, {3.8770884083492126`*^9, 
   3.877088427246805*^9}, {3.877089819355278*^9, 3.877089844373837*^9}, {
   3.8770899517052794`*^9, 3.87708997878941*^9}, {3.8770900210095863`*^9, 
   3.8770900328150253`*^9}, 3.8770906151099577`*^9, {3.877318574387721*^9, 
   3.877318577931019*^9}, {3.87737005160135*^9, 3.87737005386684*^9}, {
   3.8775219924596252`*^9, 3.877522017281509*^9}, 3.87758022088621*^9, {
   3.877582660014113*^9, 3.877582666717863*^9}, 3.877599355390893*^9, {
   3.8839855649322777`*^9, 3.883985566759678*^9}, 3.883987578259076*^9},
 CellLabel->"In[67]:=",ExpressionUUID->"16a30d60-6bf2-4190-9c75-694cff49a06b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "collect", " ", "coefficient", " ", "of", " ", "\[Delta]zw", " ", "in", 
    " ", "the", " ", "variation"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"gw0", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"eqZw", ",", 
        RowBox[{"\[Delta]zw", "[", "T", "]"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"collect", " ", "coefficient", " ", "of", " ", 
     SubscriptBox["\[Delta]zw", 
      RowBox[{",", "T"}]], " ", "in", " ", "the", " ", "variation"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gw1", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"eqZw", ",", 
        RowBox[{
         RowBox[{"\[Delta]zw", "'"}], "[", "T", "]"}]}], "]"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"collect", " ", "coefficient", " ", "of", " ", 
     SubscriptBox["\[Delta]zw", 
      RowBox[{",", "TT"}]], " ", "in", " ", "the", " ", "variation"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gw2", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"eqZw", ",", 
        RowBox[{
         RowBox[{"\[Delta]zw", "''"}], "[", "T", "]"}]}], "]"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"sanity", " ", 
     RowBox[{"check", ":", " ", 
      RowBox[{"only", " ", "three", " ", "terms", " ", 
       RowBox[{"(", 
        RowBox[{"gw0", ",", " ", "gw1", ",", " ", "gw2"}], ")"}], " ", "are", 
       " ", "associated", " ", "with", " ", "\[Delta]zw", " ", "and", " ", 
       "its", " ", "derivatives", " ", "in", " ", "the", " ", "variation", 
       " ", "of", " ", "potential"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   
   RowBox[{"If", "[", 
    RowBox[{"doSanityCheck", ",", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"gw0", " ", 
          RowBox[{"\[Delta]zw", "[", "T", "]"}]}], " ", "+", " ", 
         RowBox[{"gw1", " ", 
          RowBox[{
           RowBox[{"\[Delta]zw", "'"}], "[", "T", "]"}]}], "+", " ", 
         RowBox[{"gw2", " ", 
          RowBox[{
           RowBox[{"\[Delta]zw", "''"}], "[", "T", "]"}]}], "-", "eqZw"}], 
        "]"}], "==", "0"}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8770832512980013`*^9, 3.877083258242156*^9}, {
   3.877083644876461*^9, 3.8770836735219717`*^9}, 3.877085437627351*^9, {
   3.877085527687989*^9, 3.8770855391938057`*^9}, {3.877090064011057*^9, 
   3.877090072137437*^9}, {3.877509239885825*^9, 3.877509240875722*^9}, {
   3.877532677845282*^9, 3.8775327075922623`*^9}, 3.877532826841658*^9, 
   3.8775328987973948`*^9, {3.877595600109378*^9, 3.877595615226069*^9}, {
   3.8775993346834993`*^9, 3.87759933664764*^9}, {3.877601186490946*^9, 
   3.877601238945222*^9}, {3.8776096970659933`*^9, 3.877609716031644*^9}},
 CellLabel->"In[68]:=",ExpressionUUID->"977acfca-08a0-40a2-bbb6-0b255ac86712"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "the", " ", "differential", " ", "equation", " ", "for", " ", "zw"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"diffEqnZw", "=", 
   RowBox[{"Collect", "[", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"gw2", ",", 
         RowBox[{"{", 
          RowBox[{"T", ",", "2"}], "}"}]}], "]"}], "-", " ", 
       RowBox[{"D", "[", 
        RowBox[{"gw1", ",", "T"}], "]"}], "+", "gw0"}], "Db"], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"zw", "[", "T", "]"}], ",", 
       RowBox[{
        RowBox[{"zw", "'"}], "[", "T", "]"}], ",", 
       RowBox[{
        RowBox[{"zw", "''"}], "[", "T", "]"}], ",", 
       RowBox[{
        RowBox[{"zw", "'''"}], "[", "T", "]"}], ",", 
       RowBox[{
        RowBox[{"zw", "''''"}], "[", "T", "]"}], ",", " ", "fN", ",", 
       RowBox[{"gN", " ", "T"}]}], "}"}], ",", "FullSimplify"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8770891285299253`*^9, 3.877089141957427*^9}, {
   3.877089179799315*^9, 3.877089205343918*^9}, {3.877141643090095*^9, 
   3.877141645977737*^9}, {3.877152813483418*^9, 3.87715282981149*^9}, {
   3.877523172492347*^9, 3.877523182112667*^9}, 3.8775325070366793`*^9, {
   3.8775325522529907`*^9, 3.877532604217382*^9}},
 CellLabel->"In[72]:=",ExpressionUUID->"420920d7-6a53-4057-be66-343901ad58e7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["fN", "Db"]}], "-", 
  FractionBox[
   RowBox[{"gN", " ", "T"}], "Db"], "-", 
  FractionBox[
   RowBox[{"Km", " ", 
    SuperscriptBox["\[Kappa]2", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[Nu]", "2"]}], ")"}], " ", 
    RowBox[{"zw", "[", "T", "]"}]}], "Db"], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"12", " ", "Db"}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"t", " ", "Y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "d\[Kappa]1", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           RowBox[{"8", " ", 
            SuperscriptBox["T", "2"]}]}], ")"}], " ", "\[Kappa]3"}], "+", 
        RowBox[{"d\[Kappa]3", " ", "T", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"12", " ", 
            RowBox[{"(", 
             RowBox[{"\[Epsilon]", "+", 
              RowBox[{"T", " ", "\[Kappa]1"}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"14", " ", 
               SuperscriptBox["T", "2"]}]}], ")"}], " ", 
            SuperscriptBox["\[Kappa]3", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"12", " ", "Km", " ", "\[Kappa]2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[Nu]", "2"]}], ")"}], " ", 
      RowBox[{"dYv", "[", "T", "]"}]}], "+", 
     RowBox[{"24", " ", 
      RowBox[{
       SuperscriptBox["dm0ST", "\[Prime]",
        MultilineFunction->None], "[", "T", "]"}]}], "+", 
     RowBox[{"12", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"T", " ", "\[Kappa]3", " ", 
         RowBox[{"dn0SS", "[", "T", "]"}]}], "-", 
        RowBox[{"Km", " ", "T", " ", "\[Kappa]2", " ", "\[Kappa]3", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[Nu]", "2"]}], ")"}], " ", 
         RowBox[{"dYw", "[", "T", "]"}]}], "+", 
        RowBox[{"t", " ", "Y", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Kappa]2", " ", "\[Kappa]3", " ", 
            RowBox[{"idYw", "[", "T", "]"}]}], "+", 
           RowBox[{"2", " ", "d\[Kappa]2", " ", "\[Kappa]3", " ", 
            RowBox[{"iYw", "[", "T", "]"}]}], "-", 
           RowBox[{"d\[Kappa]3", " ", "T", " ", "\[Kappa]2", " ", 
            RowBox[{"Yw", "[", "T", "]"}]}], "+", 
           RowBox[{"T", " ", "\[Kappa]2", " ", "\[Kappa]3", " ", 
            RowBox[{
             SuperscriptBox["idYw", "\[Prime]",
              MultilineFunction->None], "[", "T", "]"}]}], "+", 
           RowBox[{"d\[Kappa]2", " ", "T", " ", "\[Kappa]3", " ", 
            RowBox[{
             SuperscriptBox["iYw", "\[Prime]",
              MultilineFunction->None], "[", "T", "]"}]}]}], ")"}]}]}], 
       ")"}]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["zw", 
    TagBox[
     RowBox[{"(", "4", ")"}],
     Derivative],
    MultilineFunction->None], "[", "T", "]"}]}]], "Output",
 CellChangeTimes->{3.884086891452395*^9},
 CellLabel->"Out[72]=",ExpressionUUID->"fa6990a1-506f-40a0-a5a2-370a6120669f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"natural", " ", "boundary", " ", 
     RowBox[{"condition", ":", " ", 
      RowBox[{
       RowBox[{"zw", "''"}], "[", 
       RowBox[{
        RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}]}], " ", "=", " ", 
    RowBox[{"D2zwBc", "[", 
     RowBox[{
      RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"D2zwBc", "[", "T_", "]"}], " ", "=", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["gw2", "Db"]}], " ", "+", 
     RowBox[{
      RowBox[{"zw", "''"}], "[", "T", "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"natural", " ", "boundary", " ", 
      RowBox[{"condition", ":", " ", 
       RowBox[{
        RowBox[{"zw", "'''"}], "[", 
        RowBox[{
         RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}]}], " ", "=", " ", 
     
     RowBox[{"D3zwBc", "[", 
      RowBox[{
       RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"D3zwBc", "[", "T_", "]"}], " ", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Simplify", "[", 
          RowBox[{
           FractionBox[
            RowBox[{
             RowBox[{"-", 
              RowBox[{"D", "[", 
               RowBox[{"gw2", ",", "T"}], "]"}]}], "+", "gw1"}], "Db"], " ", 
           "+", 
           RowBox[{
            RowBox[{"zw", "'''"}], "[", "T", "]"}]}], "]"}], "/.", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"dm0ST", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"dm0STfn", "[", "#", "]"}], "&"}], ")"}]}], ",", " ", 
           RowBox[{"idn0SS", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"idn0SSfn", "[", "#", "]"}], "&"}], ")"}]}]}], "}"}]}], 
        "/.", 
        RowBox[{"{", 
         RowBox[{"Db", "->", " ", "DbExp"}], "}"}]}], "]"}], ",", "T", ",", 
      "Simplify"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.877089562591235*^9, 3.877089569126189*^9}, {
   3.8770896870607853`*^9, 3.877089695061591*^9}, {3.87708973849051*^9, 
   3.877089746221363*^9}, {3.877090099471476*^9, 3.877090120472905*^9}, {
   3.877090241011812*^9, 3.877090282226797*^9}, {3.877090396797496*^9, 
   3.877090400993243*^9}, {3.877090481341448*^9, 3.877090500834477*^9}, 
   3.877142108123414*^9, {3.8771425768765*^9, 3.877142577870945*^9}, {
   3.877142674824102*^9, 3.8771426764694967`*^9}, {3.877143793849131*^9, 
   3.877143809649416*^9}, {3.877523188690947*^9, 3.8775232402189217`*^9}, {
   3.877601263876885*^9, 3.877601322245618*^9}},
 CellLabel->"In[73]:=",ExpressionUUID->"af6f5292-7db7-4c27-8b43-f66a77a905ee"],

Cell[BoxData[
 RowBox[{"d\[Kappa]3", " ", "T", " ", "\[Nu]"}]], "Output",
 CellChangeTimes->{3.8840868914570627`*^9},
 CellLabel->"Out[73]=",ExpressionUUID->"201e10e0-a083-40b3-affb-dbfb90016b0d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "d\[Kappa]3"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], "+", "\[Nu]"}], ")"}]}], "-", 
  FractionBox[
   RowBox[{"6", " ", "d\[Kappa]1", " ", 
    SuperscriptBox["T", "3"], " ", "\[Kappa]3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[Nu]", "2"]}], ")"}]}], 
   SuperscriptBox["t", "2"]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["a", "2"], " ", "d\[Kappa]3", " ", 
    SuperscriptBox["T", "2"], " ", 
    SuperscriptBox["\[Kappa]3", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[Nu]", "2"]}], ")"}]}], 
   SuperscriptBox["t", "2"]], "-", 
  FractionBox[
   RowBox[{"4", " ", "d\[Kappa]3", " ", 
    SuperscriptBox["T", "4"], " ", 
    SuperscriptBox["\[Kappa]3", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[Nu]", "2"]}], ")"}]}], 
   SuperscriptBox["t", "2"]], "+", 
  FractionBox[
   RowBox[{"3", " ", "T", " ", "\[Kappa]3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[Nu]", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], " ", "d\[Kappa]1"}], "+", 
      RowBox[{"8", " ", "\[Kappa]2", " ", 
       RowBox[{"idYw", "[", "T", "]"}]}], "+", 
      RowBox[{"8", " ", "d\[Kappa]2", " ", 
       RowBox[{"iYw", "[", "T", "]"}]}]}], ")"}]}], 
   RowBox[{"2", " ", 
    SuperscriptBox["t", "2"]}]]}]], "Output",
 CellChangeTimes->{3.884086891484901*^9},
 CellLabel->"Out[74]=",ExpressionUUID->"b5a0c268-ab29-47ed-a63b-24ef40491152"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "We", " ", "want", " ", "the", " ", "differential", " ", "equation", 
       " ", "diffEqnZw", " ", "in", " ", "this", " ", "form", " ", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"zw", "''''"}], "[", "T", "]"}]}], " ", "+", " ", 
      RowBox[{"coefzw", " ", 
       RowBox[{"zw", "[", "T", "]"}]}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{"nonHomzw", "[", "T", "]"}], " ", "+", " ", 
      FractionBox["fN", "Db"], " ", "+", " ", 
      FractionBox[
       RowBox[{"T", " ", "gN"}], "Db"]}]}], ";"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "coefficient", " ", "of", " ", "zw", " ", "in", " ", "the", " ", 
    "differential", " ", "equation"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"coefZw", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"diffEqnZw", ",", 
     RowBox[{"zw", "[", "T", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8770905772393637`*^9, 3.877090590490191*^9}, {
   3.877090650464807*^9, 3.877090708082748*^9}, {3.877090811568214*^9, 
   3.877090837731523*^9}, {3.8770909495826807`*^9, 3.877090961256481*^9}, 
   3.8770911229469337`*^9, {3.877091739338058*^9, 3.877091769033226*^9}, 
   3.877227912430646*^9, {3.877408689113751*^9, 3.8774086900471992`*^9}},
 CellLabel->"In[75]:=",ExpressionUUID->"d7c5f393-1b1c-4da5-bf5f-7a6a08bd1b06"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"Km", " ", 
    SuperscriptBox["\[Kappa]2", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[Nu]", "2"]}], ")"}]}], "Db"]}]], "Output",
 CellChangeTimes->{3.884086891487569*^9},
 CellLabel->"Out[75]=",ExpressionUUID->"7486a061-d8de-4b46-a334-a67cfc1400a8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"we", " ", "calculate", " ", "the", " ", "non"}], "-", 
    RowBox[{"homogeneous", " ", "part", " ", 
     RowBox[{"nonHomzw", "[", "T", "]"}], " ", "as"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"nonHomzwCalculated", "[", "T_", "]"}], " ", "=", "  ", 
   RowBox[{"-", 
    RowBox[{"Simplify", "[", 
     RowBox[{"diffEqnZw", " ", "-", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"zw", "''''"}], "[", "T", "]"}], " ", "+", " ", 
        RowBox[{"coefZw", " ", 
         RowBox[{"zw", "[", "T", "]"}]}], " ", "-", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["fN", "Db"], "+", 
          FractionBox[
           RowBox[{"gN", " ", "T"}], "Db"]}], ")"}]}], ")"}]}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.877091781125448*^9, 3.877091888426427*^9}, {
   3.877091933290057*^9, 3.877091964231841*^9}, {3.877092112690422*^9, 
   3.877092188145534*^9}, {3.87709374351624*^9, 3.877093744038048*^9}, 
   3.877094808457583*^9, {3.877101488024021*^9, 3.87710152009871*^9}, {
   3.8771083912698717`*^9, 3.877108394148438*^9}, {3.877142109998295*^9, 
   3.877142111468959*^9}, 3.877142262530881*^9, {3.877142579571145*^9, 
   3.877142587412951*^9}, {3.877142680911479*^9, 3.877142681878044*^9}, {
   3.877143826204718*^9, 3.877143849257901*^9}, 3.877227919453987*^9, {
   3.877407433618334*^9, 3.8774074347054443`*^9}, {3.8774086980215683`*^9, 
   3.8774086989945917`*^9}, {3.8776013356189327`*^9, 3.877601385529904*^9}, {
   3.877609819504827*^9, 3.877609841860939*^9}, 3.883987707803692*^9},
 CellLabel->"In[76]:=",ExpressionUUID->"ba09ec37-6b5d-4efb-aefc-a725093241fc"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"12", " ", "Db"}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"t", " ", "Y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "d\[Kappa]1", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           RowBox[{"8", " ", 
            SuperscriptBox["T", "2"]}]}], ")"}], " ", "\[Kappa]3"}], "+", 
        RowBox[{"d\[Kappa]3", " ", "T", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"12", " ", 
            RowBox[{"(", 
             RowBox[{"\[Epsilon]", "+", 
              RowBox[{"T", " ", "\[Kappa]1"}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"14", " ", 
               SuperscriptBox["T", "2"]}]}], ")"}], " ", 
            SuperscriptBox["\[Kappa]3", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"12", " ", "Km", " ", "\[Kappa]2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[Nu]", "2"]}], ")"}], " ", 
      RowBox[{"dYv", "[", "T", "]"}]}], "+", 
     RowBox[{"24", " ", 
      RowBox[{
       SuperscriptBox["dm0ST", "\[Prime]",
        MultilineFunction->None], "[", "T", "]"}]}], "+", 
     RowBox[{"12", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"T", " ", "\[Kappa]3", " ", 
         RowBox[{"dn0SS", "[", "T", "]"}]}], "-", 
        RowBox[{"Km", " ", "T", " ", "\[Kappa]2", " ", "\[Kappa]3", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[Nu]", "2"]}], ")"}], " ", 
         RowBox[{"dYw", "[", "T", "]"}]}], "+", 
        RowBox[{"t", " ", "Y", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Kappa]2", " ", "\[Kappa]3", " ", 
            RowBox[{"idYw", "[", "T", "]"}]}], "+", 
           RowBox[{"2", " ", "d\[Kappa]2", " ", "\[Kappa]3", " ", 
            RowBox[{"iYw", "[", "T", "]"}]}], "-", 
           RowBox[{"d\[Kappa]3", " ", "T", " ", "\[Kappa]2", " ", 
            RowBox[{"Yw", "[", "T", "]"}]}], "+", 
           RowBox[{"T", " ", "\[Kappa]2", " ", "\[Kappa]3", " ", 
            RowBox[{
             SuperscriptBox["idYw", "\[Prime]",
              MultilineFunction->None], "[", "T", "]"}]}], "+", 
           RowBox[{"d\[Kappa]2", " ", "T", " ", "\[Kappa]3", " ", 
            RowBox[{
             SuperscriptBox["iYw", "\[Prime]",
              MultilineFunction->None], "[", "T", "]"}]}]}], ")"}]}]}], 
       ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.884086891519828*^9},
 CellLabel->"Out[76]=",ExpressionUUID->"f9cdda71-61d8-451b-8324-cf96b08136de"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "set", " ", "the", " ", "expanded", " ", "expressions", " ", "for", " ", 
    "various", " ", "functions", " ", "in", " ", "nonHomzwCalculated"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"nonHomzwCalculated", "[", "T_", "]"}], "=", " ", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"nonHomzwCalculated", "[", "T", "]"}], " ", "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"dYv", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"dYvfn", "[", "#", "]"}], "&"}], ")"}]}], ",", " ", 
           RowBox[{"dn0SS", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"dn0SSfn", "[", "#", "]"}], "&"}], ")"}]}], ",", " ", 
           RowBox[{"idn0SS", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"idn0SSfn", "[", "#", "]"}], "&"}], ")"}]}], ",", " ", 
           RowBox[{"n0SS", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"n0SS", "[", "#", "]"}], "&"}], ")"}]}], ",", " ", 
           RowBox[{"dm0ST", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"dm0STfn", "[", "#", "]"}], "&"}], ")"}]}]}], "}"}]}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Km", "->", " ", "KmExp"}], ",", 
          RowBox[{"Db", "->", " ", "DbExp"}]}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Yw", "[", "T", "]"}], ",", 
         RowBox[{"iYw", "[", "T", "]"}], ",", 
         RowBox[{
          RowBox[{"iYw", "'"}], "[", "T", "]"}], ",", 
         RowBox[{"dYw", "[", "T", "]"}], ",", 
         RowBox[{"idYw", "[", "T", "]"}], ",", 
         RowBox[{
          RowBox[{"idYw", "'"}], "[", "T", "]"}]}], "}"}], ",", 
       "FullSimplify"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"proposed", " ", "nonHomzw"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"nonHomzw", "[", "T_", "]"}], "=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"12", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[Nu]", "2"]}], ")"}]}], 
         RowBox[{"  ", 
          SuperscriptBox["t", "2"]}]], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "4"], " ", 
          SuperscriptBox["a", "2"], " ", "d\[Kappa]1", " ", "\[Kappa]3"}], 
         "-", 
         RowBox[{
          FractionBox["1", "6"], " ", "d\[Kappa]3", " ", 
          SuperscriptBox["T", "3"], " ", 
          SuperscriptBox["\[Kappa]3", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["T", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"d\[Kappa]3", " ", "\[Kappa]1"}], "-", 
            RowBox[{"d\[Kappa]1", " ", "\[Kappa]3"}]}], ")"}]}], "+", 
         RowBox[{"T", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"d\[Epsilon]", " ", "\[Kappa]3"}], "+", 
            RowBox[{"d\[Kappa]3", " ", 
             RowBox[{"(", 
              RowBox[{"\[Epsilon]", "+", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["a", "2"], " ", 
                 SuperscriptBox["\[Kappa]3", "2"]}], "4"]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{"4", " ", "\[Kappa]2", " ", "\[Kappa]3", " ", 
          RowBox[{"idYw", "[", "T", "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"d\[Kappa]3", " ", "\[Kappa]2"}], "+", 
            RowBox[{"d\[Kappa]2", " ", "\[Kappa]3"}]}], ")"}], " ", 
          RowBox[{"iYw", "[", "T", "]"}]}], "-", 
         RowBox[{"2", " ", "d\[Kappa]3", " ", "T", " ", "\[Kappa]2", " ", 
          RowBox[{"Yw", "[", "T", "]"}]}]}], ")"}]}], ")"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "we", " ", "check", " ", "the", " ", "equivalence", " ", "of", " ", 
     "proposed", " ", "and", " ", "calculated", " ", "nonHomzw", " ", "at", 
     " ", "the", " ", "end", " ", "of", " ", "this", " ", "file"}], " ", 
    "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.877091781125448*^9, 3.877091888426427*^9}, {
   3.877091933290057*^9, 3.877091964231841*^9}, {3.877092112690422*^9, 
   3.877092188145534*^9}, {3.87709374351624*^9, 3.877093744038048*^9}, 
   3.877094808457583*^9, {3.877101488024021*^9, 3.87710152009871*^9}, {
   3.8771083912698717`*^9, 3.877108394148438*^9}, {3.877142109998295*^9, 
   3.877142111468959*^9}, 3.877142262530881*^9, {3.877142579571145*^9, 
   3.877142587412951*^9}, {3.877142680911479*^9, 3.877142681878044*^9}, {
   3.877143826204718*^9, 3.877143849257901*^9}, 3.877227919453987*^9, {
   3.877407433618334*^9, 3.8774074347054443`*^9}, {3.8774086980215683`*^9, 
   3.8774086989945917`*^9}, {3.877522024877267*^9, 3.8775220263484583`*^9}, {
   3.8775827169133368`*^9, 3.8775827492083483`*^9}, {3.877601404723654*^9, 
   3.8776014064568996`*^9}, {3.87760147207649*^9, 3.877601474951933*^9}},
 CellLabel->"In[77]:=",ExpressionUUID->"50a8e573-9ccd-4cfd-9b97-a607431076da"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"proposed", " ", "lagrange", " ", 
    RowBox[{"multipliers", ":", " ", 
     RowBox[{"fN", " ", "and", " ", "gN"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"fNExp", " ", "=", " ", 
     RowBox[{
      FractionBox["1", "12"], " ", 
      SuperscriptBox["a", "2"], " ", "t", " ", "Y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"d\[Kappa]3", " ", "\[Kappa]1"}], "+", 
        RowBox[{"2", " ", "d\[Kappa]1", " ", "\[Kappa]3"}]}], ")"}]}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gNExp", "  ", "=", " ", 
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"40", " ", 
          SuperscriptBox["a", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox["\[Nu]", "2"]}], ")"}]}]], "t", " ", "Y", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Nu]"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"80", " ", "a", " ", "d\[Kappa]3", " ", 
           SuperscriptBox["t", "2"]}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["a", "5"], " ", "d\[Kappa]3", " ", 
           SuperscriptBox["\[Kappa]3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "\[Nu]"}], ")"}]}], "+", 
          RowBox[{"40", " ", 
           SuperscriptBox["a", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"d\[Kappa]3", " ", "\[Epsilon]"}], "+", 
             RowBox[{"d\[Epsilon]", " ", "\[Kappa]3"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "\[Nu]"}], ")"}]}], "-", 
          RowBox[{"240", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "\[Nu]"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["a", "2"], " ", "\[Kappa]2", " ", "\[Kappa]3", 
              " ", 
              RowBox[{"idYw", "[", 
               FractionBox["a", "2"], "]"}]}], "-", 
             RowBox[{"16", " ", "\[Kappa]2", " ", "\[Kappa]3", " ", 
              RowBox[{"iTidYw", "[", 
               FractionBox["a", "2"], "]"}]}], "-", 
             RowBox[{"8", " ", "d\[Kappa]3", " ", "\[Kappa]2", " ", 
              RowBox[{"iTiYw", "[", 
               FractionBox["a", "2"], "]"}]}], "-", 
             RowBox[{"8", " ", "d\[Kappa]2", " ", "\[Kappa]3", " ", 
              RowBox[{"iTiYw", "[", 
               FractionBox["a", "2"], "]"}]}], "+", 
             RowBox[{"8", " ", "d\[Kappa]3", " ", "\[Kappa]2", " ", 
              RowBox[{"iTSqYw", "[", 
               FractionBox["a", "2"], "]"}]}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "d\[Kappa]2", " ", "\[Kappa]3", 
              " ", 
              RowBox[{"iYw", "[", 
               FractionBox["a", "2"], "]"}]}]}], ")"}]}]}], ")"}]}], 
       ")"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8770905772393637`*^9, 3.877090590490191*^9}, {
  3.877090650464807*^9, 3.877090708082748*^9}, {3.877090811568214*^9, 
  3.877090837731523*^9}, {3.8770909495826807`*^9, 3.877090961256481*^9}, {
  3.8770911229469337`*^9, 3.8770911823483343`*^9}, {3.877091240828974*^9, 
  3.8770912508404903`*^9}, {3.8770925636743717`*^9, 3.877092565741377*^9}, {
  3.877093364885091*^9, 3.877093368341683*^9}, {3.877094361761303*^9, 
  3.87709436411147*^9}, {3.877142114178379*^9, 3.8771421156796713`*^9}, {
  3.87714385932997*^9, 3.877143860381901*^9}, {3.877601430543309*^9, 
  3.8776014368340607`*^9}},
 CellLabel->"In[79]:=",ExpressionUUID->"f5bb08a8-711d-4075-9faf-bbf47c76515a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"calculated", " ", "fN", " ", "and", " ", "gN"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"rawfNExp", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       FractionBox["Db", "a"], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"D3zwBc", "[", 
         FractionBox["a", "2"], "]"}], "-", 
        RowBox[{"D3zwBc", "[", 
         RowBox[{"-", 
          FractionBox["a", "2"]}], "]"}], "-", 
        RowBox[{"Integrate", "[", 
         RowBox[{
          RowBox[{"nonHomzw", "[", "T", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"T", ",", 
            RowBox[{"-", 
             FractionBox["a", "2"]}], ",", 
            FractionBox["a", "2"]}], "}"}]}], "]"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rawgNExp", " ", "=", " ", 
     RowBox[{
      FractionBox[
       RowBox[{"12", " ", "Db"}], 
       SuperscriptBox["a", "3"]], 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"a", " ", 
          RowBox[{"D3zwBc", "[", 
           RowBox[{"a", "/", "2"}], "]"}]}], "2"], "+", " ", 
        FractionBox[
         RowBox[{"a", " ", 
          RowBox[{"D3zwBc", "[", 
           RowBox[{
            RowBox[{"-", "a"}], "/", "2"}], "]"}]}], "2"], "-", 
        RowBox[{"D2zwBc", "[", 
         FractionBox["a", "2"], "]"}], "+", 
        RowBox[{"D2zwBc", "[", 
         RowBox[{"-", 
          FractionBox["a", "2"]}], "]"}], " ", "-", " ", 
        RowBox[{"Integrate", "[", " ", 
         RowBox[{
          RowBox[{"T", " ", 
           RowBox[{"nonHomzw", "[", "T", "]"}]}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"T", ",", 
            RowBox[{"-", 
             FractionBox["a", "2"]}], ",", 
            FractionBox["a", "2"]}], "}"}]}], "]"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "we", " ", "check", " ", "the", " ", "equivalence", " ", "of", " ", 
     "proposed", " ", "and", " ", "calculated", " ", "fN", " ", "and", " ", 
     "gN", " ", "at", " ", "the", " ", "end", " ", "of", " ", "this", " ", 
     "file"}], " ", "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.8770905772393637`*^9, 3.877090590490191*^9}, {
  3.877090650464807*^9, 3.877090708082748*^9}, {3.877090811568214*^9, 
  3.877090837731523*^9}, {3.8770909495826807`*^9, 3.877090961256481*^9}, {
  3.8770911229469337`*^9, 3.8770911823483343`*^9}, {3.877093374635314*^9, 
  3.877093422225772*^9}, {3.8770934534626627`*^9, 3.877093538104849*^9}, {
  3.877093576893609*^9, 3.877093618839916*^9}, {3.8770938285363417`*^9, 
  3.8770938501343517`*^9}, {3.877141582045497*^9, 3.877141584234539*^9}, {
  3.877142118055395*^9, 3.877142119161016*^9}, {3.877146792770206*^9, 
  3.8771468045624943`*^9}, {3.8775220403454847`*^9, 3.8775220417282457`*^9}, {
  3.8775233039881887`*^9, 3.877523341666092*^9}, {3.8776014445102797`*^9, 
  3.877601468538353*^9}, {3.87760988520394*^9, 3.877609885755321*^9}},
 CellLabel->"In[81]:=",ExpressionUUID->"39e09131-9f13-44c7-a8b3-af42115f5508"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Summary: differential equations", "Subsection"]], \
"Subsection",
 CellChangeTimes->{{3.877150489973415*^9, 3.87715053501407*^9}, {
   3.877151018461117*^9, 3.8771512155249987`*^9}, 3.877151293760796*^9, {
   3.877151420765995*^9, 3.877151437906726*^9}, 3.8775802927709627`*^9, {
   3.877580385266399*^9, 
   3.87758039244459*^9}},ExpressionUUID->"4c9c5726-4cc7-4d43-8ce0-\
33516cfaf273"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "differential", " ", "equations", " ", "and", " ", "boundary", " ", 
    "conditions", " ", "to", " ", "solve", " ", "for", " ", "zw"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"A", " ", "fourth", " ", "order", " ", "differential", " ", 
      RowBox[{"equation", ":", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"zw", "''''"}], "[", "T", "]"}], " ", "+", " ", 
        RowBox[{"coefzw", " ", 
         RowBox[{"zw", "[", "T", "]"}]}]}]}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{"nonHomzw", "[", "T", "]"}], " ", "+", " ", 
      FractionBox["fN", "Db"], " ", "+", " ", 
      FractionBox[
       RowBox[{"T", " ", "gN"}], "Db"]}]}], ";"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"zw", "''''"}], "[", "T", "]"}], " ", "+", " ", 
    RowBox[{"coefZw", " ", 
     RowBox[{"zw", "[", "T", "]"}]}]}], " ", "==", 
   RowBox[{
    RowBox[{"nonHomzw", "[", "T", "]"}], "+", 
    FractionBox["fNExp", "Db"], "+", 
    FractionBox[
     RowBox[{"T", " ", "gNExp", " "}], "Db"]}]}]}]], "Input",
 CellChangeTimes->{{3.877150489973415*^9, 3.87715053501407*^9}, {
   3.877151018461117*^9, 3.8771512155249987`*^9}, 3.877151293760796*^9, {
   3.877151420765995*^9, 3.877151437906726*^9}, 3.8775802927709627`*^9, 
   3.877580385266399*^9, {3.877601484450383*^9, 3.877601492482683*^9}},
 CellLabel->"In[83]:=",ExpressionUUID->"5f8c50de-07aa-4b8f-9e8f-dca152de4555"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"Km", " ", 
      SuperscriptBox["\[Kappa]2", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[Nu]", "2"]}], ")"}], " ", 
      RowBox[{"zw", "[", "T", "]"}]}], "Db"]}], "+", 
   RowBox[{
    SuperscriptBox["zw", 
     TagBox[
      RowBox[{"(", "4", ")"}],
      Derivative],
     MultilineFunction->None], "[", "T", "]"}]}], "\[Equal]", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["a", "2"], " ", "t", " ", "Y", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"d\[Kappa]3", " ", "\[Kappa]1"}], "+", 
       RowBox[{"2", " ", "d\[Kappa]1", " ", "\[Kappa]3"}]}], ")"}]}], 
    RowBox[{"12", " ", "Db"}]], "-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"40", " ", 
      SuperscriptBox["a", "3"], " ", "Db", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SuperscriptBox["\[Nu]", "2"]}], ")"}]}]], 
    RowBox[{"t", " ", "T", " ", "Y", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Nu]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"80", " ", "a", " ", "d\[Kappa]3", " ", 
        SuperscriptBox["t", "2"]}], "+", 
       RowBox[{"9", " ", 
        SuperscriptBox["a", "5"], " ", "d\[Kappa]3", " ", 
        SuperscriptBox["\[Kappa]3", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Nu]"}], ")"}]}], "+", 
       RowBox[{"40", " ", 
        SuperscriptBox["a", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"d\[Kappa]3", " ", "\[Epsilon]"}], "+", 
          RowBox[{"d\[Epsilon]", " ", "\[Kappa]3"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Nu]"}], ")"}]}], "-", 
       RowBox[{"240", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Nu]"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "2"], " ", "\[Kappa]2", " ", "\[Kappa]3", " ", 
           
           RowBox[{"idYw", "[", 
            FractionBox["a", "2"], "]"}]}], "-", 
          RowBox[{"16", " ", "\[Kappa]2", " ", "\[Kappa]3", " ", 
           RowBox[{"iTidYw", "[", 
            FractionBox["a", "2"], "]"}]}], "-", 
          RowBox[{"8", " ", "d\[Kappa]3", " ", "\[Kappa]2", " ", 
           RowBox[{"iTiYw", "[", 
            FractionBox["a", "2"], "]"}]}], "-", 
          RowBox[{"8", " ", "d\[Kappa]2", " ", "\[Kappa]3", " ", 
           RowBox[{"iTiYw", "[", 
            FractionBox["a", "2"], "]"}]}], "+", 
          RowBox[{"8", " ", "d\[Kappa]3", " ", "\[Kappa]2", " ", 
           RowBox[{"iTSqYw", "[", 
            FractionBox["a", "2"], "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", "d\[Kappa]2", " ", "\[Kappa]3", " ", 
           RowBox[{"iYw", "[", 
            FractionBox["a", "2"], "]"}]}]}], ")"}]}]}], ")"}]}]}], "+", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox["t", "2"]], 
    RowBox[{"12", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[Nu]", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        SuperscriptBox["a", "2"], " ", "d\[Kappa]1", " ", "\[Kappa]3"}], "-", 
       
       RowBox[{
        FractionBox["1", "6"], " ", "d\[Kappa]3", " ", 
        SuperscriptBox["T", "3"], " ", 
        SuperscriptBox["\[Kappa]3", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["T", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"d\[Kappa]3", " ", "\[Kappa]1"}], "-", 
          RowBox[{"d\[Kappa]1", " ", "\[Kappa]3"}]}], ")"}]}], "+", 
       RowBox[{"T", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"d\[Epsilon]", " ", "\[Kappa]3"}], "+", 
          RowBox[{"d\[Kappa]3", " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]", "+", 
             FractionBox[
              RowBox[{
               SuperscriptBox["a", "2"], " ", 
               SuperscriptBox["\[Kappa]3", "2"]}], "4"]}], ")"}]}]}], ")"}]}],
        "+", 
       RowBox[{"4", " ", "\[Kappa]2", " ", "\[Kappa]3", " ", 
        RowBox[{"idYw", "[", "T", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"d\[Kappa]3", " ", "\[Kappa]2"}], "+", 
          RowBox[{"d\[Kappa]2", " ", "\[Kappa]3"}]}], ")"}], " ", 
        RowBox[{"iYw", "[", "T", "]"}]}], "-", 
       RowBox[{"2", " ", "d\[Kappa]3", " ", "T", " ", "\[Kappa]2", " ", 
        RowBox[{"Yw", "[", "T", "]"}]}]}], ")"}]}]}]}]}]], "Output",
 CellChangeTimes->{3.8840868940312967`*^9},
 CellLabel->"Out[83]=",ExpressionUUID->"74d6f6f5-ccc4-4647-9401-d1e511bad8dc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "boundary", " ", "conditions"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"zw", "''"}], "[", 
     RowBox[{"a", "/", "2"}], "]"}], "==", 
    RowBox[{"D2zwBc", "[", 
     RowBox[{"a", "/", "2"}], "]"}]}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"zw", "''"}], "[", 
     RowBox[{
      RowBox[{"-", "a"}], "/", "2"}], "]"}], "==", 
    RowBox[{"D2zwBc", "[", 
     RowBox[{
      RowBox[{"-", "a"}], "/", "2"}], "]"}]}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"zw", "'''"}], "[", 
     RowBox[{"a", "/", "2"}], "]"}], "==", 
    RowBox[{"D3zwBc", "[", " ", 
     RowBox[{"a", "/", "2"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"zw", "'''"}], "[", 
     RowBox[{
      RowBox[{"-", "a"}], "/", "2"}], "]"}], "==", 
    RowBox[{"D3zwBc", "[", " ", 
     RowBox[{
      RowBox[{"-", "a"}], "/", "2"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"and", " ", "the", " ", "integral", " ", "constraints", " ", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["\[Integral]", 
          RowBox[{
           RowBox[{"-", "a"}], "/", "2"}]], 
         RowBox[{"a", "/", "2"}]], " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"zw", ",", " ", 
           RowBox[{"T", " ", "zw"}]}], ")"}], " ", "dT"}]}]}], " ", "=", " ", 
      
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"0", ",", "0"}], ")"}], ".", " ", "The"}], " ", 
        "mathematica", " ", "file", " ", "for", " ", "no"}], "-", 
       RowBox[{"bending", " ", "case", " ", 
        RowBox[{"(", 
         RowBox[{"\[Kappa]1", " ", "=", " ", 
          RowBox[{"\[Kappa]2", " ", "=", " ", "0"}]}], ")"}]}]}]}], ",", " ", 
     
     RowBox[{
     "shows", " ", "how", " ", "we", " ", "use", " ", "these", " ", 
      "differential", " ", "equations", " ", "to", " ", "calculate", " ", 
      "the", " ", "microscopic", " ", "displacements", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"zv", ",", " ", "zu", ",", " ", "zw"}], "}"}], "."}]}]}], " ",
     "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.877150489973415*^9, 3.87715053501407*^9}, {
   3.877151018461117*^9, 3.8771512155249987`*^9}, 3.877151293760796*^9, {
   3.8774069307760763`*^9, 3.877406947043659*^9}, 3.877411121445292*^9, {
   3.877583932847036*^9, 3.8775840629133263`*^9}, {3.8776015063072987`*^9, 
   3.87760151654904*^9}},
 CellLabel->"In[84]:=",ExpressionUUID->"487673ee-52e3-48ba-8547-da71f6a7aadb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["zw", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", 
   FractionBox["a", "2"], "]"}], "\[Equal]", 
  FractionBox[
   RowBox[{"a", " ", "d\[Kappa]3", " ", "\[Nu]"}], "2"]}]], "Output",
 CellChangeTimes->{3.884086894047731*^9},
 CellLabel->"Out[84]=",ExpressionUUID->"f3ef797d-3f29-429e-9888-0779eb64f645"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["zw", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", 
   RowBox[{"-", 
    FractionBox["a", "2"]}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", "a", " ", "d\[Kappa]3", " ", 
   "\[Nu]"}]}]], "Output",
 CellChangeTimes->{3.884086894048682*^9},
 CellLabel->"Out[85]=",ExpressionUUID->"82a72beb-0c91-43ac-95d1-6cbad5b52c9a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["zw", 
    TagBox[
     RowBox[{"(", "3", ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   FractionBox["a", "2"], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "d\[Kappa]3"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", "\[Nu]"}], ")"}]}], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox["a", "3"], " ", "d\[Kappa]1", " ", "\[Kappa]3", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[Nu]", "2"]}], ")"}]}], 
    RowBox[{"4", " ", 
     SuperscriptBox["t", "2"]}]], "+", 
   FractionBox[
    RowBox[{"3", " ", "a", " ", "\[Kappa]3", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[Nu]", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["a", "2"], " ", "d\[Kappa]1"}], "+", 
       RowBox[{"8", " ", "\[Kappa]2", " ", 
        RowBox[{"idYw", "[", 
         FractionBox["a", "2"], "]"}]}], "+", 
       RowBox[{"8", " ", "d\[Kappa]2", " ", 
        RowBox[{"iYw", "[", 
         FractionBox["a", "2"], "]"}]}]}], ")"}]}], 
    RowBox[{"4", " ", 
     SuperscriptBox["t", "2"]}]]}]}]], "Output",
 CellChangeTimes->{3.884086894049346*^9},
 CellLabel->"Out[86]=",ExpressionUUID->"5386120f-a7b9-47bc-be34-da7cad35921b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["zw", 
    TagBox[
     RowBox[{"(", "3", ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"-", 
    FractionBox["a", "2"]}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "d\[Kappa]3"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", "\[Nu]"}], ")"}]}], "+", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox["a", "3"], " ", "d\[Kappa]1", " ", "\[Kappa]3", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[Nu]", "2"]}], ")"}]}], 
    RowBox[{"4", " ", 
     SuperscriptBox["t", "2"]}]], "-", 
   FractionBox[
    RowBox[{"3", " ", "a", " ", "\[Kappa]3", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[Nu]", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["a", "2"], " ", "d\[Kappa]1"}], "+", 
       RowBox[{"8", " ", "\[Kappa]2", " ", 
        RowBox[{"idYw", "[", 
         RowBox[{"-", 
          FractionBox["a", "2"]}], "]"}]}], "+", 
       RowBox[{"8", " ", "d\[Kappa]2", " ", 
        RowBox[{"iYw", "[", 
         RowBox[{"-", 
          FractionBox["a", "2"]}], "]"}]}]}], ")"}]}], 
    RowBox[{"4", " ", 
     SuperscriptBox["t", "2"]}]]}]}]], "Output",
 CellChangeTimes->{3.884086894050161*^9},
 CellLabel->"Out[87]=",ExpressionUUID->"7ab1a397-3200-4b6f-9eeb-0ca563f0b915"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "differential", " ", "equations", " ", "to", " ", "solve", " ", "for", " ",
     "zu", " ", "and", " ", "zv"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"zu", "'"}], "[", "T", "]"}], " ", "==", "zuDT"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"zv", "'"}], "[", "T", "]"}], " ", "==", "zvDT"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"the", " ", "integral", " ", "constraints", " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"zv", ",", " ", "zu"}], ")"}], " ", "dT"}]}]}], " ", "=", 
     " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"0", ",", "0"}], ")"}], " ", "will", " ", "help", " ", "us", 
      " ", "find", " ", "the", " ", "constants", " ", "of", " ", 
      "integration"}]}], " ", "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.877151233190744*^9, 3.8771513870733852`*^9}, {
  3.8771519684245653`*^9, 3.877151977063991*^9}},
 CellLabel->"In[88]:=",ExpressionUUID->"6a3c2f3d-1566-4c95-97c1-e1e64ad5cc4f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["zu", "\[Prime]",
    MultilineFunction->None], "[", "T", "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "\[Nu]"}], " ", 
    RowBox[{"dYv", "[", "T", "]"}]}], "+", 
   RowBox[{"T", " ", "\[Kappa]3", " ", "\[Nu]", " ", 
    RowBox[{"dYw", "[", "T", "]"}]}], "+", 
   RowBox[{"\[Kappa]2", " ", "\[Nu]", " ", 
    RowBox[{"zw", "[", "T", "]"}]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["Yw", "\[Prime]",
      MultilineFunction->None], "[", "T", "]"}], " ", 
    RowBox[{
     SuperscriptBox["zw", "\[Prime]",
      MultilineFunction->None], "[", "T", "]"}]}]}]}]], "Output",
 CellChangeTimes->{3.884086894052621*^9},
 CellLabel->"Out[88]=",ExpressionUUID->"74a9d345-dd54-4358-ab03-7b57dc8b61c2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["zv", "\[Prime]",
    MultilineFunction->None], "[", "T", "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"dYu", "[", "T", "]"}]}], "-", 
   FractionBox[
    RowBox[{"t", " ", "Y", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["T", "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "d\[Kappa]1"}], "+", 
          RowBox[{"2", " ", "d\[Kappa]3", " ", "T", " ", "\[Kappa]3"}]}], 
         ")"}]}], "+", 
       RowBox[{"24", " ", "\[Kappa]2", " ", 
        RowBox[{"idYw", "[", "T", "]"}]}], "+", 
       RowBox[{"24", " ", "d\[Kappa]2", " ", 
        RowBox[{"iYw", "[", "T", "]"}]}]}], ")"}]}], 
    RowBox[{"12", " ", "Km", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Nu]"}], ")"}]}]], "-", 
   RowBox[{"\[Kappa]3", " ", 
    RowBox[{"zw", "[", "T", "]"}]}], "-", 
   RowBox[{
    RowBox[{"dYw", "[", "T", "]"}], " ", 
    RowBox[{
     SuperscriptBox["Yw", "\[Prime]",
      MultilineFunction->None], "[", "T", "]"}]}], "+", 
   RowBox[{"T", " ", "\[Kappa]3", " ", 
    RowBox[{
     SuperscriptBox["zw", "\[Prime]",
      MultilineFunction->None], "[", "T", "]"}]}]}]}]], "Output",
 CellChangeTimes->{3.884086894053506*^9},
 CellLabel->"Out[89]=",ExpressionUUID->"afd292e4-ab3f-4ea4-8347-2c05a3c291d5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sanity checks for some proposed and calculated expressions", \
"Subsection",
 CellChangeTimes->{
  3.877156171654076*^9, {3.877156389110196*^9, 3.877156438566206*^9}, 
   3.877156470546419*^9, {3.8775092419063253`*^9, 3.877509242861021*^9}, {
   3.8775804144524117`*^9, 3.8775804603442097`*^9}, {3.877580601637948*^9, 
   3.8775806081527033`*^9}, {3.877580993944912*^9, 3.8775809973129396`*^9}, {
   3.8775966416802187`*^9, 
   3.877596646819583*^9}},ExpressionUUID->"26791cd7-8f72-4093-9423-\
1261d0652e20"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "sanity", " ", "tests", " ", "to", " ", "check", " ", "the", " ", 
    "calculated", " ", "and", " ", "proposed", " ", "value", " ", "of", " ", 
    "fN", " ", "and", " ", "gN"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"If", "[", 
   RowBox[{"doSanityCheck", ",", 
    RowBox[{
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"fNExp", " ", "-", " ", "rawfNExp"}], " ", "/.", " ", 
          RowBox[{"{", 
           RowBox[{"Db", "->", " ", "DbExp"}], "}"}]}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"idYw", " ", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"idYwExp", "[", "#", "]"}], "&"}], ")"}]}], ",", "  ", 
           RowBox[{"iYw", " ", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"iYwExp", "[", "#", "]"}], "&"}], ")"}]}], ",", " ", 
           RowBox[{"Yw", " ", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"YwExp", "[", "#", "]"}], "&"}], ")"}]}], ",", " ", 
           RowBox[{"iTidYw", " ", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"iTidYwExp", "[", "#", "]"}], "&"}], ")"}]}], ",", " ", 
           
           RowBox[{"iTiYw", " ", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"iTiYwExp", "[", "#", "]"}], "&"}], ")"}]}], ",", " ", 
           RowBox[{"iTSqYw", " ", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"iTSqYwExp", "[", "#", "]"}], "&"}], ")"}]}]}], " ", 
          "}"}]}], "]"}], "==", "0"}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"gNExp", " ", "-", " ", "rawgNExp"}], " ", "/.", " ", 
          RowBox[{"{", 
           RowBox[{"Db", "->", " ", "DbExp"}], "}"}]}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"idYw", " ", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"idYwExp", "[", "#", "]"}], "&"}], ")"}]}], ",", "  ", 
           RowBox[{"iYw", " ", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"iYwExp", "[", "#", "]"}], "&"}], ")"}]}], ",", " ", 
           RowBox[{"Yw", " ", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"YwExp", "[", "#", "]"}], "&"}], ")"}]}], ",", " ", 
           RowBox[{"iTidYw", " ", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"iTidYwExp", "[", "#", "]"}], "&"}], ")"}]}], ",", " ", 
           
           RowBox[{"iTiYw", " ", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"iTiYwExp", "[", "#", "]"}], "&"}], ")"}]}], ",", " ", 
           RowBox[{"iTSqYw", " ", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"iTSqYwExp", "[", "#", "]"}], "&"}], ")"}]}]}], " ", 
          "}"}]}], "]"}], "==", "0"}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "sanity", " ", "test", " ", "to", " ", "check", " ", "the", " ", 
       "calculated", " ", "and", " ", "proposed", " ", "value", " ", "of", 
       " ", 
       RowBox[{"nonHomzw", "[", "T", "]"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Collect", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Simplify", "[", 
           RowBox[{
            RowBox[{"nonHomzw", "[", "T", "]"}], "-", 
            RowBox[{"nonHomzwCalculated", "[", "T", "]"}]}], "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Yw", "->", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"YwExp", "[", "#", "]"}], "&"}], ")"}]}], ",", 
            RowBox[{"iYw", "->", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"iYwExp", "[", "#", "]"}], "&"}], ")"}]}], ",", " ", 
            RowBox[{"dYw", "->", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"dYwExp", "[", "#", "]"}], "&"}], ")"}]}], ",", 
            RowBox[{"idYw", "->", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"idYwExp", "[", "#", "]"}], "&"}], ")"}]}]}], "}"}]}], 
         ",", " ", 
         RowBox[{"{", 
          RowBox[{"a", ",", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SuperscriptBox["\[Nu]", "2"]}], ")"}]}], "}"}], ",", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Simplify", "[", 
            RowBox[{"#", ",", 
             RowBox[{"Assumptions", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"ks", ">", "0"}], ",", 
                RowBox[{"0", "<", "\[Nu]", "<", "0.5"}], ",", 
                RowBox[{"a", ">", "0"}], ",", 
                RowBox[{"0", "<", "t", "<", "a"}], ",", " ", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "a"}], "/", "2"}], "<", "T", "<", 
                 RowBox[{"a", "/", "2"}]}], ",", " ", 
                RowBox[{"\[Kappa]2", " ", "\[Element]", " ", "Reals"}]}], 
               "}"}]}]}], "]"}], "&"}], ")"}]}], "]"}], "==", "0"}], "]"}], 
     ";"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.877156171654076*^9, {3.877156389110196*^9, 3.877156438566206*^9}, 
   3.877156470546419*^9, {3.8775092419063253`*^9, 3.877509242861021*^9}, 
   3.8775804144524117`*^9, {3.877595624130821*^9, 3.877595640242518*^9}, {
   3.87759654974571*^9, 3.8775965862401047`*^9}},
 CellLabel->"In[90]:=",ExpressionUUID->"92213a17-4fc8-4be2-9a4a-3afe3a4c487d"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Evaluator->"ThirdLocalKernel",
WindowSize->{837, 1051},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
TaggingRules-><|"TryRealOnly" -> False|>,
FrontEndVersion->"13.0 for Mac OS X ARM (64-bit) (February 4, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"dfc1b587-c6ba-4d12-93c7-ea823e186151"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 480, 7, 160, "Title",ExpressionUUID->"454d7575-22f2-4c20-befb-6f73f7b89361"],
Cell[1063, 31, 410, 8, 117, "Subtitle",ExpressionUUID->"4339e4dd-4963-4ec2-80d7-e3d53dd8024f"],
Cell[1476, 41, 4202, 88, 291, "Input",ExpressionUUID->"5376c61e-4e9a-433c-ac0f-566b8de80917"],
Cell[CellGroupData[{
Cell[5703, 133, 387, 6, 67, "Section",ExpressionUUID->"c9bcd3b3-cca4-4b42-9ab7-7edb766bdeb3"],
Cell[6093, 141, 766, 12, 73, "Input",ExpressionUUID->"a2653600-1e1d-44a6-9f4e-8cf04dd607c9"],
Cell[CellGroupData[{
Cell[6884, 157, 1557, 22, 54, "Subsection",ExpressionUUID->"0d39e317-472f-4783-927c-b4a17221c0cb"],
Cell[8444, 181, 3464, 60, 137, "Input",ExpressionUUID->"df70e129-ee60-437d-8859-9a2f3ec89a90"],
Cell[11911, 243, 2638, 53, 120, "Input",ExpressionUUID->"3e963411-ec00-4897-a619-31463d9a4578"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14586, 301, 1521, 21, 54, "Subsection",ExpressionUUID->"df72384d-429e-46dc-8ea1-541080dd4b93"],
Cell[16110, 324, 3955, 103, 332, "Input",ExpressionUUID->"2f745f26-46cf-49b1-bcf8-f32bfad1c392"],
Cell[20068, 429, 1269, 31, 124, "Input",ExpressionUUID->"1492f9e4-6e91-48b8-b131-151b43441f76"],
Cell[21340, 462, 1150, 25, 87, "Input",ExpressionUUID->"f21aca84-7b48-41fb-a4c0-b93aaac0452a"],
Cell[22493, 489, 5741, 141, 453, "Input",ExpressionUUID->"0c9e1c71-c829-454b-9890-6d2489ea7fb7"],
Cell[28237, 632, 3122, 87, 242, "Input",ExpressionUUID->"26e0bcd8-5d38-47be-b4bf-298130cce3c0"],
Cell[31362, 721, 1579, 36, 136, "Input",ExpressionUUID->"935759a6-2c84-49af-a612-72f5c8f890dd"],
Cell[32944, 759, 4678, 124, 242, "Input",ExpressionUUID->"33c23470-a8fa-48d5-8982-a10a194079ea"],
Cell[37625, 885, 7131, 174, 410, "Input",ExpressionUUID->"22612f94-e04f-4c73-b765-4a9ae246f463"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[44805, 1065, 1125, 16, 67, "Section",ExpressionUUID->"d35ec7dd-91c4-4d43-aa49-1de38f793db1"],
Cell[CellGroupData[{
Cell[45955, 1085, 4608, 106, 241, "Input",ExpressionUUID->"565403d9-4fa1-4a62-8cf7-a59053ff8c31"],
Cell[50566, 1193, 551, 15, 60, "Output",ExpressionUUID->"a3ecadad-8f5b-4539-9a1c-24702c09793d"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[51166, 1214, 3991, 64, 68, "Section",ExpressionUUID->"8210c24d-24d5-4e23-8cbb-76ba0290b39e"],
Cell[55160, 1280, 5136, 124, 214, "Input",ExpressionUUID->"e2aa353f-43fe-4f5a-802b-6feab5e6c672"],
Cell[60299, 1406, 4272, 104, 173, "Input",ExpressionUUID->"a4d7ab47-70ad-4391-b38a-8ba96cfb794f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64608, 1515, 503, 7, 67, "Section",ExpressionUUID->"e66c51fb-032a-45ae-8802-26cac61b4b95"],
Cell[CellGroupData[{
Cell[65136, 1526, 521, 8, 54, "Subsection",ExpressionUUID->"6b3ee279-e312-4d6a-9500-2bcd09f3f139"],
Cell[65660, 1536, 1301, 28, 73, "Input",ExpressionUUID->"837230d0-cc4c-424e-a2b5-de9d8ba3fd55"],
Cell[66964, 1566, 1378, 38, 73, "Input",ExpressionUUID->"d21f47d6-285f-4c7b-b2c3-0cb9ae648818"],
Cell[68345, 1606, 856, 19, 52, "Input",ExpressionUUID->"3fb1818b-244d-4fef-833c-375dbb0c4734"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69238, 1630, 192, 3, 54, "Subsection",ExpressionUUID->"ecf546f6-ebcd-433c-b7ab-da15b3be26ed"],
Cell[69433, 1635, 1951, 41, 73, "Input",ExpressionUUID->"18f8083a-5e7e-415a-acfc-96ef2e8c108f"],
Cell[71387, 1678, 5840, 161, 398, "Input",ExpressionUUID->"d806f8eb-1376-4abc-8581-6544c250fdc9"],
Cell[CellGroupData[{
Cell[77252, 1843, 2487, 53, 136, "Input",ExpressionUUID->"8031dd7d-2318-41bb-84a6-00643ed43f94"],
Cell[79742, 1898, 221, 5, 34, "Output",ExpressionUUID->"79a7d843-e3f9-4a06-96fe-b20deadb5adf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80000, 1908, 1999, 36, 56, "Input",ExpressionUUID->"07b23b9b-58eb-48ed-a764-18cae13f6a1b"],
Cell[82002, 1946, 247, 6, 34, "Output",ExpressionUUID->"37ac0217-ffb7-47fc-86f2-fb039397432f"]
}, Open  ]],
Cell[82264, 1955, 3615, 83, 157, "Input",ExpressionUUID->"5264fe7f-6cf4-4645-b76a-6d14a08f9b29"],
Cell[85882, 2040, 2762, 64, 259, "Input",ExpressionUUID->"f4837019-e190-49ff-857e-b1a011aa50f4"],
Cell[CellGroupData[{
Cell[88669, 2108, 2724, 56, 97, "Input",ExpressionUUID->"a041d4d2-6491-4c4c-9c02-a694097a3560"],
Cell[91396, 2166, 1800, 52, 74, "Output",ExpressionUUID->"5f5dc54a-cd81-457e-95da-04d87dea650a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[93233, 2223, 3206, 82, 239, "Input",ExpressionUUID->"2fe3840e-93d2-4d76-8599-4fab340d5363"],
Cell[96442, 2307, 1334, 39, 81, "Output",ExpressionUUID->"5a7304ca-0d58-4f35-82e9-b119e4f0e82b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[97825, 2352, 822, 12, 54, "Subsection",ExpressionUUID->"9b7feb6f-bab4-421b-991f-7e76ae3ff93f"],
Cell[98650, 2366, 5645, 149, 455, "Input",ExpressionUUID->"d9d8002a-5b39-41b4-a548-ffbd4c07c1b4"],
Cell[104298, 2517, 2883, 68, 180, "Input",ExpressionUUID->"0fe2909e-1d14-4177-b189-c68e840bf172"],
Cell[CellGroupData[{
Cell[107206, 2589, 4736, 114, 292, "Input",ExpressionUUID->"930a1df0-08b1-4d53-9205-e3141fd3b2b4"],
Cell[111945, 2705, 463, 10, 46, "Message",ExpressionUUID->"532ac196-4fcd-4be9-9397-2bb14f8d5bf8"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[112457, 2721, 333, 5, 54, "Subsection",ExpressionUUID->"074a7824-3fd7-47d2-ab15-6274917cf98c"],
Cell[112793, 2728, 4208, 95, 220, "Input",ExpressionUUID->"3d94a17c-4154-4565-aec8-ed65dd39a88e"],
Cell[117004, 2825, 15707, 438, 834, "Input",ExpressionUUID->"16a30d60-6bf2-4190-9c75-694cff49a06b"],
Cell[132714, 3265, 3135, 73, 224, "Input",ExpressionUUID->"977acfca-08a0-40a2-bbb6-0b255ac86712"],
Cell[CellGroupData[{
Cell[135874, 3342, 1395, 35, 99, "Input",ExpressionUUID->"420920d7-6a53-4057-be66-343901ad58e7"],
Cell[137272, 3379, 3281, 89, 150, "Output",ExpressionUUID->"fa6990a1-506f-40a0-a5a2-370a6120669f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[140590, 3473, 2830, 75, 238, "Input",ExpressionUUID->"af6f5292-7db7-4c27-8b43-f66a77a905ee"],
Cell[143423, 3550, 196, 3, 34, "Output",ExpressionUUID->"201e10e0-a083-40b3-affb-dbfb90016b0d"],
Cell[143622, 3555, 1674, 51, 105, "Output",ExpressionUUID->"b5a0c268-ab29-47ed-a63b-24ef40491152"]
}, Open  ]],
Cell[CellGroupData[{
Cell[145333, 3611, 1463, 33, 121, "Input",ExpressionUUID->"d7c5f393-1b1c-4da5-bf5f-7a6a08bd1b06"],
Cell[146799, 3646, 362, 10, 55, "Output",ExpressionUUID->"7486a061-d8de-4b46-a334-a67cfc1400a8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[147198, 3661, 1716, 36, 75, "Input",ExpressionUUID->"ba09ec37-6b5d-4efb-aefc-a725093241fc"],
Cell[148917, 3699, 2781, 71, 98, "Output",ExpressionUUID->"f9cdda71-61d8-451b-8324-cf96b08136de"]
}, Open  ]],
Cell[151713, 3773, 5265, 126, 348, "Input",ExpressionUUID->"50a8e573-9ccd-4cfd-9b97-a607431076da"],
Cell[156981, 3901, 3671, 86, 267, "Input",ExpressionUUID->"f5bb08a8-711d-4075-9faf-bbf47c76515a"],
Cell[160655, 3989, 3088, 76, 224, "Input",ExpressionUUID->"39e09131-9f13-44c7-a8b3-af42115f5508"]
}, Open  ]],
Cell[CellGroupData[{
Cell[163780, 4070, 412, 7, 54, "Subsection",ExpressionUUID->"4c9c5726-4cc7-4d43-8ce0-33516cfaf273"],
Cell[CellGroupData[{
Cell[164217, 4081, 1534, 38, 120, "Input",ExpressionUUID->"5f8c50de-07aa-4b8f-9e8f-dca152de4555"],
Cell[165754, 4121, 4704, 128, 274, "Output",ExpressionUUID->"74d6f6f5-ccc4-4647-9401-d1e511bad8dc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[170495, 4254, 2663, 73, 204, "Input",ExpressionUUID->"487673ee-52e3-48ba-8547-da71f6a7aadb"],
Cell[173161, 4329, 366, 9, 50, "Output",ExpressionUUID->"f3ef797d-3f29-429e-9888-0779eb64f645"],
Cell[173530, 4340, 420, 12, 49, "Output",ExpressionUUID->"82a72beb-0c91-43ac-95d1-6cbad5b52c9a"],
Cell[173953, 4354, 1382, 43, 99, "Output",ExpressionUUID->"5386120f-a7b9-47bc-be34-da7cad35921b"],
Cell[175338, 4399, 1454, 46, 99, "Output",ExpressionUUID->"7ab1a397-3200-4b6f-9eeb-0ca563f0b915"]
}, Open  ]],
Cell[CellGroupData[{
Cell[176829, 4450, 1282, 35, 120, "Input",ExpressionUUID->"6a3c2f3d-1566-4c95-97c1-e1e64ad5cc4f"],
Cell[178114, 4487, 772, 21, 34, "Output",ExpressionUUID->"74a9d345-dd54-4358-ab03-7b57dc8b61c2"],
Cell[178889, 4510, 1490, 43, 81, "Output",ExpressionUUID->"afd292e4-ab3f-4ea4-8347-2c05a3c291d5"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[180428, 4559, 514, 9, 54, "Subsection",ExpressionUUID->"26791cd7-8f72-4093-9423-1261d0652e20"],
Cell[180945, 4570, 5837, 145, 419, "Input",ExpressionUUID->"92213a17-4fc8-4be2-9a4a-3afe3a4c487d"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

