(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    186219,       4467]
NotebookOptionsPosition[    178423,       4346]
NotebookOutlinePosition[    178893,       4364]
CellTagsIndexPosition[    178850,       4361]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["No bending case: \[Kappa]1=0, \[Kappa]2=0", "Title",
 CellChangeTimes->{{3.877579626855694*^9, 3.8775796534559593`*^9}, 
   3.87757974502632*^9, 3.877580843652823*^9, 3.877586468371747*^9, {
   3.877601700490007*^9, 3.877601707081295*^9}, 
   3.883988436131216*^9},ExpressionUUID->"53d258d3-0c79-4c56-bf9c-\
acfb8a337b01"],

Cell["\<\
Supplementary material for \[OpenCurlyDoubleQuote]Asymptotic derivation of a \
higher-order one-dimensional model for tape springs; Arun Kumar, Basile \
Audoly, Claire Lestringant\[CloseCurlyDoubleQuote]\
\>", "Subtitle",
 CellChangeTimes->{{3.877601735846743*^9, 
  3.877601738909281*^9}},ExpressionUUID->"2be9cc51-2303-4271-bd31-\
bb099221a161"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
     "This", " ", "notebook", " ", "provides", " ", "supporting", " ", 
      "material", " ", "for", " ", "the", " ", "specialization", " ", "of", 
      " ", "our", " ", "tape", " ", "spring", " ", "model", " ", "to", " ", 
      "the", " ", "case", " ", "of", " ", "no", " ", "bending", " ", 
      RowBox[{"(", 
       RowBox[{"\[Kappa]1", " ", "=", " ", 
        RowBox[{"\[Kappa]2", " ", "=", " ", "0"}]}], ")"}], " ", "presented", 
      " ", "in", " ", "Appendix"}], "-", 
     RowBox[{"B", " ", "of", " ", "the", " ", 
      RowBox[{"paper", ".", "\[IndentingNewLine]", "The"}], " ", "leading", 
      " ", "order", " ", "energy", " ", "term", " ", "for", " ", "the", " ", 
      "special", " ", "case", " ", "is", " ", "presented", " ", "in", " ", 
      "the", " ", "Mathematica", " ", "file", " ", "for", " ", "leading", " ", 
      RowBox[{"order", ".", " ", "The"}], " ", "higher", " ", "order", " ", 
      "terms", " ", "are", " ", "calculated", " ", "in", " ", "this", " ", 
      RowBox[{"file", ".", "  ", "Owing"}], " ", "to", " ", "\[Kappa]1"}]}], 
    " ", "=", " ", 
    RowBox[{
     RowBox[{"0", " ", "the", " ", "first"}], "-", 
     RowBox[{"order", " ", "term", " ", 
      RowBox[{"vanishes", ".", "\n", "  ", "\[IndentingNewLine]", "To"}], " ",
       "calculate", " ", "second"}], "-", 
     RowBox[{"order", " ", "terms"}]}]}], ",", " ", 
   RowBox[{
   "we", " ", "start", " ", "with", " ", "the", " ", "energy", " ", 
    "expression", " ", "involving", " ", "the", " ", "displacement", " ", 
    "correction", " ", "term", " ", 
    RowBox[{"z", ".", " ", "We"}], " ", "calculate", " ", "the", " ", 
    "potential", " ", "and", " ", "take", " ", "its", " ", "variation", " ", 
    "to", " ", "get", " ", "the", " ", "differential", " ", "equations", " ", 
    "for", " ", "zv"}], ",", " ", 
   RowBox[{"zu", " ", "and", " ", 
    RowBox[{"zw", ".", " ", "The"}], " ", "procedure", " ", "is", " ", 
    "identical", " ", "to", " ", "the", " ", "general", " ", "case"}], ",", 
   " ", 
   RowBox[{
    RowBox[{
    "and", " ", "we", " ", "benefit", " ", "from", " ", "the", " ", 
     "simplification", " ", 
     RowBox[{"h\[Dagger]", " ", ".", " ", 
      RowBox[{
       SubscriptBox["\[Del]", "h"], 
       RowBox[{"Yw", "[", "T", "]"}]}]}]}], " ", "=", " ", 
    RowBox[{
    "0.", " ", "We", " ", "easily", " ", "solve", " ", "for", " ", "the", " ",
      "differential", " ", "equations", " ", "for", " ", "zv"}]}], ",", " ", 
   RowBox[{
   "zu", " ", "and", " ", "zw", " ", "for", " ", "the", " ", "special", " ", 
    "case", " ", "and", " ", "use", " ", "these", " ", "displacements", " ", 
    "to", " ", "calculate", " ", "the", " ", "second", " ", "order", " ", 
    "energy", " ", "terms"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.877601735846743*^9, 3.8776017657564487`*^9}, {
  3.877601900572587*^9, 3.877602437868518*^9}, {3.8776026191812143`*^9, 
  3.877602730178812*^9}, {3.877608661834021*^9, 3.8776087376324873`*^9}, {
  3.877615360813092*^9, 3.8776154261311483`*^9}, {3.877670963235491*^9, 
  3.8776710110917253`*^9}, {3.8834744835901423`*^9, 3.8834744840093727`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"4ae26b98-82ac-453c-ab96-733b68fdfb9d"],

Cell[CellGroupData[{

Cell["Preliminaries", "Section",
 CellChangeTimes->{{3.8775829902575693`*^9, 
  3.877582995605624*^9}},ExpressionUUID->"32431199-a326-4a3e-abe8-\
5140e93b4a9b"],

Cell[BoxData[{
 RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ClearAll", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FrontEndTokenExecute", "[", "\"\<DeleteGeneratedCells\>\"", "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.876476267438961*^9, 3.8764762677765923`*^9}, {
   3.877236858908724*^9, 3.8772368654870462`*^9}, {3.8773723341697063`*^9, 
   3.8773723581369762`*^9}, 3.877412480235056*^9, 3.877582910191581*^9, 
   3.877582985504841*^9, 3.8775861442394457`*^9, {3.882606356774397*^9, 
   3.882606358245243*^9}},
 CellLabel->
  "In[110]:=",ExpressionUUID->"39704aad-1bb9-4774-b24c-5696be7e7846"],

Cell[CellGroupData[{

Cell["want to do sanity/consistency checks?", "Subsection",
 CellChangeTimes->{{3.8764763032689457`*^9, 3.876476325898991*^9}, {
   3.876817320245174*^9, 3.8768173988178883`*^9}, {3.876817462707177*^9, 
   3.876817468708086*^9}, {3.8768205463995943`*^9, 3.876820548123602*^9}, {
   3.876930629672821*^9, 3.876930654441105*^9}, {3.8769668818346653`*^9, 
   3.87696692980023*^9}, {3.877136909545273*^9, 3.877136942430546*^9}, {
   3.8771454933674707`*^9, 3.8771454991956863`*^9}, {3.877145556561166*^9, 
   3.877145622419488*^9}, {3.877150561311514*^9, 3.877150586255044*^9}, {
   3.8771518461109133`*^9, 3.877151863799665*^9}, {3.877156185468029*^9, 
   3.877156197001549*^9}, {3.877156314961116*^9, 3.8771563261535177`*^9}, {
   3.877164385209506*^9, 3.877164393207386*^9}, {3.8772291716135674`*^9, 
   3.877229179992193*^9}, {3.877236868253346*^9, 3.8772368720350523`*^9}, {
   3.877371411699435*^9, 3.877371414326598*^9}, {3.877413080099915*^9, 
   3.877413085181151*^9}, 3.8775094373156033`*^9, {3.8775105918373528`*^9, 
   3.8775105920146646`*^9}, 3.877524215697679*^9, {3.877529023755588*^9, 
   3.877529037467195*^9}, {3.87752918397806*^9, 3.877529188176506*^9}, {
   3.877583467331223*^9, 
   3.8775834878648977`*^9}},ExpressionUUID->"8d694171-5145-43c1-8940-\
513913dba0bc"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"doSanityCheck", " ", "=", " ", "True"}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"set", " ", "doSanityCheck", " ", "to", " ", 
    RowBox[{"True", "/", "False"}], " ", "if", " ", "you", " ", 
    RowBox[{"want", "/", "do"}], " ", "not", " ", "want", " ", "to", " ", 
    "perform", " ", "the", " ", "consistency", " ", "checks"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"On", "[", "Assert", "]"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "A", " ", "function", " ", "to", " ", "do", " ", "consistency", " ", 
    "checks"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CheckSanity", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Check", "[", 
      RowBox[{
       RowBox[{"Assert", "[", "#", "]"}], ",", " ", 
       RowBox[{"Abort", "[", "]"}]}], "]"}], "&"}], ")"}]}], ";"}]}], "Input",\

 CellChangeTimes->{{3.8764763032689457`*^9, 3.876476325898991*^9}, {
   3.876817320245174*^9, 3.8768173988178883`*^9}, {3.876817462707177*^9, 
   3.876817468708086*^9}, {3.8768205463995943`*^9, 3.876820548123602*^9}, {
   3.876930629672821*^9, 3.876930654441105*^9}, {3.8769668818346653`*^9, 
   3.87696692980023*^9}, {3.877136909545273*^9, 3.877136942430546*^9}, {
   3.8771454933674707`*^9, 3.8771454991956863`*^9}, {3.877145556561166*^9, 
   3.877145622419488*^9}, {3.877150561311514*^9, 3.877150586255044*^9}, {
   3.8771518461109133`*^9, 3.877151863799665*^9}, {3.877156185468029*^9, 
   3.877156197001549*^9}, {3.877156314961116*^9, 3.8771563261535177`*^9}, {
   3.877164385209506*^9, 3.877164393207386*^9}, {3.8772291716135674`*^9, 
   3.877229179992193*^9}, {3.877236868253346*^9, 3.8772368720350523`*^9}, {
   3.877371411699435*^9, 3.877371414326598*^9}, {3.877413080099915*^9, 
   3.877413085181151*^9}, 3.8775094373156033`*^9, {3.8775105918373528`*^9, 
   3.8775105920146646`*^9}, 3.877524215697679*^9, {3.877529023755588*^9, 
   3.877529037467195*^9}, {3.87752918397806*^9, 3.877529188176506*^9}, {
   3.877583467331223*^9, 3.8775834834587297`*^9}, {3.877595810654142*^9, 
   3.87759581663133*^9}, {3.877617227175774*^9, 3.877617229664023*^9}, {
   3.877617266274301*^9, 3.877617270728241*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"c41766af-6b46-43da-8ec5-d103a050a45c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"$Assumptions", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\[Kappa]1", ",", "\[Kappa]2", ",", "\[Kappa]3", ",", "d\[Kappa]1", 
        ",", "d\[Kappa]2", ",", "d\[Kappa]3", ",", "c", ",", "\[Epsilon]"}], 
       " ", "}"}], "\[Element]", "Reals"}], " ", "&&", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], 
       SuperscriptBox["t", "2"]}], " ", ">", "0"}], " ", "&&", " ", 
     RowBox[{"a", ">", "0"}], "&&", " ", 
     RowBox[{"ks", ">", "0"}], " ", "&&", " ", 
     RowBox[{"0", "<", "t", "<", "a"}], " ", "&&", " ", 
     RowBox[{"0", "<", "\[Nu]", "<", "0.5"}], " ", "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[Nu]", "2"]}], "<", "0"}]}]}], ";"}], " "}]], "Input",\

 CellChangeTimes->{{3.8764763032689457`*^9, 3.876476325898991*^9}, {
   3.876817320245174*^9, 3.8768173988178883`*^9}, {3.876817462707177*^9, 
   3.876817468708086*^9}, {3.8768205463995943`*^9, 3.876820548123602*^9}, 
   3.876930629672821*^9, {3.876930818328162*^9, 3.876930821252952*^9}, {
   3.877100382560156*^9, 3.8771004177322483`*^9}, {3.8771004875141497`*^9, 
   3.8771004933320436`*^9}, 3.8771005346734333`*^9, {3.8771429122890253`*^9, 
   3.8771429158514833`*^9}, {3.877155187241674*^9, 3.877155187496827*^9}, 
   3.8772274464580593`*^9, {3.87722749945474*^9, 3.877227563607544*^9}, {
   3.877227682717112*^9, 3.877227684421707*^9}, {3.877229224661436*^9, 
   3.87722925862991*^9}, {3.877236882079504*^9, 3.877236905027246*^9}, {
   3.8773190726474752`*^9, 3.8773190767075167`*^9}, {3.877319638349769*^9, 
   3.877319647128783*^9}, {3.877319721368867*^9, 3.877319754712872*^9}, {
   3.8773252801284523`*^9, 3.877325281364684*^9}, {3.877523791055874*^9, 
   3.8775237946854362`*^9}, {3.87752410667344*^9, 3.877524111629706*^9}, {
   3.877524146241233*^9, 3.877524153519594*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"52fff9ff-d929-42ec-a608-8e89fec2c0e5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Notation used in this  file", "Subsection",
 CellChangeTimes->{{3.8764763032689457`*^9, 3.876476325898991*^9}, {
   3.876817320245174*^9, 3.8768173988178883`*^9}, {3.876817462707177*^9, 
   3.876817468708086*^9}, {3.8768205463995943`*^9, 3.876820548123602*^9}, 
   3.876930629672821*^9, {3.876930818328162*^9, 3.876930821252952*^9}, {
   3.877100382560156*^9, 3.8771004177322483`*^9}, {3.8771004875141497`*^9, 
   3.8771004933320436`*^9}, {3.8771005346734333`*^9, 
   3.8771006619325323`*^9}, {3.877100700840889*^9, 3.877100803606545*^9}, {
   3.8771008410709352`*^9, 3.8771008650446033`*^9}, {3.877100936731655*^9, 
   3.877101138787685*^9}, {3.877101262053821*^9, 3.87710132690692*^9}, {
   3.877105739972723*^9, 3.87710574526723*^9}, {3.877105854495693*^9, 
   3.877106022482705*^9}, {3.87710669220485*^9, 3.877106704168757*^9}, {
   3.877108354141328*^9, 3.877108359375945*^9}, {3.8771084773272257`*^9, 
   3.87710848308984*^9}, {3.8771085947952833`*^9, 3.877108638740376*^9}, {
   3.87710893794389*^9, 3.877109022309369*^9}, {3.877136840032823*^9, 
   3.877136862829431*^9}, {3.8771405090013943`*^9, 3.8771405100357656`*^9}, 
   3.877140949770193*^9, {3.8771431774093523`*^9, 3.8771432004274607`*^9}, {
   3.877143276332111*^9, 3.877143290216323*^9}, {3.877227619389901*^9, 
   3.877227653811565*^9}, {3.877227695335451*^9, 3.877227696762123*^9}, {
   3.8772440373017178`*^9, 3.877244050771546*^9}, 3.877319779356041*^9, {
   3.877583502919073*^9, 
   3.8775835133130693`*^9}},ExpressionUUID->"df72384d-429e-46dc-8ea1-\
541080dd4b93"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "\[IndentingNewLine]", GridBox[{
     {
      RowBox[{"dYw", "[", "T", "]"}], 
      RowBox[{" ", 
       RowBox[{"h\[Dagger]", ".", " ", 
        RowBox[{
         SubscriptBox["\[Del]", "h"], 
         RowBox[{"Yw", "[", "T", "]"}]}]}]}]},
     {
      RowBox[{"dYv", "[", "T", "]"}], 
      RowBox[{" ", 
       RowBox[{"h\[Dagger]", ".", " ", 
        RowBox[{
         SubscriptBox["\[Del]", "h"], 
         RowBox[{"Yv", "[", "T", "]"}]}]}]}]},
     {
      RowBox[{"dYu", "[", "T", "]"}], 
      RowBox[{" ", 
       RowBox[{"h\[Dagger]", ".", " ", 
        RowBox[{
         SubscriptBox["\[Del]", "h"], 
         RowBox[{"Yu", "[", "T", "]"}]}]}]}]},
     {
      RowBox[{"dn0SS", "[", "T", "]"}], 
      RowBox[{" ", 
       RowBox[{"h\[Dagger]", ".", " ", 
        RowBox[{
         SubscriptBox["\[Del]", "h"], 
         RowBox[{"n0SS", "[", "T", "]"}]}]}]}]}
    },
    GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}}], 
   "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.8764763032689457`*^9, 3.876476325898991*^9}, {
   3.876817320245174*^9, 3.8768173988178883`*^9}, {3.876817462707177*^9, 
   3.876817468708086*^9}, {3.8768205463995943`*^9, 3.876820548123602*^9}, 
   3.876930629672821*^9, {3.876930818328162*^9, 3.876930821252952*^9}, {
   3.877100382560156*^9, 3.8771004177322483`*^9}, {3.8771004875141497`*^9, 
   3.8771004933320436`*^9}, {3.8771005346734333`*^9, 
   3.8771006619325323`*^9}, {3.877100700840889*^9, 3.877100803606545*^9}, {
   3.8771008410709352`*^9, 3.8771008650446033`*^9}, {3.877100936731655*^9, 
   3.877101138787685*^9}, {3.877101262053821*^9, 3.87710132690692*^9}, {
   3.877105739972723*^9, 3.87710574526723*^9}, {3.877105854495693*^9, 
   3.877106022482705*^9}, {3.87710669220485*^9, 3.877106704168757*^9}, {
   3.877108354141328*^9, 3.877108359375945*^9}, {3.8771084773272257`*^9, 
   3.87710848308984*^9}, {3.8771085947952833`*^9, 3.877108638740376*^9}, {
   3.87710893794389*^9, 3.877109022309369*^9}, {3.877136840032823*^9, 
   3.877136862829431*^9}, {3.8771405090013943`*^9, 3.8771405100357656`*^9}, 
   3.877140949770193*^9, {3.8771431774093523`*^9, 3.8771432004274607`*^9}, {
   3.877143276332111*^9, 3.877143290216323*^9}, {3.877227619389901*^9, 
   3.877227653811565*^9}, {3.877227695335451*^9, 3.877227696762123*^9}, {
   3.8772440373017178`*^9, 3.877244050771546*^9}, 3.877319779356041*^9, {
   3.877583502919073*^9, 3.877583507471282*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"6696d940-da3d-4e7d-9c63-7ed7519fd1a7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"stiffnesses", "'"}], " ", "expressions"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"KmExp", " ", "=", 
     FractionBox[
      RowBox[{"Y", " ", "t"}], 
      RowBox[{"1", "-", 
       SuperscriptBox["\[Nu]", "2"]}]]}], " ", ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DbExp", " ", "=", 
     FractionBox[
      RowBox[{"Y", " ", 
       SuperscriptBox["t", "3"]}], 
      RowBox[{"12", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["\[Nu]", "2"]}], ")"}]}]]}], " ", ";"}]}]}]], "Input",\

 CellChangeTimes->{{3.87681749790352*^9, 3.876817505665374*^9}, 
   3.876931424389435*^9, {3.876968551716156*^9, 3.8769685538183813`*^9}, {
   3.87697009310639*^9, 3.87697009344176*^9}, {3.8770055108594418`*^9, 
   3.877005511574963*^9}, {3.877088515916668*^9, 3.877088537722622*^9}, {
   3.877089217277742*^9, 3.87708921755291*^9}, 3.877139947573279*^9, {
   3.877141989053913*^9, 3.8771419910161877`*^9}, {3.877151519641608*^9, 
   3.87715152249244*^9}, {3.8771523020060987`*^9, 3.87715230322244*^9}, {
   3.8774153371500807`*^9, 3.877415425416506*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"9347657c-b617-424b-8ef2-27764f5d432f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"non", " ", "dimensional", " ", "strain"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ksExp", " ", "=", " ", 
    FractionBox["t", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"12", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox["\[Nu]", "2"]}], ")"}]}], ")"}], 
       FractionBox["1", "2"]]}]]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.87681749790352*^9, 3.876817505665374*^9}, 
   3.876931424389435*^9, {3.876968551716156*^9, 3.8769685538183813`*^9}, {
   3.87697009310639*^9, 3.87697009344176*^9}, {3.8770055108594418`*^9, 
   3.877005511574963*^9}, {3.877088515916668*^9, 3.877088537722622*^9}, {
   3.877089217277742*^9, 3.87708921755291*^9}, 3.877139947573279*^9, {
   3.877141989053913*^9, 3.8771419910161877`*^9}, {3.877151519641608*^9, 
   3.87715152249244*^9}, {3.8771523020060987`*^9, 3.877152313692169*^9}, {
   3.877415437820889*^9, 3.877415548357358*^9}, 3.877415643456785*^9},
 CellLabel->"In[12]:=",ExpressionUUID->"5a15fdf2-5314-48d7-b173-ad9e70210ee5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "microdisplacements", " ", "found", " ", "for", " ", "leading", " ", 
    "order", " ", "solution"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Yw", "[", "T_", "]"}], " ", "=", " ", 
     RowBox[{
      FractionBox["1", "2"], " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["a", "2"], "12"]}], "+", 
        SuperscriptBox["T", "2"]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Yv", "[", "T_", "]"}], "=", " ", 
     RowBox[{
      FractionBox["1", "24"], " ", "c", " ", "T", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["T", "2"]}]}], ")"}], " ", "\[Kappa]3"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Yu", "[", "T_", "]"}], " ", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "T"}], " ", "\[Nu]", " ", "\[Epsilon]"}], "-", 
      RowBox[{
       FractionBox["1", "6"], " ", 
       SuperscriptBox["T", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["c", "2"], "+", 
         RowBox[{"\[Nu]", " ", 
          SuperscriptBox["\[Kappa]3", "2"]}]}], ")"}]}]}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.876820064038756*^9, 3.876820128838537*^9}, {
   3.876820219121138*^9, 3.87682021974536*^9}, {3.876820404105648*^9, 
   3.8768205303591557`*^9}, {3.8768205759105797`*^9, 3.876820637356763*^9}, {
   3.876821198707364*^9, 3.8768212175051537`*^9}, {3.8769315995847263`*^9, 
   3.876931600460803*^9}, {3.876931638289497*^9, 3.876931657599105*^9}, {
   3.876931749932707*^9, 3.876931752661777*^9}, {3.876966804460428*^9, 
   3.8769668471740007`*^9}, {3.8771523197128*^9, 3.8771523948812103`*^9}, {
   3.877229293047501*^9, 3.877229368803741*^9}, {3.877229635602088*^9, 
   3.877229663905273*^9}, {3.8772300611982203`*^9, 3.877230062261117*^9}, 
   3.877510501080811*^9, {3.8775216089767523`*^9, 3.8775216099517803`*^9}, 
   3.883993103526144*^9},
 CellLabel->"In[13]:=",ExpressionUUID->"d1d70a15-415b-411a-add3-932d1fe000e9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "stress", " ", "and", " ", "strains", " ", "at", " ", "leading", " ", 
    "order"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"n0SS", "[", "T_", "]"}], " ", "=", 
     RowBox[{
      FractionBox["1", "2"], " ", "t", " ", "Y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "\[Epsilon]"}], "+", 
        RowBox[{
         SuperscriptBox["T", "2"], " ", 
         SuperscriptBox["\[Kappa]3", "2"]}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"E0SS", "[", "T_", "]"}], "=", 
     RowBox[{"\[Epsilon]", "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["T", "2"], " ", 
        SuperscriptBox["\[Kappa]3", "2"]}], "2"]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"m0SS", "[", "T_", "]"}], "=", " ", "0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"B0SS", "[", "T_", "]"}], "=", "0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"m0ST", "[", "T_", "]"}], "=", " ", 
     FractionBox[
      RowBox[{" ", 
       RowBox[{"Y", " ", 
        SuperscriptBox["t", "3"], " ", "\[Kappa]3", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Nu]"}], ")"}]}]}], 
      RowBox[{"12", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["\[Nu]", "2"]}], ")"}]}]]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"B0ST", "[", "T_", "]"}], "=", 
     RowBox[{"-", "\[Kappa]3"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"m0TT", "[", "T_", "]"}], "=", "0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"B0TT", "[", "T_", "]"}], "=", "0"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.876968612008811*^9, 3.876968801510522*^9}, {
   3.876971191496477*^9, 3.876971195699588*^9}, {3.876971234586986*^9, 
   3.876971254069565*^9}, 3.877139914330255*^9, 3.877141147305276*^9, 
   3.877142210747314*^9, 3.877142303208866*^9, {3.8771423407010527`*^9, 
   3.877142342131057*^9}, {3.877142447918782*^9, 3.877142449916073*^9}, {
   3.877145438039093*^9, 3.877145451571044*^9}, {3.877151533777832*^9, 
   3.877151534120825*^9}, {3.8772296977952337`*^9, 3.877229778009882*^9}, {
   3.8774393208167562`*^9, 3.877439333907125*^9}, {3.8774393820051327`*^9, 
   3.877439391940033*^9}, {3.877525241923003*^9, 3.877525243613587*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"26e0bcd8-5d38-47be-b4bf-298130cce3c0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"canonical", " ", "representation"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "dagger", " ", "symbol", " ", "used", " ", "in", " ", "the", " ", "paper",
      " ", "confuses", " ", "with", " ", "plus", " ", "symbol", " ", "in", 
     " ", 
     RowBox[{"Mathematica", ".", " ", "To"}], " ", "overcome", " ", "it"}], 
    ",", " ", 
    RowBox[{
    "we", " ", "denote", " ", "the", " ", "value", " ", "of", " ", 
     "longitudinal", " ", "strain", " ", "gradients", " ", "in", " ", "a", 
     " ", "cross", " ", "section", " ", "by", " ", 
     SubscriptBox["d\[Kappa]", "i"]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"h", "  ", "=", " ", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]", ",", "\[Kappa]3"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dh", "=", " ", 
     RowBox[{"{", 
      RowBox[{"d\[Epsilon]", ",", "d\[Kappa]3"}], "}"}]}], " ", 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.87696978218681*^9, 3.876969805610215*^9}, {
   3.8769703641717567`*^9, 3.876970473106339*^9}, {3.8771370819114532`*^9, 
   3.877137086484332*^9}, {3.877140468372661*^9, 3.877140476359717*^9}, {
   3.877140519229653*^9, 3.8771405490031567`*^9}, 3.877141994823835*^9, {
   3.877151546884131*^9, 3.8771515473911457`*^9}, {3.8772297932976294`*^9, 
   3.877229797409375*^9}, {3.877229978048491*^9, 3.877229981497794*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"935759a6-2c84-49af-a612-72f5c8f890dd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "intermediate", " ", "functions", " ", "used", " ", "in", " ", "the", " ", 
    "calculations"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dYw", "[", "T_", "]"}], "=", " ", 
    RowBox[{"dh", ".", " ", 
     RowBox[{"Grad", "[", 
      RowBox[{
       RowBox[{"Yw", "[", "T", "]"}], ",", "h"}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"dYu", "[", "T_", "]"}], "=", " ", 
     RowBox[{"dh", ".", " ", 
      RowBox[{"Grad", "[", 
       RowBox[{
        RowBox[{"Yu", "[", "T", "]"}], ",", "h"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"dYv", "[", "T_", "]"}], "=", " ", 
     RowBox[{"dh", ".", " ", 
      RowBox[{"Grad", "[", 
       RowBox[{
        RowBox[{"Yv", "[", "T", "]"}], ",", "h"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"dn0SS", "[", "T_", "]"}], "=", "  ", 
     RowBox[{"dh", ".", " ", 
      RowBox[{"Grad", "[", 
       RowBox[{
        RowBox[{"n0SS", "[", "T", "]"}], ",", "h"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"dm0ST", "[", "T_", "]"}], "=", "  ", 
     RowBox[{"dh", ".", " ", 
      RowBox[{"Grad", "[", 
       RowBox[{
        RowBox[{"m0ST", "[", "T", "]"}], ",", "h"}], "]"}]}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.87696978218681*^9, 3.876969805610215*^9}, {
   3.8769703641717567`*^9, 3.876970473106339*^9}, {3.8771370819114532`*^9, 
   3.877137086484332*^9}, {3.877140468372661*^9, 3.877140476359717*^9}, {
   3.877140519229653*^9, 3.8771405490031567`*^9}, 3.877141994823835*^9, {
   3.877151546884131*^9, 3.8771515473911457`*^9}, {3.8772297932976294`*^9, 
   3.877229797409375*^9}, {3.877229978048491*^9, 3.877230044361498*^9}, {
   3.877230953606901*^9, 3.877231021319545*^9}, {3.87731978931973*^9, 
   3.877319793649246*^9}, {3.87740990959009*^9, 3.877409915303241*^9}, {
   3.8774116939947643`*^9, 3.8774117177913647`*^9}, {3.877524237033228*^9, 
   3.877524252116811*^9}, {3.8775244509340878`*^9, 3.8775244741004*^9}, {
   3.88399367093538*^9, 3.88399367219792*^9}, {3.883994005492288*^9, 
   3.8839940115464287`*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"0e181627-175c-4692-adcb-556f5c89c417"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"leading", " ", "order", " ", "energy", " ", "expression"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"leadOrdEnr", " ", "=", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], "Y", " ", "a", " ", "t", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", " ", "+", " ", 
          FractionBox[
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["\[Kappa]3", "2"]}], "24"]}], ")"}], "2"]}], "+", 
      RowBox[{
       FractionBox["1", "2"], 
       FractionBox[
        RowBox[{"Y", " ", "a", " ", 
         SuperscriptBox["t", "3"]}], 
        RowBox[{"6", 
         RowBox[{"(", 
          RowBox[{"1", "+", "\[Nu]"}], ")"}]}]], 
       SuperscriptBox["\[Kappa]3", "2"]}], " ", "+", " ", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SuperscriptBox["a", "5"], " ", "t", " ", "Y", " ", 
       SuperscriptBox["\[Kappa]3", "4"], 
       RowBox[{"(", 
        FractionBox["1", "360"], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"If", "[", 
    RowBox[{"doSanityCheck", ",", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Collect", "[", 
        RowBox[{
         RowBox[{"Simplify", "[", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Integrate", "[", 
             RowBox[{
              RowBox[{
               FractionBox["1", "2"], 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"n0SS", "[", "T", "]"}], 
                  RowBox[{"E0SS", "[", "T", "]"}]}], " ", "+", " ", 
                 RowBox[{
                  RowBox[{"m0SS", "[", "T", "]"}], 
                  RowBox[{"B0SS", "[", "T", "]"}]}], " ", "+", 
                 RowBox[{
                  RowBox[{"m0TT", "[", "T", "]"}], 
                  RowBox[{"B0TT", "[", "T", "]"}]}], "+", 
                 RowBox[{"2", 
                  RowBox[{"m0ST", "[", "T", "]"}], 
                  RowBox[{"B0ST", "[", "T", "]"}]}]}], " ", ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"T", ",", 
                RowBox[{
                 RowBox[{"-", "a"}], "/", "2"}], ",", 
                RowBox[{"a", "/", "2"}]}], "}"}]}], "]"}], "-", 
            "leadOrdEnr"}], ")"}], "]"}], ",", "\[Kappa]3", ",", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"Simplify", "[", 
             RowBox[{"#", ",", 
              RowBox[{"Assumptions", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"a", ">", "0"}], ",", 
                 RowBox[{"a", ">", "t", ">", "0"}], ",", 
                 RowBox[{"0.5", ">", "\[Nu]", ">", "0"}]}], "}"}]}]}], "]"}], 
            ")"}], "&"}], ")"}]}], "]"}], "==", "0"}], "]"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8769693268089933`*^9, 3.876969393013617*^9}, {
   3.876969578481927*^9, 3.8769695830088453`*^9}, {3.876969624254148*^9, 
   3.876969638152968*^9}, {3.8769697121808863`*^9, 3.8769697591965837`*^9}, {
   3.8769698034093246`*^9, 3.876969839562067*^9}, {3.876970735385333*^9, 
   3.876970768290411*^9}, {3.877000141583839*^9, 3.877000232677216*^9}, {
   3.877003084015959*^9, 3.8770030852103558`*^9}, {3.877003239141836*^9, 
   3.877003334852416*^9}, {3.877003380694316*^9, 3.877003415320134*^9}, {
   3.877003638003354*^9, 3.877003703794965*^9}, {3.8770566854687233`*^9, 
   3.877056715936049*^9}, {3.877060631793907*^9, 3.8770606714814177`*^9}, 
   3.8770775825772343`*^9, {3.8771063639640017`*^9, 3.8771063776074667`*^9}, {
   3.877106440469431*^9, 3.877106474257674*^9}, {3.877106565246604*^9, 
   3.877106617693007*^9}, {3.877108371217656*^9, 3.877108380518605*^9}, {
   3.8771405212529182`*^9, 3.877140554547408*^9}, {3.8771408961059*^9, 
   3.877140901144218*^9}, {3.8771420406908197`*^9, 3.877142058791802*^9}, {
   3.877142212401903*^9, 3.877142215117024*^9}, {3.877142527444941*^9, 
   3.87714253086303*^9}, {3.8771433561422873`*^9, 3.877143390136867*^9}, {
   3.877150809604753*^9, 3.877150871409831*^9}, 3.877150916261458*^9, {
   3.877152576206917*^9, 3.877152580042231*^9}, {3.877229820818502*^9, 
   3.8772298215988827`*^9}, {3.8772298550575438`*^9, 3.877229891494475*^9}, 
   3.877229925784232*^9, {3.8772302147072067`*^9, 3.877230217453538*^9}, {
   3.877236925734376*^9, 3.8772369260512733`*^9}, 3.87731980000916*^9, {
   3.877439410941534*^9, 3.877439417178589*^9}, 3.877509448156074*^9, {
   3.877509484929611*^9, 3.877509518235818*^9}, {3.877595849531353*^9, 
   3.877595856624386*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"2bc7175c-bee0-487c-91c6-c315ac8741a3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "First order gradient term:",
 Cell[BoxData[
  RowBox[{"  ", 
   RowBox[{"A", ".", " ", "h\[Dagger]"}]}]],
  CellChangeTimes->{{3.876999716308838*^9, 3.876999719778428*^9}, {
    3.876999791262299*^9, 3.876999823148569*^9}, {3.876999966091852*^9, 
    3.876999988263636*^9}, {3.877000433521043*^9, 3.877000488885623*^9}, 
    3.877000838898486*^9, {3.877000890497925*^9, 3.877000919651627*^9}, {
    3.877002339293315*^9, 3.8770023412681837`*^9}, {3.8770024505128307`*^9, 
    3.877002455383127*^9}, {3.877002517741177*^9, 3.877002546092609*^9}, {
    3.877004056312842*^9, 3.877004115625627*^9}, {3.877004363315894*^9, 
    3.877004367884698*^9}, {3.877139755814892*^9, 3.877139757053953*^9}, {
    3.877142533228709*^9, 3.877142535111288*^9}, 3.877142665138546*^9, {
    3.877143419382751*^9, 3.87714343321734*^9}, {3.877143588609045*^9, 
    3.8771435899496098`*^9}, {3.877151616170932*^9, 3.877151616698037*^9}, {
    3.877324735567295*^9, 3.877324747264461*^9}, 3.877407822630435*^9, {
    3.8775223267905903`*^9, 3.877522361274061*^9}, 3.877524398091016*^9, {
    3.8775245021792803`*^9, 3.8775245198434763`*^9}, {3.8775246700027657`*^9, 
    3.877524682418738*^9}, {3.877532353741651*^9, 3.877532476873117*^9}, 
    3.877532509859695*^9, 3.8775799869985857`*^9},ExpressionUUID->
  "80b77bd0-c4a1-4b09-a19d-a6c28cd4007a"]
}], "Section",
 CellChangeTimes->{{3.876988155478589*^9, 3.876988227990621*^9}, {
   3.876999390562511*^9, 3.876999392481991*^9}, {3.877000990999222*^9, 
   3.8770010581157312`*^9}, {3.877002637655897*^9, 3.877002662141382*^9}, {
   3.8770037802488337`*^9, 3.877003785126947*^9}, {3.87700382117379*^9, 
   3.877003842141083*^9}, {3.8770038768998203`*^9, 3.877003910644436*^9}, {
   3.8770785845931873`*^9, 3.8770785907850027`*^9}, 3.877141510542817*^9, {
   3.877142060157757*^9, 3.8771420611238327`*^9}, 3.877142216563416*^9, {
   3.8771423486926537`*^9, 3.877142350019465*^9}, {3.877143396787369*^9, 
   3.877143410086153*^9}, 3.8771460491241617`*^9, {3.877152592826062*^9, 
   3.877152629946349*^9}, {3.877229968677485*^9, 3.8772299691012907`*^9}, {
   3.877230123836893*^9, 3.877230180699862*^9}, {3.8775835616938667`*^9, 
   3.8775835659275703`*^9}, {3.8775854228263083`*^9, 
   3.877585454425227*^9}},ExpressionUUID->"d35ec7dd-91c4-4d43-aa49-\
1de38f793db1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"first", " ", "order", " ", "gradient", " ", "term", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", 
        FractionBox["a", "2"]}], 
       FractionBox["a", "2"]], 
      RowBox[{"t", " ", "T", " ", "Y", " ", "\[Kappa]1", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"dYv", "[", "T", "]"}], "-", 
         RowBox[{"T", " ", "\[Kappa]3", " ", 
          RowBox[{"dYw", "[", "T", "]"}]}]}], ")"}], 
       RowBox[{"\[DifferentialD]", "T"}], " ", "equals", " ", "zero", " ", 
       "because", " ", "\[Kappa]1"}]}]}], " ", "=", " ", "0"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Adh", " ", "=", "0"}], ";"}], "  "}]], "Input",
 CellChangeTimes->{{3.876988155478589*^9, 3.876988227990621*^9}, {
   3.876999390562511*^9, 3.876999392481991*^9}, {3.877000990999222*^9, 
   3.8770010581157312`*^9}, {3.877002637655897*^9, 3.877002662141382*^9}, {
   3.8770037802488337`*^9, 3.877003785126947*^9}, {3.87700382117379*^9, 
   3.877003842141083*^9}, {3.8770038768998203`*^9, 3.877003910644436*^9}, {
   3.8770785845931873`*^9, 3.8770785907850027`*^9}, 3.877141510542817*^9, {
   3.877142060157757*^9, 3.8771420611238327`*^9}, 3.877142216563416*^9, {
   3.8771423486926537`*^9, 3.877142350019465*^9}, {3.877143396787369*^9, 
   3.877143410086153*^9}, 3.8771460491241617`*^9, {3.877152592826062*^9, 
   3.877152629946349*^9}, {3.877229968677485*^9, 3.8772299691012907`*^9}, {
   3.877230123836893*^9, 3.877230180699862*^9}, 3.8775835616938667`*^9, 
   3.883993685046783*^9},
 CellLabel->"In[33]:=",ExpressionUUID->"9e839389-12fa-49d5-be51-9607281b2660"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Second order terms gradients (",
 Cell[BoxData[
  RowBox[{"h\[Dagger]", ".", " ", 
   SuperscriptBox["B", 
    RowBox[{"(", "1", ")"}]], ".", "z"}]],
  CellChangeTimes->{{3.876999716308838*^9, 3.876999719778428*^9}, {
    3.876999791262299*^9, 3.876999823148569*^9}, {3.876999966091852*^9, 
    3.876999988263636*^9}, {3.877000433521043*^9, 3.877000488885623*^9}, 
    3.877000838898486*^9, {3.877000890497925*^9, 3.877000919651627*^9}, {
    3.877002339293315*^9, 3.8770023412681837`*^9}, {3.8770024505128307`*^9, 
    3.877002455383127*^9}, {3.877002517741177*^9, 3.877002546092609*^9}, {
    3.877004056312842*^9, 3.877004115625627*^9}, {3.877004363315894*^9, 
    3.877004367884698*^9}, {3.877139755814892*^9, 3.877139757053953*^9}, {
    3.877142533228709*^9, 3.877142535111288*^9}, 3.877142665138546*^9, {
    3.877143419382751*^9, 3.87714343321734*^9}, {3.877143588609045*^9, 
    3.8771435899496098`*^9}, {3.877151616170932*^9, 3.877151616698037*^9}, {
    3.877324735567295*^9, 3.877324747264461*^9}, 3.877407822630435*^9, {
    3.8775223267905903`*^9, 3.877522361274061*^9}, 3.877524398091016*^9, {
    3.8775245021792803`*^9, 3.8775245198434763`*^9}, {3.8775246700027657`*^9, 
    3.877524682418738*^9}, {3.877532353741651*^9, 3.877532476873117*^9}, 
    3.877532509859695*^9, 3.8775799869985857`*^9},ExpressionUUID->
  "9bac7ac1-9f90-487f-a44d-d7f2007472e9"],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", "2"], 
   RowBox[{"z", ".", " ", 
    SuperscriptBox["B", 
     RowBox[{"(", "2", ")"}]], ".", "z"}]}]],
  CellChangeTimes->{{3.8770006992073383`*^9, 3.877000707115068*^9}, {
    3.87700074290419*^9, 3.87700076226318*^9}, 3.877000798426526*^9, {
    3.8770008308440027`*^9, 3.8770008885164413`*^9}, {3.8770043294986*^9, 
    3.8770043505298033`*^9}, {3.877004567821703*^9, 3.8770045769380693`*^9}, {
    3.877004616275828*^9, 3.87700464266265*^9}, 3.877004673251775*^9, {
    3.877004717221848*^9, 3.877004725624597*^9}, {3.8770048353123837`*^9, 
    3.877004896227014*^9}, {3.877078603904949*^9, 3.877078623694674*^9}, {
    3.8771397590443087`*^9, 3.8771397602536383`*^9}, {3.877324711851568*^9, 
    3.877324727080205*^9}, {3.8775218354877987`*^9, 3.877521909865629*^9}, {
    3.877522379852137*^9, 3.8775224281916103`*^9}, {3.877522459645728*^9, 
    3.877522476259976*^9}, {3.877524690741798*^9, 3.877524706409527*^9}, {
    3.877532512959372*^9, 3.877532545849325*^9}, {3.8775328282943563`*^9, 
    3.877532829520975*^9}, {3.877532900227874*^9, 3.877532942604125*^9}, {
    3.877533113666583*^9, 3.8775331223748913`*^9}, {3.877533212250414*^9, 
    3.8775332134082193`*^9}},ExpressionUUID->
  "dcf8fc0a-7999-47f0-aad6-5fdbb9658a09"],
 ")"
}], "Section",
 CellChangeTimes->{{3.876999716308838*^9, 3.876999719778428*^9}, {
   3.876999791262299*^9, 3.876999823148569*^9}, {3.876999966091852*^9, 
   3.876999988263636*^9}, {3.877000433521043*^9, 3.877000488885623*^9}, 
   3.877000838898486*^9, {3.877000890497925*^9, 3.877000919651627*^9}, {
   3.877002339293315*^9, 3.8770023412681837`*^9}, {3.8770024505128307`*^9, 
   3.877002455383127*^9}, {3.877002517741177*^9, 3.877002546092609*^9}, {
   3.877004056312842*^9, 3.877004115625627*^9}, {3.877004363315894*^9, 
   3.877004367884698*^9}, {3.877139755814892*^9, 3.877139757053953*^9}, {
   3.877142533228709*^9, 3.877142535111288*^9}, 3.877142665138546*^9, {
   3.877143419382751*^9, 3.87714343321734*^9}, {3.877143588609045*^9, 
   3.8771435899496098`*^9}, {3.877151616170932*^9, 3.877151616698037*^9}, {
   3.877230469896594*^9, 3.8772304733391867`*^9}, {3.8772305767607393`*^9, 
   3.8772305787911663`*^9}, {3.8772306096261263`*^9, 3.877230615104177*^9}, {
   3.877255571079823*^9, 3.877255614498726*^9}, 3.877318419612125*^9, {
   3.877523823538862*^9, 3.877523874597084*^9}, {3.877524278793779*^9, 
   3.877524285755721*^9}, {3.87752434449997*^9, 3.877524421309396*^9}, {
   3.877524498720788*^9, 3.877524526986031*^9}, 3.8775250658358383`*^9, 
   3.8775251211260433`*^9, {3.877525349244084*^9, 3.877525358144022*^9}, {
   3.877533756776243*^9, 3.8775337708647957`*^9}, {3.877533839043833*^9, 
   3.877533862497093*^9}, 3.877534187302579*^9, {3.877534297435874*^9, 
   3.8775343338218393`*^9}, {3.877583571312767*^9, 3.877583582456386*^9}, {
   3.877585740774529*^9, 
   3.877585742336568*^9}},ExpressionUUID->"8210c24d-24d5-4e23-8cbb-\
76ba0290b39e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "the", " ", "expressions", " ", "below", " ", "are", " ", "simplified", 
     " ", "further", " ", "knowing", " ", "that", " ", 
     RowBox[{"dYw", "[", "T", "]"}]}], " ", "=", " ", "0."}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"h\[Dagger]B1z", ":", " ", 
    RowBox[{"terms", " ", "linear", " ", "in", " ", "z"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"first", "-", 
    RowBox[{"line", " ", "terms", " ", "in", " ", 
     RowBox[{"Eq", ".", " ", "5.13"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"t1dhB1z", " ", "=", " ", 
     RowBox[{"(", 
      RowBox[{"Km", " ", 
       RowBox[{"dYv", "[", "T", "]"}], 
       RowBox[{"(", 
        RowBox[{"\[Nu]", 
         RowBox[{"(", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"zu", "'"}], "[", "T", "]"}], "+", 
           RowBox[{
            RowBox[{
             RowBox[{"Yw", "'"}], "[", "T", "]"}], 
            RowBox[{
             RowBox[{"zw", "'"}], "[", "T", "]"}]}]}], ")"}]}], ")"}]}], 
      ")"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"second", "-", 
     RowBox[{"line", " ", "terms", " ", "in", " ", 
      RowBox[{"Eq", ".", " ", "5.13"}]}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"t2dhB1z", " ", "=", 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{
        FractionBox["Km", "2"], "  ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Nu]"}], ")"}], 
        RowBox[{"dYu", "[", "T", "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"zv", "'"}], "[", "T", "]"}], "+", 
          RowBox[{"\[Kappa]3", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"zw", "[", "T", "]"}], "-", 
             RowBox[{"T", " ", 
              RowBox[{
               RowBox[{"zw", "'"}], "[", "T", "]"}]}]}], ")"}]}]}], ")"}]}], 
       "-", 
       RowBox[{"Db", " ", "\[Nu]", " ", "T", " ", "d\[Kappa]3", " ", 
        RowBox[{
         RowBox[{"zw", "''"}], "[", "T", "]"}]}]}], ")"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"third", "-", 
     RowBox[{"line", " ", "terms", " ", "in", " ", 
      RowBox[{"Eq", ".", " ", "5.13"}]}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"t3dhB1z", " ", "=", " ", 
     RowBox[{"-", 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"dn0SS", "[", "T", "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"zv", "[", "T", "]"}], "-", 
           RowBox[{"T", " ", "\[Kappa]3", " ", 
            RowBox[{"zw", "[", "T", "]"}]}]}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"n0SS", "[", "T", "]"}], " ", "T", " ", "d\[Kappa]3", " ", 
         RowBox[{"zw", "[", "T", "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"dm0ST", "[", "T", "]"}], 
         RowBox[{
          RowBox[{"zw", "'"}], "[", "T", "]"}]}]}], " ", ")"}]}]}], " ", 
    ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.876999716308838*^9, 3.876999719778428*^9}, {
   3.876999791262299*^9, 3.876999823148569*^9}, {3.876999966091852*^9, 
   3.876999988263636*^9}, {3.877000433521043*^9, 3.877000488885623*^9}, 
   3.877000838898486*^9, {3.877000890497925*^9, 3.877000919651627*^9}, {
   3.877002339293315*^9, 3.8770023412681837`*^9}, {3.8770024505128307`*^9, 
   3.877002455383127*^9}, {3.877002517741177*^9, 3.877002546092609*^9}, {
   3.877004056312842*^9, 3.877004115625627*^9}, {3.877004363315894*^9, 
   3.877004367884698*^9}, {3.877139755814892*^9, 3.877139757053953*^9}, {
   3.877142533228709*^9, 3.877142535111288*^9}, 3.877142665138546*^9, {
   3.877143419382751*^9, 3.87714343321734*^9}, {3.877143588609045*^9, 
   3.8771435899496098`*^9}, {3.877151616170932*^9, 3.877151616698037*^9}, {
   3.877230469896594*^9, 3.8772304733391867`*^9}, {3.8772305767607393`*^9, 
   3.8772305787911663`*^9}, {3.8772306096261263`*^9, 3.877230615104177*^9}, {
   3.877255571079823*^9, 3.877255614498726*^9}, 3.877318419612125*^9, {
   3.877523823538862*^9, 3.877523874597084*^9}, {3.877524278793779*^9, 
   3.877524285755721*^9}, {3.87752434449997*^9, 3.877524421309396*^9}, {
   3.877524498720788*^9, 3.877524526986031*^9}, 3.8775250658358383`*^9, 
   3.8775251211260433`*^9, {3.877525349244084*^9, 3.877525358144022*^9}, {
   3.877533756776243*^9, 3.8775337708647957`*^9}, {3.877533839043833*^9, 
   3.877533862497093*^9}, 3.877534187302579*^9, {3.877534297435874*^9, 
   3.8775343338218393`*^9}, {3.877583571312767*^9, 3.8775835728629913`*^9}, {
   3.877608892297965*^9, 3.877608899443001*^9}, {3.878639117155016*^9, 
   3.878639126913671*^9}, {3.878639190503579*^9, 3.8786392204277983`*^9}, 
   3.8839936939676437`*^9, 3.8839939660384417`*^9, 3.88399403392596*^9},
 CellLabel->"In[34]:=",ExpressionUUID->"da0f40de-596e-403c-be46-81257da1e2d7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"zB2z", ":", 
    RowBox[{"terms", " ", "quadratic", " ", "in", " ", "z"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"first", "-", 
    RowBox[{"line", " ", "terms", " ", "in", " ", 
     RowBox[{"Eq", ".", " ", "5.14"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"t1zB2z", " ", "=", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Km", " ", 
         RowBox[{"(", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"zu", "'"}], "[", "T", "]"}], "+", 
             RowBox[{
              RowBox[{
               RowBox[{"Yw", "'"}], "[", "T", "]"}], " ", 
              RowBox[{
               RowBox[{"zw", "'"}], "[", "T", "]"}]}]}], ")"}], "2"], ")"}]}],
         "+", 
        RowBox[{"Db", " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"zw", "''"}], "[", "T", "]"}], "2"]}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"second", "-", 
     RowBox[{"line", " ", "terms", " ", "in", " ", 
      RowBox[{"Eq", ".", " ", "5.14"}]}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"t2zB2z", "=", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["Km", "2"], 
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Nu]"}], ")"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"zv", "'"}], "[", "T", "]"}], " ", "+", 
           RowBox[{"\[Kappa]3", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"zw", "[", "T", "]"}], "-", 
              RowBox[{"T", " ", 
               RowBox[{
                RowBox[{"zw", "'"}], "[", "T", "]"}]}]}], ")"}]}]}], ")"}], 
         "2"]}], ")"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8770006992073383`*^9, 3.877000707115068*^9}, {
   3.87700074290419*^9, 3.87700076226318*^9}, 3.877000798426526*^9, {
   3.8770008308440027`*^9, 3.8770008885164413`*^9}, {3.8770043294986*^9, 
   3.8770043505298033`*^9}, {3.877004567821703*^9, 3.8770045769380693`*^9}, {
   3.877004616275828*^9, 3.87700464266265*^9}, 3.877004673251775*^9, {
   3.877004717221848*^9, 3.877004725624597*^9}, {3.8770048353123837`*^9, 
   3.877004896227014*^9}, {3.877078603904949*^9, 3.877078623694674*^9}, {
   3.8771397590443087`*^9, 3.8771397602536383`*^9}, 3.877230657948716*^9, {
   3.877231122702318*^9, 3.877231140295484*^9}, {3.87752391393009*^9, 
   3.8775239426179256`*^9}, 3.877525085852963*^9, {3.877525365510116*^9, 
   3.8775253698443117`*^9}, {3.877526162335884*^9, 3.877526322214508*^9}, {
   3.877533842728528*^9, 3.877533885870255*^9}, 3.8775341881875887`*^9, {
   3.877534319963357*^9, 3.877534334984168*^9}, {3.87753465537357*^9, 
   3.8775346815697927`*^9}, {3.877608836895357*^9, 3.877608843673032*^9}, {
   3.877608884301077*^9, 3.877608889414123*^9}, {3.8786392729336843`*^9, 
   3.878639277114369*^9}, {3.878639311519614*^9, 3.8786393607285767`*^9}, {
   3.8786400045325003`*^9, 3.878640008249284*^9}, {3.88399396136084*^9, 
   3.883993979990778*^9}, {3.883994044223687*^9, 3.8839940515533657`*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"a4d7ab47-70ad-4391-b38a-8ba96cfb794f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Derivation of differential equations", "Section",
 CellChangeTimes->{{3.877583635016717*^9, 
  3.877583640695848*^9}},ExpressionUUID->"63b21f53-65db-4f25-9800-\
003d25d0b471"],

Cell[CellGroupData[{

Cell["Potential and its variation", "Subsection",
 CellChangeTimes->{{3.877005105606927*^9, 3.877005157218639*^9}, {
   3.877006344512466*^9, 3.8770063867872257`*^9}, {3.877006472930174*^9, 
   3.8770064779212503`*^9}, {3.877011324028507*^9, 3.877011324626033*^9}, {
   3.877057769896278*^9, 3.877057781973106*^9}, 3.877141553355358*^9, {
   3.87714607089791*^9, 3.8771461119040413`*^9}, {3.8772306861144037`*^9, 
   3.87723070064161*^9}, 3.8772308819657087`*^9, {3.877583624892126*^9, 
   3.8775836555824633`*^9}},ExpressionUUID->"c246f70a-db31-4765-b25f-\
dcedf73a6352"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "potential", " ", "to", " ", "minimize", " ", "for", " ", "the", " ", "z", 
    " ", "solution"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"potToMinimize", "=", 
    RowBox[{
    "t1dhB1z", "+", "t2dhB1z", "+", "t3dhB1z", "+", "t1zB2z", "+", "t2zB2z", 
     "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"fS", " ", 
        RowBox[{"zv", "[", "T", "]"}]}], " ", "+", " ", 
       RowBox[{"fT", " ", 
        RowBox[{"zu", "[", "T", "]"}]}], " ", "+", " ", 
       RowBox[{"fN", " ", 
        RowBox[{"zw", "[", "T", "]"}]}], " ", "+", " ", 
       RowBox[{"gN", " ", "T", " ", 
        RowBox[{"zw", "[", "T", "]"}]}]}], ")"}]}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.877005105606927*^9, 3.877005157218639*^9}, {
   3.877006344512466*^9, 3.8770063867872257`*^9}, {3.877006472930174*^9, 
   3.8770064779212503`*^9}, {3.877011324028507*^9, 3.877011324626033*^9}, {
   3.877057769896278*^9, 3.877057781973106*^9}, 3.877141553355358*^9, {
   3.87714607089791*^9, 3.8771461119040413`*^9}, {3.8772306861144037`*^9, 
   3.87723070064161*^9}, 3.8772308819657087`*^9, {3.877583624892126*^9, 
   3.877583645330771*^9}, 3.878639431160865*^9, 3.87863980936627*^9, 
   3.878644142678771*^9},
 CellLabel->"In[39]:=",ExpressionUUID->"c8bddfd3-cbdb-41a6-bd41-1c5a2eb8d318"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"minimize", " ", "rules"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"repRulesEta", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"zw", "->", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"zw", "[", "#", "]"}], "+", " ", 
           RowBox[{"\[Eta]", " ", 
            RowBox[{"\[Delta]zw", "[", "#", "]"}]}]}], ")"}], " ", "&"}], 
        ")"}]}], ",", 
      RowBox[{"zu", "->", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"zu", "[", "#", "]"}], "+", " ", 
           RowBox[{"\[Eta]", " ", 
            RowBox[{"\[Delta]zu", "[", "#", "]"}]}]}], ")"}], " ", "&"}], 
        ")"}]}], ",", " ", 
      RowBox[{"zv", "->", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"zv", "[", "#", "]"}], "+", " ", 
           RowBox[{"\[Eta]", " ", 
            RowBox[{"\[Delta]zv", "[", "#", "]"}]}]}], ")"}], " ", "&"}], 
        ")"}]}]}], "}"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.877005307986816*^9, 3.877005383834833*^9}, {
  3.8770063201274147`*^9, 3.8770063367915707`*^9}, {3.8770068724595613`*^9, 
  3.877006886830921*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"d21f47d6-285f-4c7b-b2c3-0cb9ae648818"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "variation", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"eqToSolveForZ", "=", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"potToMinimize", "/.", "repRulesEta"}], ",", "\[Eta]"}], "]"}],
      "/.", 
     RowBox[{"{", 
      RowBox[{"\[Eta]", "->", " ", "0"}], "}"}]}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.877005307986816*^9, 3.877005383834833*^9}, {
   3.8770063201274147`*^9, 3.8770063367915707`*^9}, {3.8770068724595613`*^9, 
   3.87700688707023*^9}, 3.8770785240679617`*^9, {3.8771461002007437`*^9, 
   3.87714611870623*^9}, {3.8771516475685387`*^9, 3.877151647989135*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"3fb1818b-244d-4fef-833c-375dbb0c4734"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Terms with \[Delta]zv and its derivatives ", "Subsection",
 CellChangeTimes->{
  3.877584737690699*^9},ExpressionUUID->"b5c6d873-0835-4505-9285-\
303524ed0556"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "collect", " ", "coefficient", " ", "of", " ", "\[Delta]zv", " ", "and", 
    " ", "its", " ", "derivatives", " ", "in", " ", "the", " ", "variation", 
    " ", "of", " ", "potential"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"eqZv", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{"eqToSolveForZ", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Delta]zw", "->", " ", 
           RowBox[{"(", 
            RowBox[{"0", "&"}], ")"}]}], ",", 
          RowBox[{"\[Delta]zu", "->", " ", 
           RowBox[{"(", 
            RowBox[{"0", "&"}], ")"}]}]}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Delta]zv", "[", "T", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Delta]zv", "'"}], "[", "T", "]"}]}], "}"}], ",", 
      "FullSimplify"}], "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.8770056461077957`*^9, 3.877005667192342*^9}, {
   3.877005705558473*^9, 3.877005806394244*^9}, {3.877006190355116*^9, 
   3.8770061918453827`*^9}, {3.877022485481937*^9, 3.877022500781509*^9}, {
   3.8770532577413177`*^9, 3.877053272967491*^9}, {3.877061650480495*^9, 
   3.87706166296099*^9}, {3.877078498203377*^9, 3.877078512635633*^9}, {
   3.877139919058017*^9, 3.877139920464994*^9}, 3.877145268202771*^9, {
   3.877151655864447*^9, 3.877151656206232*^9}, 3.877151729471819*^9, 
   3.877231219341444*^9, {3.8774088512739897`*^9, 3.877408854996834*^9}, {
   3.877409208230685*^9, 3.877409219112339*^9}, 3.8774096932833033`*^9, {
   3.877534136520535*^9, 3.877534158559023*^9}, {3.877584726836239*^9, 
   3.877584734183448*^9}, {3.877608996188545*^9, 3.8776090078861647`*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"9791a7fb-964c-4687-b595-1cc6f7acc22e"],

Cell[BoxData[
 RowBox[{"(*", "\[IndentingNewLine]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
     "Calculation", " ", "of", " ", "differential", " ", "equation", " ", 
      "for", " ", 
      RowBox[{"zv", ":", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Integral]", 
           RowBox[{
            RowBox[{"-", "a"}], "/", "2"}]], 
          RowBox[{"a", "/", "2"}]], " ", 
         RowBox[{"gv0", " ", "\[Delta]zv"}]}], " ", "+", " ", 
        RowBox[{"gv1", " ", 
         SubscriptBox["\[Delta]zv", 
          RowBox[{",", "T"}]], " ", "dT"}]}]}]}], "=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", 
        RowBox[{
         RowBox[{"-", "a"}], "/", "2"}]], 
       RowBox[{"a", "/", "2"}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"gv0", " ", "\[Delta]zv"}], " ", "+", " ", 
         SubscriptBox[
          RowBox[{"(", 
           RowBox[{"gv1", " ", "\[Delta]zv"}], ")"}], 
          RowBox[{",", "T"}]], " ", "-", 
         RowBox[{
          SubscriptBox["gv1", 
           RowBox[{",", "T"}]], " ", "\[Delta]zv"}]}], ")"}], " ", "dT"}]}], 
     "=", "0"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"gv0", " ", "-", 
          SubscriptBox["gv1", 
           RowBox[{",", "T"}]]}], ")"}], " ", "\[Delta]zv", " ", "dT"}]}], 
      " ", "+", "  ", 
      SuperscriptBox[
       SubscriptBox[
        RowBox[{"[", 
         RowBox[{"gv1", " ", "\[Delta]zv"}], "]"}], 
        RowBox[{
         RowBox[{"-", "a"}], "/", "2"}]], 
       RowBox[{"a", "/", "2"}]]}], "=", "0"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
     "we", " ", "get", " ", "natural", " ", "boundary", " ", "conditions", 
      " ", 
      RowBox[{"as", ":", " ", 
       RowBox[{"gv1", "[", 
        RowBox[{
         RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}]}], "=", "0"}]}], 
   ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "and", " ", "the", " ", "differential", " ", "equation", " ", "as", 
       "\[IndentingNewLine]", "gv0"}], " ", "-", 
      SubscriptBox["gv1", 
       RowBox[{",", "T"}]]}], " ", "=", "0"}], ";", "\[IndentingNewLine]", 
    RowBox[{"on", " ", "integrating"}]}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"we", " ", "get", "\[IndentingNewLine]", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["\[Integral]", "0"], "T"], 
        RowBox[{
         RowBox[{"gv0", "[", "m", "]"}], " ", "dm"}]}]}], " ", "-", " ", 
      "gv1", " ", "+", " ", "cv"}], " ", "=", "0"}], ";", " ", 
    RowBox[{
     RowBox[{"where", " ", "cv"}], " ", "=", " ", 
     RowBox[{"constant", " ", "of", " ", "integration"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"at", " ", "T"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "\[IndentingNewLine]", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Integral]", "0"], 
          RowBox[{"a", "/", "2"}]], 
         RowBox[{
          RowBox[{"gv0", "[", "m", "]"}], " ", "dm"}]}]}], " ", "-", " ", 
       RowBox[{"gv1", "[", 
        RowBox[{"a", "/", "2"}], "]"}], " ", "+", " ", "cv"}], " ", "=", " ", 
      "0"}]}], " ", ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", "0"], 
        RowBox[{
         RowBox[{"-", "a"}], "/", "2"}]], 
       RowBox[{
        RowBox[{"gv0", "[", "m", "]"}], " ", "dm"}]}], " ", "-", " ", 
      RowBox[{"gv1", "[", 
       RowBox[{
        RowBox[{"-", "a"}], "/", "2"}], "]"}], " ", "+", " ", "cv"}], " ", 
     "=", " ", "0"}], " ", ";", "\[IndentingNewLine]", 
    RowBox[{
    "using", " ", "the", " ", "natural", " ", "boundary", " ", 
     "conditions"}]}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"it", " ", "boils", " ", "to", "\[IndentingNewLine]", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["\[Integral]", "0"], 
         RowBox[{"a", "/", "2"}]], 
        RowBox[{
         RowBox[{"gv0", "[", "m", "]"}], " ", "dm"}]}]}], " ", "+", " ", 
      "cv"}], " ", "=", " ", "0"}], " ", ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", "0"], 
        RowBox[{
         RowBox[{"-", "a"}], "/", "2"}]], 
       RowBox[{
        RowBox[{"gv0", "[", "m", "]"}], " ", "dm"}]}], " ", "+", " ", "cv"}], 
     " ", "=", " ", "0"}], " ", ";", "\[IndentingNewLine]", 
    RowBox[{
    "we", " ", "use", " ", "these", " ", "boundary", " ", "conditions", " ", 
     "to", " ", "solve", " ", "for", " ", "cv", " ", "and", " ", "fS", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"contained", " ", "in", " ", "gv0"}], ")"}], "."}]}]}]}], 
  "\[IndentingNewLine]", "*)"}]], "Input",
 CellChangeTimes->{{3.8770056461077957`*^9, 3.877005667192342*^9}, {
   3.877005705558473*^9, 3.877005806394244*^9}, {3.877006190355116*^9, 
   3.8770061918453827`*^9}, {3.877022485481937*^9, 3.877022500781509*^9}, {
   3.8770532577413177`*^9, 3.877053272967491*^9}, {3.877061650480495*^9, 
   3.87706166296099*^9}, {3.877078498203377*^9, 3.877078512635633*^9}, {
   3.877139919058017*^9, 3.877139920464994*^9}, 3.877145268202771*^9, {
   3.877151655864447*^9, 3.877151656206232*^9}, 3.877151729471819*^9, 
   3.877231219341444*^9, {3.8774088512739897`*^9, 3.877408854996834*^9}, {
   3.877409208230685*^9, 3.877409219112339*^9}, {3.8774096932833033`*^9, 
   3.877409697968598*^9}, 3.883994094531393*^9},
 CellLabel->"In[43]:=",ExpressionUUID->"d652d441-50b1-4d10-9612-e8e7f23f83a1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Identify", " ", "coefficients", " ", "of", " ", 
    RowBox[{"\[Delta]zv", "[", "T", "]"}], " ", "and", " ", 
    RowBox[{
     RowBox[{"\[Delta]zv", "'"}], "[", "T", "]"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"gv0", "=", " ", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"eqZv", ",", 
       RowBox[{"\[Delta]zv", "[", "T", "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gv1", "=", " ", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"eqZv", ",", 
       RowBox[{
        RowBox[{"\[Delta]zv", "'"}], "[", "T", "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"sanity", " ", 
     RowBox[{"check", ":", " ", 
      RowBox[{"only", " ", "two", " ", "terms", " ", 
       RowBox[{"(", 
        RowBox[{"gv0", ",", " ", "gv1"}], ")"}], " ", "are", " ", 
       "associated", " ", "with", " ", "\[Delta]zv", " ", "and", " ", "its", 
       " ", "derivatives"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"If", "[", 
    RowBox[{"doSanityCheck", ",", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"gv0", "  ", 
          RowBox[{"\[Delta]zv", "[", "T", "]"}]}], "  ", "+", " ", 
         RowBox[{"gv1", "  ", 
          RowBox[{
           RowBox[{"\[Delta]zv", "'"}], "[", "T", "]"}]}], "-", "eqZv"}], 
        "]"}], "==", "0"}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8770056461077957`*^9, 3.877005667192342*^9}, {
   3.877005705558473*^9, 3.877005806394244*^9}, {3.877006190355116*^9, 
   3.8770061918453827`*^9}, {3.877022485481937*^9, 3.877022500781509*^9}, {
   3.8770532577413177`*^9, 3.877053272967491*^9}, {3.877061650480495*^9, 
   3.87706166296099*^9}, {3.877078498203377*^9, 3.877078512635633*^9}, {
   3.877139919058017*^9, 3.877139920464994*^9}, 3.877145268202771*^9, {
   3.877151655864447*^9, 3.877151656206232*^9}, 3.877151729471819*^9, 
   3.877231219341444*^9, {3.8774088512739897`*^9, 3.877408854996834*^9}, {
   3.877409208230685*^9, 3.877409219112339*^9}, {3.8774096932833033`*^9, 
   3.877409696247348*^9}, {3.8774099296185102`*^9, 3.877409931171424*^9}, 
   3.877509449480441*^9, {3.877534155319561*^9, 3.877534157242735*^9}, {
   3.8775958725960293`*^9, 3.877595876144641*^9}, {3.8776090753198023`*^9, 
   3.8776090757696867`*^9}, {3.877609111446823*^9, 3.8776091220316763`*^9}},
 CellLabel->"In[44]:=",ExpressionUUID->"ae8926cd-4ad3-4242-8473-67e633857e07"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.877022513712929*^9, 3.877022516973556*^9}, {
   3.877053704553198*^9, 3.877053878151829*^9}, {3.877053927770347*^9, 
   3.8770539708771276`*^9}, {3.877054005678164*^9, 3.8770540984145823`*^9}, {
   3.877054172339796*^9, 3.8770542044057407`*^9}, {3.877054272363752*^9, 
   3.877054361658428*^9}, {3.8770544146945953`*^9, 3.877054629323852*^9}, {
   3.8770547469068613`*^9, 3.877054754411489*^9}, {3.8770547845039253`*^9, 
   3.87705481982298*^9}, {3.8770548715690413`*^9, 3.877054893102345*^9}, {
   3.877054928676278*^9, 3.8770549923643303`*^9}, {3.877055023972196*^9, 
   3.877055172801949*^9}, 3.8770553087096243`*^9, {3.877055987277916*^9, 
   3.877055993380925*^9}, {3.87705606612225*^9, 3.8770560699863253`*^9}, {
   3.877056152687504*^9, 3.877056202020637*^9}, {3.8770575913823843`*^9, 
   3.877057606080278*^9}, {3.87713985126781*^9, 3.877139858981791*^9}, {
   3.87715221886835*^9, 3.8771522627296133`*^9}, 3.87715265504243*^9, {
   3.8772314054939938`*^9, 3.877231405777104*^9}, {3.877409683628482*^9, 
   3.877409690594454*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"cb9b9e28-c149-4174-8d83-d32661636d63"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"we", " ", "write", " ", "igv0"}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["\[Integral]", "0"], "T"], " ", 
     RowBox[{
      RowBox[{"gv0", "[", "m", "]"}], " ", "dm"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"igv0", "[", "T_", "]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "T"}], " ", "fS"}], " ", "-", " ", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"dn0SS", "[", "T", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"T", ",", "0", ",", "T"}], "}"}]}], "]"}]}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.877022513712929*^9, 3.877022516973556*^9}, {
   3.877053704553198*^9, 3.877053878151829*^9}, {3.877053927770347*^9, 
   3.8770539708771276`*^9}, {3.877054005678164*^9, 3.8770540984145823`*^9}, {
   3.877054172339796*^9, 3.8770542044057407`*^9}, {3.877054272363752*^9, 
   3.877054361658428*^9}, {3.8770544146945953`*^9, 3.877054629323852*^9}, {
   3.8770547469068613`*^9, 3.877054754411489*^9}, {3.8770547845039253`*^9, 
   3.87705481982298*^9}, {3.8770548715690413`*^9, 3.877054893102345*^9}, {
   3.877054928676278*^9, 3.8770549923643303`*^9}, {3.877055023972196*^9, 
   3.877055172801949*^9}, 3.8770553087096243`*^9, {3.877055987277916*^9, 
   3.877055993380925*^9}, {3.87705606612225*^9, 3.8770560699863253`*^9}, {
   3.877056152687504*^9, 3.877056263910925*^9}, {3.877056316465229*^9, 
   3.877056334521469*^9}, {3.877056389953575*^9, 3.877056517645081*^9}, {
   3.877056596651601*^9, 3.8770566681631327`*^9}, {3.877056909972349*^9, 
   3.877056938805242*^9}, {3.877057635329927*^9, 3.877057684988014*^9}, {
   3.877059894787829*^9, 3.87705989536189*^9}, {3.877139860995453*^9, 
   3.877139862297923*^9}, 3.877142550440325*^9, {3.8771435074330997`*^9, 
   3.877143511619226*^9}, 3.8771436621533747`*^9, {3.8771519346215677`*^9, 
   3.877151935119718*^9}, {3.8771558866910057`*^9, 3.8771558873151627`*^9}, {
   3.877156148243258*^9, 3.877156150835207*^9}, 3.8772278918089867`*^9, {
   3.877231556616836*^9, 3.8772315663450737`*^9}, 3.8772317073456917`*^9, 
   3.877411430553953*^9},
 CellLabel->"In[48]:=",ExpressionUUID->"07b23b9b-58eb-48ed-a764-18cae13f6a1b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"cv", " ", "equals", " ", "zero"}], ",", " ", 
    RowBox[{
     RowBox[{"because", " ", "\[Kappa]1"}], " ", "=", " ", "0"}]}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"from", " ", "general", " ", "case", " ", "file"}], ",", " ", 
    RowBox[{"we", " ", "calculate"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"cvExp", " ", "=", " ", "0"}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"because", " ", "\[Kappa]1"}], " ", "=", " ", 
      RowBox[{"d\[Kappa]1", " ", "=", " ", "0"}]}], ",", " ", 
     RowBox[{
     "see", " ", "general", " ", "case", " ", "Mathematica", " ", "file"}]}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fSExp", "=", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "12"]}], " ", "t", " ", "Y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"12", " ", "d\[Epsilon]"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "d\[Kappa]3", " ", "\[Kappa]3"}]}], 
       ")"}]}]}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{
    "see", " ", "general", " ", "case", " ", "Mathematica", " ", "file"}], 
    " ", "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.877060043824081*^9, 3.877060073160631*^9}, {
   3.877060107925115*^9, 3.877060140491888*^9}, {3.8770603605650806`*^9, 
   3.8770603911685057`*^9}, {3.87706049377262*^9, 3.877060606804925*^9}, {
   3.877060722562911*^9, 3.877060760612526*^9}, {3.877060944236978*^9, 
   3.8770609476989527`*^9}, {3.877061100787385*^9, 3.877061185053154*^9}, {
   3.877076662887693*^9, 3.877076663625435*^9}, {3.877142095634777*^9, 
   3.877142103667554*^9}, {3.877142563775569*^9, 3.877142566514224*^9}, {
   3.87714369347083*^9, 3.877143696668911*^9}, {3.8772317554826603`*^9, 
   3.877231826313933*^9}, 3.877236071158021*^9, {3.87731843497287*^9, 
   3.877318444206861*^9}, 3.877409934948555*^9, {3.877609135270553*^9, 
   3.877609175092894*^9}, {3.8793995292285757`*^9, 3.879399542161385*^9}, {
   3.883988277554187*^9, 3.883988279641449*^9}, {3.883994706409993*^9, 
   3.883994735721931*^9}},
 CellLabel->"In[49]:=",ExpressionUUID->"f4837019-e190-49ff-857e-b1a011aa50f4"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "setting", " ", "the", " ", "expressions", " ", "of", " ", "cv", " ", 
     "and", " ", "fS", " ", "back", " ", "in", " ", "the", " ", "differntial",
      " ", "equation", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Integral]", "0"], "T"], 
         RowBox[{
          RowBox[{"gv0", "[", "m", "]"}], " ", "dm"}]}], " ", "-", " ", "gv1",
         " ", "+", " ", "Cv"}], " ", "=", "0"}], ")"}]}], ",", " ", 
    RowBox[{"we", " ", "get"}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.877022513712929*^9, 3.877022516973556*^9}, {
   3.877053704553198*^9, 3.877053878151829*^9}, {3.877053927770347*^9, 
   3.8770539708771276`*^9}, {3.877054005678164*^9, 3.8770540984145823`*^9}, {
   3.877054172339796*^9, 3.8770542044057407`*^9}, {3.877054272363752*^9, 
   3.877054361658428*^9}, {3.8770544146945953`*^9, 3.877054629323852*^9}, {
   3.8770547469068613`*^9, 3.877054754411489*^9}, {3.8770547845039253`*^9, 
   3.87705481982298*^9}, {3.8770548715690413`*^9, 3.877054893102345*^9}, {
   3.877054928676278*^9, 3.8770549923643303`*^9}, {3.877055023972196*^9, 
   3.877055172801949*^9}, 3.8770553087096243`*^9, {3.877055987277916*^9, 
   3.877055993380925*^9}, {3.87705606612225*^9, 3.8770560699863253`*^9}, {
   3.877056152687504*^9, 3.877056164781526*^9}, {3.877057448436517*^9, 
   3.877057582965824*^9}, 3.877057629974504*^9, 3.877061239038818*^9, {
   3.877061535943677*^9, 3.877061537599843*^9}, {3.8770766985244217`*^9, 
   3.8770767148114023`*^9}, {3.877076751935779*^9, 3.877076752633669*^9}, {
   3.877152663943523*^9, 3.877152671808134*^9}, 3.883994749056292*^9},
 CellLabel->"In[51]:=",ExpressionUUID->"8addf72c-9220-4bd1-aff1-c5f27cf27835"],

Cell[BoxData[
 RowBox[{"diffEqnZv", " ", "=", " ", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"igv0", "[", "T", "]"}], "-", "gv1", "+", "cvExp"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"fS", "->", " ", "fSExp"}], ",", " ", 
        RowBox[{"idn0SS", "->", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"idn0SSfn", "[", "#", "]"}], "&"}], ")"}]}]}], "}"}]}], 
     "]"}], ",", 
    RowBox[{
     RowBox[{"zv", "'"}], "[", "T", "]"}], ",", "FullSimplify"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.877022513712929*^9, 3.877022516973556*^9}, {
   3.877053704553198*^9, 3.877053878151829*^9}, {3.877053927770347*^9, 
   3.8770539708771276`*^9}, {3.877054005678164*^9, 3.8770540984145823`*^9}, {
   3.877054172339796*^9, 3.8770542044057407`*^9}, {3.877054272363752*^9, 
   3.877054361658428*^9}, {3.8770544146945953`*^9, 3.877054629323852*^9}, {
   3.8770547469068613`*^9, 3.877054754411489*^9}, {3.8770547845039253`*^9, 
   3.87705481982298*^9}, {3.8770548715690413`*^9, 3.877054893102345*^9}, {
   3.877054928676278*^9, 3.8770549923643303`*^9}, {3.877055023972196*^9, 
   3.877055172801949*^9}, 3.8770553087096243`*^9, {3.877055987277916*^9, 
   3.877055993380925*^9}, {3.87705606612225*^9, 3.8770560699863253`*^9}, {
   3.877056152687504*^9, 3.877056164781526*^9}, {3.877057448436517*^9, 
   3.877057582965824*^9}, 3.877057629974504*^9, 3.877061239038818*^9, {
   3.877061535943677*^9, 3.877061537599843*^9}, {3.8770766985244217`*^9, 
   3.877076812499345*^9}, {3.877076903820915*^9, 3.87707695883564*^9}, {
   3.877077309118314*^9, 3.877077319939056*^9}, {3.87707793574288*^9, 
   3.877077937712892*^9}, {3.877142105241219*^9, 3.877142106546664*^9}, {
   3.877142569927475*^9, 3.877142570658235*^9}, {3.877143708002226*^9, 
   3.8771437088654737`*^9}, {3.877409265508133*^9, 3.877409265979895*^9}, 
   3.87753433677726*^9},
 CellLabel->"In[52]:=",ExpressionUUID->"a041d4d2-6491-4c4c-9c02-a694097a3560"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "In", " ", "the", " ", "above", " ", "differential", " ", "equation", 
      " ", "diffEqnZv"}], " ", "=", " ", "0"}], ",", " ", 
    RowBox[{"we", " ", "collect", " ", 
     SubscriptBox["zv", 
      RowBox[{",", "T"}]], " ", "on", " ", "left", " ", "hand", " ", "side", 
     " ", "and", " ", "rest", " ", "of", " ", "the", " ", "terms", " ", "on", 
     " ", "right", " ", "hand", " ", "side", " ", "as"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"zvDT", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"zv", "'"}], "[", "T", "]"}], "/.", 
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Collect", "[", 
            RowBox[{
             RowBox[{"Simplify", "[", 
              RowBox[{"diffEqnZv", "/", " ", 
               RowBox[{"(", 
                RowBox[{
                 FractionBox["1", "2"], " ", "Km", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "\[Nu]"}], ")"}]}], " ", ")"}]}], 
              "]"}], ",", 
             RowBox[{
              RowBox[{"zv", "'"}], "[", "T", "]"}], ",", "FullSimplify"}], 
            "]"}], "==", "0"}], ",", 
          RowBox[{
           RowBox[{"zv", "'"}], "[", "T", "]"}], ",", 
          RowBox[{"Assumptions", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Km", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "\[Nu]"}], ")"}]}], "\[NotEqual]", 
             "0"}], "}"}]}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"zw", "[", "T", "]"}], ",", 
        RowBox[{
         RowBox[{"zw", "'"}], "[", "T", "]"}], ",", 
        RowBox[{
         RowBox[{"zw", "''"}], "[", "T", "]"}]}], "}"}], ",", 
      "FullSimplify"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "We", " ", "have", " ", "a", "  ", "first", " ", "order", " ", 
      "differential", " ", 
      RowBox[{"equation", ".", " ", "Once"}], " ", "zw", " ", "is", " ", 
      "known"}], ",", " ", 
     RowBox[{
      RowBox[{
      "we", " ", "can", " ", "solve", " ", "it", " ", "in", " ", "conjuction",
        " ", "with", " ", "the", " ", "integral", " ", "constraint", " ", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["\[Integral]", 
          RowBox[{
           RowBox[{"-", "a"}], "/", "2"}]], 
         RowBox[{"a", "/", "2"}]], " ", 
        RowBox[{"zv", " ", "dT"}]}]}], " ", "=", " ", 
      RowBox[{"0", "  ", "for", " ", "zv"}]}]}], " ", "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.877077485266654*^9, 3.877077512618775*^9}, {
   3.87707764985079*^9, 3.87707777119314*^9}, {3.877077940731495*^9, 
   3.8770779427916517`*^9}, {3.8770820685160646`*^9, 
   3.8770820724413347`*^9}, {3.877151913837326*^9, 3.877151914370894*^9}, {
   3.8774099480801783`*^9, 3.8774099492366943`*^9}, 3.877533845617806*^9, 
   3.877533907944727*^9, 3.8775343379796762`*^9, 3.877609205809536*^9, {
   3.8776092362857018`*^9, 3.877609239654377*^9}, {3.877613592478963*^9, 
   3.877613600840415*^9}},
 CellLabel->"In[53]:=",ExpressionUUID->"2fe3840e-93d2-4d76-8599-4fab340d5363"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Terms with \[Delta]zu and its derivatives ", "Subsection",
 CellChangeTimes->{{3.877077814628242*^9, 3.877077832239193*^9}, {
  3.877078007699695*^9, 3.877078022770813*^9}, {3.877078463882415*^9, 
  3.87707847019411*^9}, {3.8770788337372713`*^9, 3.877078856901472*^9}, {
  3.8770792699972754`*^9, 3.877079283634603*^9}, {3.87708059214437*^9, 
  3.877080746281103*^9}, {3.877080784083632*^9, 3.877080873180328*^9}, {
  3.877080977334309*^9, 3.8770809985672626`*^9}, {3.877081100754863*^9, 
  3.87708115591438*^9}, {3.877369939517921*^9, 3.877369965425001*^9}, {
  3.877526885568142*^9, 3.8775269117662773`*^9}, {3.877584757844634*^9, 
  3.877584767115299*^9}},ExpressionUUID->"9b7feb6f-bab4-421b-991f-\
7e76ae3ff93f"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
     "calculation", " ", "of", " ", "differential", " ", "equation", " ", 
      "for", " ", 
      RowBox[{"zu", ":", " ", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Integral]", 
           RowBox[{
            RowBox[{"-", "a"}], "/", "2"}]], 
          RowBox[{"a", "/", "2"}]], " ", 
         RowBox[{
          RowBox[{"-", "fT"}], " ", "\[Delta]zu"}]}], " ", "+", " ", 
        RowBox[{"gu1", " ", 
         SubscriptBox["\[Delta]zu", 
          RowBox[{",", "T"}]], " ", "dT"}]}]}]}], " ", "=", " ", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"fT", " ", "+", " ", 
           SubscriptBox["gu1", 
            RowBox[{",", "T"}]]}], ")"}]}], " ", "\[Delta]zu", " ", "dT"}]}], 
      "+", " ", 
      SuperscriptBox[
       SubscriptBox[
        RowBox[{"[", 
         RowBox[{"gu1", " ", "\[Delta]zu"}], "]"}], 
        RowBox[{
         RowBox[{"-", "a"}], "/", "2"}]], 
       RowBox[{"a", "/", "2"}]]}], " ", "=", " ", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
     "we", " ", "get", " ", "natural", " ", "boundary", " ", "conditions", 
      " ", 
      RowBox[{"as", ":", " ", 
       RowBox[{"gu1", "[", 
        RowBox[{
         RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}]}], " ", "=", " ", 
     "0"}]}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "and", " ", "the", " ", "differential", " ", "equation", " ", "as", 
      "\[IndentingNewLine]", "fT"}], " ", "+", " ", 
     SubscriptBox["gu1", 
      RowBox[{",", "T"}]]}], " ", "=", " ", 
    RowBox[{"0", "\[IndentingNewLine]", "on", " ", "integrating"}]}], ",", 
   " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"we", " ", "get", "\[IndentingNewLine]", "fT", " ", "T"}], " ", 
      "+", " ", "gu1", " ", "+", " ", "cu"}], " ", "=", " ", "0"}], ";", " ", 
    
    RowBox[{
     RowBox[{"where", " ", "cu"}], " ", "=", " ", 
     RowBox[{"constant", " ", "of", " ", "integration"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"at", " ", "T"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "\[IndentingNewLine]", 
        "fT", " ", 
        RowBox[{"(", 
         FractionBox["a", "2"], ")"}]}], " ", "+", " ", 
       RowBox[{"gu1", "[", 
        FractionBox["a", "2"], "]"}], " ", "+", " ", "cu"}], " ", "=", " ", 
      "0"}]}], " ", ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"fT", " ", 
       RowBox[{"(", 
        RowBox[{"-", 
         FractionBox["a", "2"]}], ")"}]}], " ", "+", " ", 
      RowBox[{"gu1", "[", 
       RowBox[{"-", 
        FractionBox["a", "2"]}], "]"}], " ", "+", " ", "cu"}], " ", "=", " ", 
     "0"}], " ", ";", "\[IndentingNewLine]", 
    RowBox[{
    "using", " ", "the", " ", "natural", " ", "boundry", " ", 
     "conditions"}]}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"it", " ", "boils", " ", "to", "\[IndentingNewLine]", "fT", " ", 
       RowBox[{"(", 
        FractionBox["a", "2"], ")"}]}], "  ", "+", " ", "cu"}], " ", "=", " ",
      "0"}], " ", ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"fT", " ", 
       RowBox[{"(", 
        RowBox[{"-", 
         FractionBox["a", "2"]}], ")"}]}], " ", "+", " ", "cu"}], " ", "=", 
     " ", "0"}], " ", ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"which", " ", "gives", " ", "us", " ", "fT"}], " ", "=", " ", 
     RowBox[{"cu", " ", "=", " ", "0"}]}], ";", " ", 
    RowBox[{
     RowBox[{
     "and", " ", "therefore", " ", "the", " ", "differential", " ", 
      "equation", " ", "\[IndentingNewLine]", "gu1"}], " ", "=", " ", 
     RowBox[{
     "0", "\[IndentingNewLine]", "\[IndentingNewLine]", "It", " ", "is", " ", 
      "a", " ", "first", " ", "order", " ", "differential", " ", 
      RowBox[{"equation", ".", " ", "Once"}], " ", "zw", " ", "is", " ", 
      "known"}]}]}], ",", " ", 
   RowBox[{
    RowBox[{
    "we", " ", "can", " ", "solve", " ", "it", " ", "in", " ", "conjuction", 
     " ", "with", " ", "the", " ", "integral", " ", "constraint", " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", 
        RowBox[{
         RowBox[{"-", "a"}], "/", "2"}]], 
       RowBox[{"a", "/", "2"}]], " ", 
      RowBox[{"zu", " ", "dT"}]}]}], " ", "=", " ", "0"}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.877077814628242*^9, 3.877077832239193*^9}, {
   3.877078007699695*^9, 3.877078022770813*^9}, {3.877078463882415*^9, 
   3.87707847019411*^9}, {3.8770788337372713`*^9, 3.877078856901472*^9}, {
   3.8770792699972754`*^9, 3.877079283634603*^9}, {3.87708059214437*^9, 
   3.877080746281103*^9}, {3.877080784083632*^9, 3.877080873180328*^9}, {
   3.877080977334309*^9, 3.8770809985672626`*^9}, {3.877081100754863*^9, 
   3.87708115591438*^9}, {3.877369939517921*^9, 3.877369965425001*^9}, {
   3.877526885568142*^9, 3.8775269117662773`*^9}, 3.877584757844634*^9, {
   3.8839947572542686`*^9, 3.883994793117148*^9}},
 CellLabel->"In[54]:=",ExpressionUUID->"09673c67-0042-44ee-a0f5-468672b30a4d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"eqZu", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{"eqToSolveForZ", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Delta]zw", "->", " ", 
           RowBox[{"(", 
            RowBox[{"0", "&"}], ")"}]}], ",", 
          RowBox[{"\[Delta]zv", "->", " ", 
           RowBox[{"(", 
            RowBox[{"0", "&"}], ")"}]}]}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Delta]zu", "[", "T", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Delta]zu", "'"}], "[", "T", "]"}]}], "}"}], ",", 
      "FullSimplify"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"collect", " ", "coefficient", " ", "of", " ", 
    SubscriptBox["\[Delta]zu", 
     RowBox[{",", "T"}]], " ", "in", " ", "the", " ", "variation", " ", "of", 
    " ", "potential"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gu1", "=", " ", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"eqZu", ",", 
      RowBox[{
       RowBox[{"\[Delta]zu", "'"}], "[", "T", "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"sanity", " ", 
    RowBox[{"check", ":", " ", 
     RowBox[{"only", " ", "two", " ", "terms", " ", 
      RowBox[{"(", 
       RowBox[{"gu0", ",", " ", "fT"}], ")"}], " ", "are", " ", "associated", 
      " ", "with", " ", "\[Delta]zu", " ", "and", " ", "its", " ", 
      "derivatives", " ", "in", " ", "the", " ", "variation", " ", "of", " ", 
      "potential"}]}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"If", "[", 
  RowBox[{"doSanityCheck", ",", 
   RowBox[{"CheckSanity", "[", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"gu1", " ", 
        RowBox[{
         RowBox[{"\[Delta]zu", "'"}], "[", "T", "]"}]}], "-", 
       RowBox[{"fT", " ", 
        RowBox[{"\[Delta]zu", "[", "T", "]"}]}], "-", "eqZu"}], "]"}], "==", 
     "0"}], "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.877077814628242*^9, 3.877077832239193*^9}, {
   3.877078007699695*^9, 3.877078022770813*^9}, {3.877078463882415*^9, 
   3.877078470701952*^9}, {3.877081949186699*^9, 3.877081966588032*^9}, {
   3.8770820514589443`*^9, 3.877082052840279*^9}, {3.877082340558381*^9, 
   3.8770823889757*^9}, {3.8770827262357407`*^9, 3.877082760095502*^9}, {
   3.8770828076886253`*^9, 3.8770828140086193`*^9}, 3.877509450480638*^9, {
   3.877534018302302*^9, 3.877534068570245*^9}, {3.877595884223659*^9, 
   3.8775958873260307`*^9}, {3.877609375119351*^9, 3.877609393184204*^9}},
 CellLabel->"In[55]:=",ExpressionUUID->"0fe2909e-1d14-4177-b189-c68e840bf172"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "In", " ", "the", " ", "differential", " ", "equation", " ", "gu1"}], 
     " ", "=", " ", "0"}], ",", " ", 
    RowBox[{"we", " ", "collect", " ", 
     SubscriptBox["zu", 
      RowBox[{",", "T"}]], " ", "on", " ", "left", " ", "hand", " ", "side", 
     " ", "and", " ", "rest", " ", "of", " ", "the", " ", "terms", " ", "on", 
     " ", "right", " ", "hand", " ", "side", " ", "as"}]}], " ", "*)"}], " ", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"zuDTCalculated", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"zu", "'"}], "[", "T", "]"}], "/.", 
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Simplify", "[", 
            RowBox[{"gu1", "/", "Km"}], "]"}], "==", "0"}], ",", 
          RowBox[{
           RowBox[{"zu", "'"}], "[", "T", "]"}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"we", " ", "propose", " ", "expression", " ", "for", " ", 
     SubscriptBox["zu", 
      RowBox[{",", "T"}]]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zuDT", "=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "24"]}], " ", "c", " ", "T", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"d\[Kappa]3", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["T", "2"]}]}], ")"}], " ", "\[Nu]"}], "+", 
         RowBox[{"24", " ", 
          RowBox[{
           RowBox[{"zw", "'"}], "[", "T", "]"}]}]}], ")"}]}], ")"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"If", "[", 
    RowBox[{"doSanityCheck", ",", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{"zuDT", "-", "zuDTCalculated"}], "]"}], "==", "0"}], "]"}]}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"The", " ", "equation", " ", "above", "  ", 
      RowBox[{"(", 
       RowBox[{"zuDT", "=", " ", ".."}], " ", ")"}], " ", "is", " ", "a", " ",
       "first", " ", "order", " ", "differential", " ", 
      RowBox[{"equation", ".", " ", "Once"}], " ", "zw", " ", "is", " ", 
      "known"}], ",", " ", 
     RowBox[{
      RowBox[{
      "we", " ", "can", " ", "solve", " ", "it", " ", "in", " ", "conjuction",
        " ", "with", " ", "the", " ", "integral", " ", "constraint", " ", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["\[Integral]", 
          RowBox[{
           RowBox[{"-", "a"}], "/", "2"}]], 
         RowBox[{"a", "/", "2"}]], " ", 
        RowBox[{"zu", " ", "dT"}]}]}], " ", "=", " ", "0"}]}], " ", 
    "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.877082469528946*^9, 3.877082479368155*^9}, {
   3.877082663395711*^9, 3.877082708936462*^9}, 3.877082784839858*^9, 
   3.8770828190243807`*^9, {3.8770828510190887`*^9, 3.877082901968637*^9}, 
   3.8770829834442377`*^9, {3.8770848112526007`*^9, 3.8770848152221603`*^9}, {
   3.877085419627633*^9, 3.8770854243477993`*^9}, {3.877143735567498*^9, 
   3.877143736827957*^9}, {3.877236791716367*^9, 3.877236796984006*^9}, {
   3.877236962974997*^9, 3.877236963997034*^9}, {3.877237022501871*^9, 
   3.877237030006996*^9}, {3.877237060767922*^9, 3.877237088382408*^9}, 
   3.877237124590249*^9, 3.877237174737205*^9, {3.877237223457127*^9, 
   3.8772373335261173`*^9}, {3.877355529284507*^9, 3.8773555452503777`*^9}, 
   3.877509454845703*^9, {3.877527903589282*^9, 3.8775279052840223`*^9}, {
   3.87759589879466*^9, 3.8775959019057827`*^9}, {3.8776094635148077`*^9, 
   3.877609474462267*^9}, {3.877609511550806*^9, 3.877609545870584*^9}, 
   3.8839886352146263`*^9},
 CellLabel->"In[58]:=",ExpressionUUID->"837f8e32-0d23-4373-a429-facf2e89876b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Terms with \[Delta]zw and its derivatives ", "Subsection",
 CellChangeTimes->{{3.8770832512980013`*^9, 3.877083258242156*^9}, {
   3.877083644876461*^9, 3.8770836735219717`*^9}, {3.877085437627351*^9, 
   3.877085453979806*^9}, {3.877085580733629*^9, 3.877085675922286*^9}, {
   3.877085710125102*^9, 3.877085853811496*^9}, {3.877085925894361*^9, 
   3.877085968998953*^9}, {3.877086098699175*^9, 3.877086272203559*^9}, {
   3.877086306402602*^9, 3.8770863657026567`*^9}, {3.877086514753149*^9, 
   3.8770866800938797`*^9}, {3.877086747648378*^9, 3.8770868146774893`*^9}, {
   3.877086858044056*^9, 3.877086872467382*^9}, {3.87708696448761*^9, 
   3.877086973860702*^9}, {3.877087080053789*^9, 3.877087080689988*^9}, {
   3.877087116417864*^9, 3.877087284882596*^9}, {3.877087327523135*^9, 
   3.877087458990073*^9}, {3.877087737120924*^9, 3.8770879730724573`*^9}, {
   3.877088003441382*^9, 3.8770883601528*^9}, {3.8770884083492126`*^9, 
   3.877088427246805*^9}, {3.877089819355278*^9, 3.877089844373837*^9}, {
   3.8770899517052794`*^9, 3.87708997878941*^9}, {3.8770900210095863`*^9, 
   3.8770900328150253`*^9}, 3.8770906151099577`*^9, 3.877236801468814*^9, {
   3.8773184730153503`*^9, 3.877318550408924*^9}, {3.877370021135536*^9, 
   3.8773700227702208`*^9}, {3.877525491037469*^9, 3.877525530485752*^9}, 
   3.877534698066868*^9, {3.877584774111837*^9, 
   3.877584780140218*^9}},ExpressionUUID->"e82d03b9-a802-49f6-a587-\
7b8f42320a38"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "variation", " ", "terms", " ", "that", " ", "involve", " ", 
    "\[Delta]zw", " ", "and", " ", "its", " ", "derivatives"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eqZw", "=", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{"eqToSolveForZ", " ", "/.", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Delta]zu", "->", " ", 
            RowBox[{"(", 
             RowBox[{"0", "&"}], ")"}]}], ",", 
           RowBox[{"\[Delta]zv", "->", " ", 
            RowBox[{"(", 
             RowBox[{"0", "&"}], ")"}]}]}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Delta]zw", "[", "T", "]"}], ",", 
         RowBox[{
          RowBox[{"\[Delta]zw", "'"}], "[", "T", "]"}], ",", 
         RowBox[{
          RowBox[{"\[Delta]zw", "''"}], "[", "T", "]"}]}], "}"}], ",", 
       "FullSimplify"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"sanity", " ", 
      RowBox[{"check", ":", " ", 
       RowBox[{
       "Have", " ", "included", " ", "all", " ", "the", " ", "terms", " ", 
        "of", " ", "variation", " ", "of", " ", "potential", " ", "in", " ", 
        "the", " ", "three", " ", "equations", " ", "eqZu"}]}]}], ",", " ", 
     "eqZv", ",", " ", 
     RowBox[{"and", " ", 
      RowBox[{"eqZw", "?"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"If", "[", 
    RowBox[{"doSanityCheck", ",", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"eqZu", "+", "eqZv", "+", "eqZw"}], ")"}], "-", 
         "eqToSolveForZ"}], "]"}], "==", "0"}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"reorganize", " ", "eqZw"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqZw", "=", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"eqZw", " ", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"zu", "'"}], "[", "T", "]"}], "->", " ", "zuDT"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"zv", "'"}], "[", "T", "]"}], "->", " ", "zvDT"}]}], 
         "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Delta]zw", "[", "T", "]"}], ",", 
         RowBox[{
          RowBox[{"\[Delta]zw", "'"}], "[", "T", "]"}], ",", 
         RowBox[{
          RowBox[{"\[Delta]zw", "''"}], "[", "T", "]"}]}], "}"}], ",", 
       "FullSimplify"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8770832512980013`*^9, 3.877083258242156*^9}, {
   3.877083644876461*^9, 3.8770836735219717`*^9}, {3.877085437627351*^9, 
   3.877085453979806*^9}, {3.877085580733629*^9, 3.877085675922286*^9}, {
   3.877085710125102*^9, 3.877085853811496*^9}, {3.877085925894361*^9, 
   3.877085968998953*^9}, {3.877086098699175*^9, 3.877086272203559*^9}, {
   3.877086306402602*^9, 3.8770863657026567`*^9}, {3.877086514753149*^9, 
   3.8770866800938797`*^9}, {3.877086747648378*^9, 3.8770868146774893`*^9}, {
   3.877086858044056*^9, 3.877086872467382*^9}, {3.87708696448761*^9, 
   3.877086973860702*^9}, {3.877087080053789*^9, 3.877087080689988*^9}, {
   3.877087116417864*^9, 3.877087284882596*^9}, {3.877087327523135*^9, 
   3.877087458990073*^9}, {3.877087737120924*^9, 3.8770879730724573`*^9}, {
   3.877088003441382*^9, 3.8770883601528*^9}, {3.8770884083492126`*^9, 
   3.877088427246805*^9}, {3.877089819355278*^9, 3.877089844373837*^9}, {
   3.8770899517052794`*^9, 3.87708997878941*^9}, {3.8770900210095863`*^9, 
   3.8770900328150253`*^9}, 3.8770906151099577`*^9, 3.877236801468814*^9, {
   3.8773184730153503`*^9, 3.877318550408924*^9}, {3.877370021135536*^9, 
   3.8773700227702208`*^9}, {3.877525491037469*^9, 3.877525530485752*^9}, 
   3.877534698066868*^9, 3.877584774111837*^9, {3.8776095680056133`*^9, 
   3.877609633241149*^9}, {3.883988316188054*^9, 3.883988317837659*^9}},
 CellLabel->"In[61]:=",ExpressionUUID->"3fe71d85-e432-4482-994c-ab0d3d50343b"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
     "Calculation", " ", "of", " ", "differential", " ", "equation", " ", 
      "for", " ", 
      RowBox[{"zw", ":", "\[IndentingNewLine]", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["\[Integral]", 
          RowBox[{
           RowBox[{"-", "a"}], "/", "2"}]], 
         RowBox[{"a", "/", "2"}]], " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"gw0", " ", "\[Delta]zw"}], " ", "+", " ", 
           RowBox[{"gw1", " ", 
            SubscriptBox["\[Delta]zw", 
             RowBox[{",", "T"}]]}], " ", "+", " ", 
           RowBox[{"gw2", " ", 
            SubscriptBox["\[Delta]zw", 
             RowBox[{",", "TT"}]]}]}], ")"}], " ", "dT"}]}]}]}], "=", "0"}], 
    ";", " ", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"we", " ", "can", " ", "write", " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{"gw2", " ", 
        SubscriptBox["\[Delta]zw", 
         RowBox[{",", "TT"}]], " ", "dT", " ", "as", "\[IndentingNewLine]", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Integral]", 
           RowBox[{
            RowBox[{"-", "a"}], "/", "2"}]], 
          RowBox[{"a", "/", "2"}]], " ", 
         RowBox[{"gw2", " ", 
          SubscriptBox["\[Delta]zw", 
           RowBox[{",", "TT"}]], " ", "dT"}]}]}]}]}], " ", "=", "  ", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{
        SubscriptBox[
         RowBox[{"(", 
          RowBox[{"gw2", " ", 
           SubscriptBox["\[Delta]zw", 
            RowBox[{",", "T"}]]}], ")"}], 
         RowBox[{",", "T"}]], " ", "dT"}]}], " ", "-", " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{
        SubscriptBox["gw2", 
         RowBox[{",", "T"}]], " ", 
        SubscriptBox["\[Delta]zw", 
         RowBox[{",", "T"}]], " ", "dT"}]}]}]}]}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["\[Integral]", 
       RowBox[{
        RowBox[{"-", "a"}], "/", "2"}]], 
      RowBox[{"a", "/", "2"}]], " ", 
     RowBox[{"gw2", " ", 
      SubscriptBox["\[Delta]zw", 
       RowBox[{",", "TT"}]], " ", "dT"}]}], " ", "=", "  ", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox[
       RowBox[{"[", 
        RowBox[{"gw2", " ", 
         SubscriptBox["\[Delta]zw", 
          RowBox[{",", "T"}]]}], "]"}], 
       RowBox[{
        RowBox[{"-", "a"}], "/", "2"}]], 
      RowBox[{"a", "/", "2"}]], " ", "-", " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", 
        RowBox[{
         RowBox[{"-", "a"}], "/", "2"}]], 
       RowBox[{"a", "/", "2"}]], " ", 
      RowBox[{
       SubscriptBox["gw2", 
        RowBox[{",", "T"}]], " ", 
       SubscriptBox["\[Delta]zw", 
        RowBox[{",", "T"}]], " ", "dT"}]}]}]}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "this", " ", "gives", " ", "first", " ", "natural", " ", "boundary", " ", 
     "condition", " ", "as", " ", 
     RowBox[{"gw2", "[", 
      RowBox[{
       RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}], " ", "=", " ", 
    "0"}], ",", " ", 
   RowBox[{"on", " ", "clubbing", " ", "terms"}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "which", " ", "can", " ", "be", " ", "rewritten", " ", "as", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"zw", "''"}], "[", 
       RowBox[{
        RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}], " ", "=", " ", 
     RowBox[{"D2zwBc", "[", 
      RowBox[{
       RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}], ";", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"on", " ", "setting", " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{"gw2", " ", 
        SubscriptBox["\[Delta]zw", 
         RowBox[{",", "TT"}]], " ", "dT"}]}]}], " ", "=", 
     RowBox[{"-", " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{
        SubscriptBox["gw2", 
         RowBox[{",", "T"}]], " ", 
        SubscriptBox["\[Delta]zw", 
         RowBox[{",", "T"}]], " ", "dT", " ", "in", " ", "the", " ", 
        "initial", " ", "equation", " ", "above", " ", "and", " ", "clubbing",
         " ", "the", " ", "terms", " ", "with", " ", "factor", " ", 
        SubscriptBox["\[Delta]zw", 
         RowBox[{",", "T"}]]}]}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"we", " ", "get", " ", "\[IndentingNewLine]", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"gw1", " ", "-", " ", 
          SubscriptBox["gw2", 
           RowBox[{",", "T"}]]}], ")"}], " ", 
        SubscriptBox["\[Delta]zw", 
         RowBox[{",", "T"}]], " ", "dT"}]}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["gw2", 
           RowBox[{",", "TT"}]], "-", " ", 
          SubscriptBox["gw1", 
           RowBox[{",", "T"}]]}], ")"}], " ", "\[Delta]zw", " ", "dT"}]}], 
      " ", "-", "  ", 
      SuperscriptBox[
       SubscriptBox[
        RowBox[{"[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["gw2", 
             RowBox[{",", "T"}]], "-", " ", "gw1"}], ")"}], "\[Delta]zw"}], 
         "]"}], 
        RowBox[{
         RowBox[{"-", "a"}], "/", "2"}]], 
       RowBox[{"a", "/", "2"}]]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
      "this", " ", "gives", " ", "the", " ", "second", " ", "natural", " ", 
       "boundary", " ", "condition", " ", "as", " ", 
       SubscriptBox["gw2", 
        RowBox[{",", "T"}]]}], " ", "-", " ", "gw1"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"0", " ", "at", " ", "T"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"\[PlusMinus]", "a"}], "/", "2"}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"which", " ", "can", " ", "be", " ", "rewritten", " ", "as", "  ", 
      RowBox[{
       RowBox[{"zw", "'''"}], "[", 
       RowBox[{
        RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}], " ", "=", " ", 
     RowBox[{"D3zwBc", "[", 
      RowBox[{
       RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"on", " ", "using", " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"gw1", " ", "-", " ", 
          SubscriptBox["gw2", 
           RowBox[{",", "T"}]]}], ")"}], " ", 
        SubscriptBox["\[Delta]zw", 
         RowBox[{",", "T"}]], " ", "dT"}]}]}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", 
        RowBox[{
         RowBox[{"-", "a"}], "/", "2"}]], 
       RowBox[{"a", "/", "2"}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["gw2", 
          RowBox[{",", "TT"}]], "-", " ", 
         SubscriptBox["gw1", 
          RowBox[{",", "T"}]]}], ")"}], " ", "\[Delta]zw", " ", "dT"}]}]}]}], 
   ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "we", " ", "can", " ", "rewrite", " ", "the", " ", "inital", " ", 
      "equation", " ", "as", "\[IndentingNewLine]", "  ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"gw0", " ", "-", " ", 
          SubscriptBox["gw1", 
           RowBox[{",", "T"}]], " ", "+", " ", 
          SubscriptBox["gw2", 
           RowBox[{",", "TT"}]]}], ")"}], "\[Delta]zw", "  ", "dT"}]}]}], " ",
      "=", " ", "0"}], ";", "\[IndentingNewLine]", 
    RowBox[{"on", " ", "rearranging", " ", "the", " ", "terms"}]}], ",", " ", 
   
   RowBox[{
    RowBox[{
     RowBox[{
     "we", " ", "get", " ", "the", " ", "differential", " ", "equation", " ", 
      "for", " ", "zw", " ", "as", "  ", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"zw", "''''"}], "[", "T", "]"}]}], "  ", "=", " ", 
     RowBox[{
      RowBox[{"nonHomzw", "[", "T", "]"}], " ", "+", " ", 
      FractionBox["fN", "Db"], " ", "+", " ", 
      FractionBox[
       RowBox[{"T", " ", "gN"}], "Db"]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
     "intergrating", " ", "the", " ", "above", " ", "equation", " ", "along", 
      " ", "T", " ", "from"}], " ", "-", 
     RowBox[{
      RowBox[{"a", "/", "2"}], " ", "to", " ", 
      RowBox[{"a", "/", "2"}]}]}]}], ",", " ", 
   RowBox[{
    RowBox[{
    "we", " ", "calculate", " ", "fN", " ", "\[IndentingNewLine]", "fN"}], 
    "=", " ", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox[
       RowBox[{
        RowBox[{"(", 
         FractionBox["Db", "a"], ")"}], "[", 
        RowBox[{
         RowBox[{
          RowBox[{"zw", "'''"}], "[", "T", "]"}], "-", 
         RowBox[{"inonHomzw", "[", "T", "]"}]}], "]"}], 
       RowBox[{
        RowBox[{"-", "a"}], "/", "2"}]], 
      RowBox[{"a", "/", "2"}]], " ", "=", " ", 
     SuperscriptBox[
      SubscriptBox[
       RowBox[{
        RowBox[{"(", 
         FractionBox["Db", "a"], ")"}], "[", 
        RowBox[{
         RowBox[{"D3zwBc", "[", "T", "]"}], "-", 
         RowBox[{"inonHomzw", "[", "T", "]"}]}], "]"}], 
       RowBox[{
        RowBox[{"-", "a"}], "/", "2"}]], 
      RowBox[{"a", "/", "2"}]]}]}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"where", " ", 
      RowBox[{"inonHomzw", "[", "T", "]"}]}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", "0"], "T"], " ", 
      RowBox[{
       RowBox[{"nonHomzw", "[", "m", "]"}], " ", "dm"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
     "we", " ", "multiply", " ", "the", " ", "differential", " ", "equation", 
      " ", "by", " ", "T", "\[IndentingNewLine]", "T", " ", 
      RowBox[{
       RowBox[{"zw", "''''"}], "[", "T", "]"}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{"T", " ", 
       RowBox[{"nonHomzw", "[", "T", "]"}]}], " ", "+", " ", 
      FractionBox[
       RowBox[{"T", " ", "fN"}], "Db"], " ", "+", " ", 
      FractionBox[
       RowBox[{
        SuperscriptBox["T", "2"], " ", "gN"}], "Db"]}]}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox[
      RowBox[{"(", 
       RowBox[{"T", " ", 
        RowBox[{
         RowBox[{"zw", "'''"}], "[", "T", "]"}]}], ")"}], 
      RowBox[{",", "T"}]], " ", "-", " ", 
     RowBox[{
      RowBox[{"zw", "''"}], "[", "T", "]"}], " ", "-", " ", 
     RowBox[{"T", " ", 
      RowBox[{"nonHomzw", "[", "T", "]"}]}]}], " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"T", " ", "fN"}], "Db"], " ", "+", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["T", "2"], " ", "gN"}], "Db"]}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
     "on", " ", "integrating", " ", "the", " ", "above", " ", "equation", " ",
       "along", " ", "T", " ", "from"}], " ", "-", 
     RowBox[{
      RowBox[{"a", "/", "2"}], " ", "to", " ", 
      RowBox[{"a", "/", "2"}], " ", "and", " ", "using", " ", "the", " ", 
      "first", " ", "natural", " ", "and", " ", "second", " ", "boundary", 
      " ", "conditions", " ", "and", " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{"T", " ", "zw", " ", "dT"}]}]}]}], " ", "=", " ", "0"}], ",", 
   " ", 
   RowBox[{
    RowBox[{"we", " ", "get", " ", "gN", " ", "\[IndentingNewLine]", "gN"}], 
    " ", "=", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       SubscriptBox[
        RowBox[{
         FractionBox[
          RowBox[{"12", " ", "Db"}], 
          SuperscriptBox["a", "3"]], " ", "[", 
         RowBox[{
          RowBox[{"T", " ", 
           RowBox[{"D3zwBc", "[", "T", "]"}]}], " ", "-", " ", 
          RowBox[{"D2zwBc", "[", "T", "]"}], " ", "-", " ", 
          RowBox[{"iTnonHomzw", "[", "T", "]"}]}], "]"}], 
        RowBox[{
         RowBox[{"-", "a"}], "/", "2"}]], 
       RowBox[{"a", "/", "2"}]], " ", "where", "  ", 
      RowBox[{"iTnonHomzw", "[", "T", "]"}]}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", "0"], "T"], " ", 
      RowBox[{"m", " ", 
       RowBox[{"nonHomzw", "[", "m", "]"}], " ", "dm"}]}]}]}]}], 
  "\[IndentingNewLine]", "*)"}]], "Input",
 CellChangeTimes->{{3.8770832512980013`*^9, 3.877083258242156*^9}, {
   3.877083644876461*^9, 3.8770836735219717`*^9}, {3.877085437627351*^9, 
   3.877085453979806*^9}, {3.877085580733629*^9, 3.877085675922286*^9}, {
   3.877085710125102*^9, 3.877085853811496*^9}, {3.877085925894361*^9, 
   3.877085968998953*^9}, {3.877086098699175*^9, 3.877086272203559*^9}, {
   3.877086306402602*^9, 3.8770863657026567`*^9}, {3.877086514753149*^9, 
   3.8770866800938797`*^9}, {3.877086747648378*^9, 3.8770868146774893`*^9}, {
   3.877086858044056*^9, 3.877086872467382*^9}, {3.87708696448761*^9, 
   3.877086973860702*^9}, {3.877087080053789*^9, 3.877087080689988*^9}, {
   3.877087116417864*^9, 3.877087284882596*^9}, {3.877087327523135*^9, 
   3.877087458990073*^9}, {3.877087737120924*^9, 3.8770879730724573`*^9}, {
   3.877088003441382*^9, 3.8770883601528*^9}, {3.8770884083492126`*^9, 
   3.877088427246805*^9}, {3.877089819355278*^9, 3.877089844373837*^9}, {
   3.8770899517052794`*^9, 3.87708997878941*^9}, {3.8770900210095863`*^9, 
   3.8770900328150253`*^9}, 3.8770906151099577`*^9, 3.877236801468814*^9, {
   3.8773184730153503`*^9, 3.877318550408924*^9}, {3.877370021135536*^9, 
   3.8773700227702208`*^9}, {3.877525491037469*^9, 3.877525530485752*^9}, 
   3.877534698066868*^9, 3.877584774111837*^9, 3.8776095680056133`*^9, {
   3.8839855980523376`*^9, 3.8839855994369097`*^9}, 3.883988539594768*^9, {
   3.8839949081877213`*^9, 3.88399492701678*^9}},
 CellLabel->"In[64]:=",ExpressionUUID->"ada966a5-8458-4c7a-8736-8566ff92f6a0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "collect", " ", "coefficient", " ", "of", " ", "\[Delta]zw", " ", "in", 
    " ", "the", " ", "variation"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"gw0", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"eqZw", ",", 
        RowBox[{"\[Delta]zw", "[", "T", "]"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"collect", " ", "coefficient", " ", "of", " ", 
     SubscriptBox["\[Delta]zw", 
      RowBox[{",", "T"}]], " ", "in", " ", "the", " ", "variation"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gw1", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"eqZw", ",", 
        RowBox[{
         RowBox[{"\[Delta]zw", "'"}], "[", "T", "]"}]}], "]"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"collect", " ", "coefficient", " ", "of", " ", 
     SubscriptBox["\[Delta]zw", 
      RowBox[{",", "TT"}]], " ", "in", " ", "the", " ", "variation"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gw2", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"eqZw", ",", 
        RowBox[{
         RowBox[{"\[Delta]zw", "''"}], "[", "T", "]"}]}], "]"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"sanity", " ", 
     RowBox[{"check", ":", " ", 
      RowBox[{"only", " ", "three", " ", "terms", " ", 
       RowBox[{"(", 
        RowBox[{"gw0", ",", " ", "gw1", ",", " ", "gw2"}], ")"}], " ", "are", 
       " ", "associated", " ", "with", " ", "\[Delta]zw", " ", "and", " ", 
       "its", " ", "derivatives", " ", "in", " ", "the", " ", "variation", 
       " ", "of", " ", "potential"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   
   RowBox[{"If", "[", 
    RowBox[{"doSanityCheck", ",", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"gw0", " ", 
          RowBox[{"\[Delta]zw", "[", "T", "]"}]}], " ", "+", " ", 
         RowBox[{"gw1", " ", 
          RowBox[{
           RowBox[{"\[Delta]zw", "'"}], "[", "T", "]"}]}], "+", " ", 
         RowBox[{"gw2", " ", 
          RowBox[{
           RowBox[{"\[Delta]zw", "''"}], "[", "T", "]"}]}], "-", "eqZw"}], 
        "]"}], "==", "0"}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8770832512980013`*^9, 3.877083258242156*^9}, {
   3.877083644876461*^9, 3.8770836735219717`*^9}, 3.877085437627351*^9, {
   3.877085527687989*^9, 3.8770855391938057`*^9}, {3.877090064011057*^9, 
   3.877090072137437*^9}, {3.877355083265671*^9, 3.877355098270568*^9}, {
   3.877509456051759*^9, 3.877509456771614*^9}, {3.8775339810261993`*^9, 
   3.877533999733696*^9}, {3.877534321235874*^9, 3.877534332253212*^9}, {
   3.877595908760811*^9, 3.8775959225142*^9}, {3.877609579652556*^9, 
   3.877609584397738*^9}, {3.877609656907341*^9, 3.877609676992401*^9}, {
   3.877609722692503*^9, 3.87760972322968*^9}},
 CellLabel->"In[65]:=",ExpressionUUID->"977acfca-08a0-40a2-bbb6-0b255ac86712"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "the", " ", "differential", " ", "equation", " ", "for", " ", "zw"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"diffEqnZw", "=", 
   RowBox[{"Collect", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{"gw2", ",", 
          RowBox[{"{", 
           RowBox[{"T", ",", "2"}], "}"}]}], "]"}], "-", " ", 
        RowBox[{"D", "[", 
         RowBox[{"gw1", ",", "T"}], "]"}], "+", "gw0"}], ")"}], "/", "Db"}], 
     " ", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"zw", "[", "T", "]"}], ",", 
       RowBox[{
        RowBox[{"zw", "'"}], "[", "T", "]"}], ",", 
       RowBox[{
        RowBox[{"zw", "''"}], "[", "T", "]"}], ",", 
       RowBox[{
        RowBox[{"zw", "'''"}], "[", "T", "]"}], ",", 
       RowBox[{
        RowBox[{"zw", "''''"}], "[", "T", "]"}], ",", " ", "fN", ",", 
       RowBox[{"gN", " ", "T"}]}], "}"}], ",", "FullSimplify"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8770891285299253`*^9, 3.877089141957427*^9}, {
   3.877089179799315*^9, 3.877089205343918*^9}, {3.877141643090095*^9, 
   3.877141645977737*^9}, {3.877152813483418*^9, 3.87715282981149*^9}, 
   3.877238048647299*^9, 3.877533846703479*^9, {3.877533909324963*^9, 
   3.877533942070517*^9}},
 CellLabel->"In[69]:=",ExpressionUUID->"a96f9314-4402-428b-b59e-ba09d15fab0f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"natural", " ", "boundary", " ", 
     RowBox[{"condition", ":", " ", 
      RowBox[{
       RowBox[{"zw", "''"}], "[", 
       RowBox[{
        RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}]}], " ", "=", " ", 
    RowBox[{"D2zwBc", "[", 
     RowBox[{
      RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"D2zwBc", "[", "T_", "]"}], " ", "=", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", " ", 
       RowBox[{"gw2", "/", "Db"}], ")"}]}], " ", "+", 
     RowBox[{
      RowBox[{"zw", "''"}], "[", "T", "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"natural", " ", "boundary", " ", 
      RowBox[{"condition", ":", " ", 
       RowBox[{
        RowBox[{"zw", "'''"}], "[", 
        RowBox[{
         RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}]}], " ", "=", " ", 
     
     RowBox[{"D3zwBc", "[", 
      RowBox[{
       RowBox[{"\[PlusMinus]", "a"}], "/", "2"}], "]"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"D3zwBc", "[", "T_", "]"}], " ", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Simplify", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"D", "[", 
                 RowBox[{"gw2", ",", "T"}], "]"}]}], "+", "gw1"}], ")"}], "/",
              "Db"}], ")"}], " ", "+", 
           RowBox[{
            RowBox[{"zw", "'''"}], "[", "T", "]"}]}], "]"}], "/.", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"dm0ST", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"dm0STfn", "[", "#", "]"}], "&"}], ")"}]}], ",", " ", 
           RowBox[{"idn0SS", "->", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"idn0SSfn", "[", "#", "]"}], "&"}], ")"}]}]}], "}"}]}], 
        "/.", 
        RowBox[{"{", 
         RowBox[{"Db", "->", " ", "DbExp"}], "}"}]}], "]"}], ",", 
      "d\[Kappa]3", ",", "Simplify"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.877089562591235*^9, 3.877089569126189*^9}, {
   3.8770896870607853`*^9, 3.877089695061591*^9}, {3.87708973849051*^9, 
   3.877089746221363*^9}, {3.877090099471476*^9, 3.877090120472905*^9}, {
   3.877090241011812*^9, 3.877090282226797*^9}, {3.877090396797496*^9, 
   3.877090400993243*^9}, {3.877090481341448*^9, 3.877090500834477*^9}, 
   3.877142108123414*^9, {3.8771425768765*^9, 3.877142577870945*^9}, {
   3.877142674824102*^9, 3.8771426764694967`*^9}, {3.877143793849131*^9, 
   3.877143809649416*^9}, 3.877241121997622*^9, {3.877242050798092*^9, 
   3.877242058127234*^9}, {3.877609746237728*^9, 3.877609773212462*^9}},
 CellLabel->"In[70]:=",ExpressionUUID->"16101f47-4779-4df9-8c43-ff07b647826d"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
    "We", " ", "want", " ", "the", " ", "differential", " ", "equation", " ", 
     "diffEqnZw", " ", "in", " ", "this", " ", "form", " ", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"zw", "''''"}], "[", "T", "]"}]}], "  ", "=", " ", 
    RowBox[{
     RowBox[{"nonHomzw", "[", "T", "]"}], " ", "+", " ", 
     FractionBox["fN", "Db"], " ", "+", " ", 
     FractionBox[
      RowBox[{"T", " ", "gN"}], "Db"]}]}], ";", " ", 
   RowBox[{
    RowBox[{"we", " ", "calculate", " ", "the", " ", "non"}], "-", 
    RowBox[{"homogeneous", " ", "part", " ", 
     RowBox[{"nonHomzw", "[", "T", "]"}], " ", "as"}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.8770905772393637`*^9, 3.877090590490191*^9}, {
   3.877090650464807*^9, 3.877090708082748*^9}, {3.877090811568214*^9, 
   3.877090837731523*^9}, {3.8770909495826807`*^9, 3.877090961256481*^9}, 
   3.8770911229469337`*^9, {3.877091739338058*^9, 3.877091769033226*^9}, 
   3.877227912430646*^9, {3.877238313086899*^9, 3.877238313584899*^9}, {
   3.877242224693309*^9, 3.877242236244573*^9}, 3.8775347140870657`*^9, 
   3.877609850937215*^9, 3.883988561741713*^9},
 CellLabel->"In[72]:=",ExpressionUUID->"86cfe238-3da7-4ba7-81d4-5082983444ec"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nonHomzw", "[", "T_", "]"}], " ", "=", "  ", 
  RowBox[{"-", 
   RowBox[{"Simplify", "[", 
    RowBox[{"diffEqnZw", " ", "-", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"zw", "''''"}], "[", "T", "]"}], "  ", "-", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["fN", "Db"], "+", 
         FractionBox[
          RowBox[{"gN", " ", "T"}], "Db"]}], ")"}]}], ")"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.877091781125448*^9, 3.877091888426427*^9}, {
   3.877091933290057*^9, 3.877091964231841*^9}, {3.877092112690422*^9, 
   3.877092188145534*^9}, {3.87709374351624*^9, 3.877093744038048*^9}, 
   3.877094808457583*^9, {3.877101488024021*^9, 3.87710152009871*^9}, {
   3.8771083912698717`*^9, 3.877108394148438*^9}, {3.877142109998295*^9, 
   3.877142111468959*^9}, 3.877142262530881*^9, {3.877142579571145*^9, 
   3.877142587412951*^9}, {3.877142680911479*^9, 3.877142681878044*^9}, {
   3.877143826204718*^9, 3.877143849257901*^9}, 3.877227919453987*^9, {
   3.877242638470957*^9, 3.8772426566258993`*^9}},
 CellLabel->"In[73]:=",ExpressionUUID->"ba09ec37-6b5d-4efb-aefc-a725093241fc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"calculate", "  ", "fN", " ", "and", " ", "gN"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"fNExp", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       FractionBox["Db", "a"], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"D3zwBc", "[", 
         FractionBox["a", "2"], "]"}], "-", 
        RowBox[{"D3zwBc", "[", 
         RowBox[{"-", 
          FractionBox["a", "2"]}], "]"}], "-", 
        RowBox[{"Integrate", "[", 
         RowBox[{
          RowBox[{"nonHomzw", "[", "T", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"T", ",", 
            RowBox[{"-", 
             FractionBox["a", "2"]}], ",", 
            FractionBox["a", "2"]}], "}"}]}], "]"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gNExp", " ", "=", " ", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{"12", " ", "Db"}], 
          SuperscriptBox["a", "3"]], 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"a", " ", 
             RowBox[{"D3zwBc", "[", 
              RowBox[{"a", "/", "2"}], "]"}]}], "2"], "+", " ", 
           FractionBox[
            RowBox[{"a", " ", 
             RowBox[{"D3zwBc", "[", 
              RowBox[{
               RowBox[{"-", "a"}], "/", "2"}], "]"}]}], "2"], "-", 
           RowBox[{"D2zwBc", "[", 
            FractionBox["a", "2"], "]"}], "+", 
           RowBox[{"D2zwBc", "[", 
            RowBox[{"-", 
             FractionBox["a", "2"]}], "]"}], " ", "-", " ", 
           RowBox[{"Integrate", "[", " ", 
            RowBox[{
             RowBox[{"T", " ", 
              RowBox[{"nonHomzw", "[", "T", "]"}]}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"T", ",", 
               RowBox[{"-", 
                FractionBox["a", "2"]}], ",", 
               FractionBox["a", "2"]}], "}"}]}], "]"}]}], ")"}]}], "/.", 
        RowBox[{"{", 
         RowBox[{"Db", "->", " ", "DbExp"}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"d\[Kappa]3", ",", " ", "d\[Epsilon]"}], "}"}], ",", 
       "Simplify"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8770905772393637`*^9, 3.877090590490191*^9}, {
   3.877090650464807*^9, 3.877090708082748*^9}, {3.877090811568214*^9, 
   3.877090837731523*^9}, {3.8770909495826807`*^9, 3.877090961256481*^9}, {
   3.8770911229469337`*^9, 3.8770911823483343`*^9}, {3.877093374635314*^9, 
   3.877093422225772*^9}, {3.8770934534626627`*^9, 3.877093538104849*^9}, {
   3.877093576893609*^9, 3.877093618839916*^9}, {3.8770938285363417`*^9, 
   3.8770938501343517`*^9}, {3.877141582045497*^9, 3.877141584234539*^9}, {
   3.877142118055395*^9, 3.877142119161016*^9}, {3.877146792770206*^9, 
   3.8771468045624943`*^9}, {3.877242464382371*^9, 3.8772424667206907`*^9}, {
   3.877243146996393*^9, 3.877243226294075*^9}, {3.877411444196315*^9, 
   3.877411446024851*^9}, {3.877525537949909*^9, 3.87752553999111*^9}, {
   3.877527072490962*^9, 3.8775271158333883`*^9}, 3.8775275849055853`*^9, {
   3.8776098677102823`*^9, 3.8776098733581*^9}},
 CellLabel->"In[74]:=",ExpressionUUID->"39e09131-9f13-44c7-a8b3-af42115f5508"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution for zw ", "Subsection",
 CellChangeTimes->{{3.877150489973415*^9, 3.87715053501407*^9}, {
   3.877151018461117*^9, 3.8771512155249987`*^9}, 3.877151293760796*^9, {
   3.877151420765995*^9, 3.877151437906726*^9}, 3.877242476103437*^9, 
   3.877243280579528*^9, {3.877243428363452*^9, 3.87724342876446*^9}, {
   3.877243484756441*^9, 3.877243520717288*^9}, {3.8772438259270487`*^9, 
   3.877243826250258*^9}, {3.87758483255179*^9, 3.877584854752213*^9}, {
   3.8775849011177263`*^9, 
   3.877584919456209*^9}},ExpressionUUID->"44aa933a-4706-44e0-827e-\
bc2a6da323db"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"differential", " ", "equation", " ", "for", " ", "zw"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"zw", "''''"}], "[", "T", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"nonHomzw", "[", "T", "]"}], " ", "+", " ", 
      FractionBox["fN", "Db"], " ", "+", " ", 
      FractionBox[
       RowBox[{"T", " ", "gN"}], "Db"]}]}], ";"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"D4zw", "[", "T_", "]"}], "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"nonHomzw", "[", "T", "]"}], "+", 
        FractionBox["fNExp", "Db"], "+", 
        FractionBox[
         RowBox[{"T", " ", "gNExp", " "}], "Db"]}], ")"}], "/.", 
      RowBox[{"{", 
       RowBox[{"Db", "->", " ", "DbExp"}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"T", ",", "d\[Kappa]3", ",", " ", "d\[Epsilon]"}], "}"}], ",", 
     "Simplify"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.877150489973415*^9, 3.87715053501407*^9}, {
   3.877151018461117*^9, 3.8771512155249987`*^9}, 3.877151293760796*^9, {
   3.877151420765995*^9, 3.877151437906726*^9}, 3.877242476103437*^9, 
   3.877243280579528*^9, {3.877243428363452*^9, 3.87724342876446*^9}, {
   3.877243484756441*^9, 3.877243520717288*^9}, {3.8772438259270487`*^9, 
   3.877243826250258*^9}, {3.87758483255179*^9, 3.8775848454377003`*^9}, 
   3.877584879151311*^9, {3.877584920776601*^9, 3.877584930672942*^9}},
 CellLabel->"In[76]:=",ExpressionUUID->"6c3582a3-9548-4d56-82ab-672a39a66feb"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
    "We", " ", "integrate", " ", "above", " ", "equation", " ", "to", " ", 
     "get", "  ", 
     RowBox[{
      RowBox[{"zw", "'''"}], "[", "T", "]"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", "0"], "T"], " ", 
      RowBox[{
       RowBox[{"zw", "''''"}], "[", "T", "]"}]}], " ", "+", " ", "cz3"}]}], 
   ",", " ", 
   RowBox[{
   "where", " ", "cz3", " ", "is", " ", "the", " ", "constant", " ", "of", 
    " ", "integration"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.877584951842044*^9, 3.877584987205542*^9}, {
  3.883995000401821*^9, 3.88399500159372*^9}},
 CellLabel->"In[77]:=",ExpressionUUID->"46c52b0a-bea6-4a39-8f22-fbd2e2170bcd"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"D3zw", "[", "T_", "]"}], "=", " ", 
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"D4zw", "[", "T", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"T", ",", "0", ",", "T"}], "}"}]}], "]"}], "+", " ", 
      "cz3"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cz3Exp", "=", 
     RowBox[{
      RowBox[{"SolveValues", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"D3zw", "[", 
          RowBox[{"a", "/", "2"}], "]"}], "==", " ", 
         RowBox[{"D3zwBc", "[", 
          RowBox[{"a", "/", "2"}], "]"}]}], ",", "cz3", ",", " ", 
        RowBox[{"Assumptions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["t", "2"]}], "!=", "0"}], "}"}]}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"check", " ", "if", " ", "calculated", " ", 
      RowBox[{
       RowBox[{"zw", "'''"}], "[", "T", "]"}], " ", "satisfies", " ", "the", 
      " ", "boundary", " ", "condition", " ", "at", " ", "T"}], "=", 
     RowBox[{
      RowBox[{"-", "a"}], "/", "2"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"If", "[", 
    RowBox[{"doSanityCheck", ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"CheckSanity", "[", 
       RowBox[{
        RowBox[{"Simplify", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"D3zw", "[", 
             RowBox[{
              RowBox[{"-", "a"}], "/", "2"}], "]"}], "-", 
            RowBox[{"D3zwBc", "[", 
             RowBox[{
              RowBox[{"-", "a"}], "/", "2"}], "]"}]}], ")"}], "/.", 
          RowBox[{"{", 
           RowBox[{"cz3", "->", " ", "cz3Exp"}], "}"}]}], "]"}], "==", "0"}], 
       "]"}], ";"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.877246860779704*^9, 3.877246999557982*^9}, {
   3.877247718311831*^9, 3.877247789423362*^9}, {3.877247918739064*^9, 
   3.877247929725952*^9}, {3.877248194074369*^9, 3.877248218674856*^9}, 
   3.87724836399271*^9, {3.877509457655007*^9, 3.877509458246647*^9}, {
   3.8775255470524282`*^9, 3.8775255520915813`*^9}, 3.877584906444816*^9, {
   3.877584949360553*^9, 3.877584964629012*^9}, {3.877595936364181*^9, 
   3.877595945904684*^9}, {3.877596814278349*^9, 3.877596823393322*^9}, {
   3.877609903576798*^9, 3.8776099553308153`*^9}},
 CellLabel->"In[78]:=",ExpressionUUID->"ae5b8f90-7207-48b9-bb1c-460d61b8c71d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"zw", "''"}], "[", "T", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", "0"], "T"], " ", 
       RowBox[{
        RowBox[{"zw", "'''"}], "[", "T", "]"}]}], " ", "+", " ", "cz2"}]}], 
    ",", " ", 
    RowBox[{
    "where", " ", "cz2", " ", "is", " ", "the", " ", "constant", " ", "of", 
     " ", "integration"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"D2zw", "[", "T_", "]"}], "=", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Integrate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"D3zw", "[", "T", "]"}], ")"}], "/.", 
           RowBox[{"{", 
            RowBox[{"cz3", "->", " ", "cz3Exp"}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"T", ",", "0", ",", "T"}], "}"}]}], "]"}], " ", "+", " ", 
        "cz2"}], ",", 
       RowBox[{"{", 
        RowBox[{"T", ",", "d\[Kappa]3", ",", " ", "d\[Epsilon]"}], "}"}], ",",
        "Simplify"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cz2Exp", "=", 
     RowBox[{
      RowBox[{"SolveValues", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"D2zw", "[", 
          RowBox[{"a", "/", "2"}], "]"}], "==", " ", 
         RowBox[{"D2zwBc", "[", 
          RowBox[{"a", "/", "2"}], "]"}]}], ",", "cz2", ",", " ", 
        RowBox[{"Assumptions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["t", "2"]}], "!=", "0"}], "}"}]}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"check", " ", "if", " ", "calculated", " ", 
      RowBox[{
       RowBox[{"zw", "''"}], "[", "T", "]"}], " ", "satisfies", " ", "the", 
      " ", "boundary", " ", "condition", " ", "at", " ", "T"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"-", "a"}], "/", "2"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"If", "[", 
    RowBox[{"doSanityCheck", ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"CheckSanity", "[", 
       RowBox[{
        RowBox[{"Simplify", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"D2zw", "[", 
             RowBox[{
              RowBox[{"-", "a"}], "/", "2"}], "]"}], "-", 
            RowBox[{"D2zwBc", "[", 
             RowBox[{
              RowBox[{"-", "a"}], "/", "2"}], "]"}]}], ")"}], "/.", 
          RowBox[{"{", 
           RowBox[{"cz2", "->", " ", "cz2Exp"}], "}"}]}], "]"}], "==", "0"}], 
       "]"}], ";"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.877246860779704*^9, 3.877246999557982*^9}, {
  3.877247718311831*^9, 3.877247802532011*^9}, {3.877247936736174*^9, 
  3.8772480449719467`*^9}, {3.877248094919794*^9, 3.877248188087563*^9}, {
  3.8772483722917233`*^9, 3.877248376807198*^9}, {3.8775094597393913`*^9, 
  3.877509460297386*^9}, {3.877525558931601*^9, 3.877525563101692*^9}, {
  3.877595949796796*^9, 3.8775959514422827`*^9}, {3.877596006628254*^9, 
  3.8775960074387827`*^9}, {3.877596831386572*^9, 3.877596838796356*^9}, {
  3.877609976932088*^9, 3.8776099918509417`*^9}, {3.8839950151196947`*^9, 
  3.88399502912745*^9}},
 CellLabel->"In[81]:=",ExpressionUUID->"84029c10-9bc6-4bbf-80ed-aefdeebc6bad"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"zw", "[", "T", "]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", "0"], "T"], "  ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", "0"], "m"], " ", 
       RowBox[{
        RowBox[{
         RowBox[{"zw", "''"}], "[", "n", "]"}], " ", "dn", " ", "dm"}]}]}], 
     " ", "+", " ", 
     RowBox[{"cz1", " ", "T"}], " ", "+", " ", "cz0"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"rawzw", "[", "T_", "]"}], "=", 
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"Integrate", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"D2zw", "[", "n", "]"}], "/.", 
            RowBox[{"{", 
             RowBox[{"cz2", "->", " ", "cz2Exp"}], "}"}]}], ")"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "m"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"m", ",", "0", ",", "T"}], "}"}]}], "]"}], "+", " ", 
      RowBox[{"cz1", " ", "T"}], " ", "+", " ", "cz0"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Use", "  ", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["\[Integral]", 
          RowBox[{"a", "/", "2"}]], 
         RowBox[{"a", "/", "2"}]], " ", 
        RowBox[{
         RowBox[{"zw", "[", "T", "]"}], " ", "dT"}]}]}], " ", "=", " ", "0"}],
      ",", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", 
         RowBox[{"a", "/", "2"}]], 
        RowBox[{"a", "/", "2"}]], " ", 
       RowBox[{
        RowBox[{"Tzw", "[", "T", "]"}], " ", "dT"}]}], " ", "=", " ", 
      RowBox[{
      "0", "  ", "to", " ", "find", " ", "cz1", " ", "and", " ", "cz0"}]}]}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"intzwaBy2MinusaBy2", " ", "=", " ", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"rawzw", "[", "T", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"T", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}], ",", 
         RowBox[{"a", "/", "2"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"intTzwaBy2MinusaBy2", " ", "=", " ", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"T", " ", 
        RowBox[{"rawzw", "[", "T", "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"T", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}], ",", 
         RowBox[{"a", "/", "2"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"cz0Exp", ",", " ", "cz1Exp"}], "}"}], "}"}], "=", 
     RowBox[{"SolveValues", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"intzwaBy2MinusaBy2", "==", "0"}], ",", 
         RowBox[{"intTzwaBy2MinusaBy2", "==", "0"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"cz0", ",", "cz1"}], "}"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["t", "2"]}], "!=", "0"}], ",", "  ", 
          RowBox[{"t", "!=", "0"}]}], " ", "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"solved", " ", "zw"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zwSol", "[", "T_", "]"}], "=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"rawzw", "[", "T", "]"}], " ", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cz0", "->", "cz0Exp"}], ",", 
         RowBox[{"cz1", "->", " ", "cz1Exp"}]}], "}"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"d\[Kappa]3", ",", " ", "d\[Epsilon]", ",", "T"}], "}"}], ",", 
      "Simplify"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.877248296141993*^9, 3.8772483563475437`*^9}, {
  3.877248402234695*^9, 3.8772484714737587`*^9}, {3.877248512160479*^9, 
  3.877248719160598*^9}, {3.877248884544235*^9, 3.877248966941904*^9}, {
  3.877249039517321*^9, 3.877249068704102*^9}, {3.877525569217778*^9, 
  3.877525573921636*^9}},
 CellLabel->"In[84]:=",ExpressionUUID->"a66fcfd8-baee-4be7-a22c-895028c18445"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"sanity", " ", "checks", " ", "for", " ", "zw", " ", "solution"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"If", "[", 
   RowBox[{"doSanityCheck", ",", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"satisfies", " ", "differential", " ", 
      RowBox[{"equation", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"zw", "''''"}], "[", "T", "]"}], "-", 
           RowBox[{"D4zw", "[", "T", "]"}]}], ")"}], "/.", 
         RowBox[{"{", 
          RowBox[{"zw", "->", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"zwSol", "[", "#", "]"}], "&"}], ")"}]}], "}"}]}], "]"}],
        "==", "0"}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"check", "  ", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Integral]", 
           RowBox[{
            RowBox[{"-", "a"}], "/", "2"}]], 
          RowBox[{"a", "/", "2"}]], " ", 
         RowBox[{
          RowBox[{"zw", "[", "T", "]"}], " ", "dT"}]}]}], " ", "=", " ", 
       RowBox[{"0", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{"Integrate", "[", 
         RowBox[{
          RowBox[{"zwSol", "[", "T", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"T", ",", 
            RowBox[{
             RowBox[{"-", "a"}], "/", "2"}], ",", 
            RowBox[{"a", "/", "2"}]}], "}"}]}], "]"}], "]"}], "==", "0"}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"check", "  ", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Integral]", 
           RowBox[{
            RowBox[{"-", "a"}], "/", "2"}]], 
          RowBox[{"a", "/", "2"}]], " ", 
         RowBox[{"T", " ", 
          RowBox[{"zw", "[", "T", "]"}], " ", "dT"}]}]}], " ", "=", " ", 
       RowBox[{"0", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{"Integrate", "[", 
         RowBox[{
          RowBox[{"T", " ", 
           RowBox[{"zwSol", "[", "T", "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"T", ",", 
            RowBox[{
             RowBox[{"-", "a"}], "/", "2"}], ",", 
            RowBox[{"a", "/", "2"}]}], "}"}]}], "]"}], "]"}], "==", "0"}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"satisfies", " ", "boundary", " ", 
       RowBox[{"conditions", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"zwSol", "''"}], "[", 
          RowBox[{"a", "/", "2"}], "]"}], "-", 
         RowBox[{"D2zwBc", "[", 
          RowBox[{"a", "/", "2"}], "]"}]}], " ", "]"}], "==", "0"}], "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"zwSol", "''"}], "[", 
          RowBox[{
           RowBox[{"-", "a"}], "/", "2"}], "]"}], "-", 
         RowBox[{"D2zwBc", "[", 
          RowBox[{
           RowBox[{"-", "a"}], "/", "2"}], "]"}]}], "]"}], " ", "==", "0"}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"zwSol", "'''"}], "[", 
          RowBox[{"a", "/", "2"}], "]"}], "-", 
         RowBox[{"D3zwBc", "[", " ", 
          RowBox[{"a", "/", "2"}], "]"}]}], "]"}], "==", "0"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"zwSol", "'''"}], "[", 
          RowBox[{
           RowBox[{"-", "a"}], "/", "2"}], "]"}], "-", 
         RowBox[{"D3zwBc", "[", " ", 
          RowBox[{
           RowBox[{"-", "a"}], "/", "2"}], "]"}]}], "]"}], "==", "0"}], "]"}],
      ";"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.877150489973415*^9, 3.87715053501407*^9}, {
   3.877151018461117*^9, 3.8771512155249987`*^9}, 3.877151293760796*^9, {
   3.877246854366061*^9, 3.877246854657576*^9}, {3.877249165415873*^9, 
   3.877249238066722*^9}, {3.877249280060753*^9, 3.877249310128995*^9}, {
   3.877249341121801*^9, 3.877249378967064*^9}, {3.877249779902264*^9, 
   3.8772498866566553`*^9}, {3.877509461296524*^9, 3.877509462615497*^9}, {
   3.877595957109514*^9, 3.8775959633109503`*^9}, {3.877596008475852*^9, 
   3.877596012562367*^9}, {3.877596851217115*^9, 3.87759686098411*^9}, {
   3.8775969059565353`*^9, 3.877596923528082*^9}, 3.877597030813056*^9, {
   3.877597064316922*^9, 3.877597072354453*^9}, {3.877610021314146*^9, 
   3.8776101135088167`*^9}},
 CellLabel->"In[89]:=",ExpressionUUID->"54ef0ba8-76f6-471d-afa1-78a774108640"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution for zu and zv", "Subsection",
 CellChangeTimes->{{3.877151233190744*^9, 3.8771513870733852`*^9}, {
   3.8771519684245653`*^9, 3.877151977063991*^9}, {3.877243665704624*^9, 
   3.877243668499507*^9}, {3.8772494370504637`*^9, 3.877249437558106*^9}, {
   3.877250178939691*^9, 3.877250391341033*^9}, {3.877250470959556*^9, 
   3.877250527192195*^9}, {3.87725076652997*^9, 3.877250784911117*^9}, {
   3.877251091940624*^9, 3.877251100662589*^9}, 3.8772514504067297`*^9, {
   3.8775255806543083`*^9, 3.877525596753078*^9}, {3.8775850709056597`*^9, 
   3.877585088766815*^9}},ExpressionUUID->"b62bac85-2529-402e-bb5b-\
15b1d3f1d1a9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "differential", " ", "equations", " ", "to", " ", "solve", " ", "for", 
      " ", "zu", " ", "and", " ", "zv", " ", 
      RowBox[{"are", ":", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"zu", "'"}], "[", "T", "]"}]}]}], " ", "=", " ", "zuDT"}], 
    ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"zv", "'"}], "[", "T", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
      "zvDT", "\[IndentingNewLine]", "we", " ", "integrate", " ", "the", " ", 
       "above", " ", "two", " ", "expressions", " ", "and", " ", "use", " ", 
       "the", " ", "integral", " ", "constraints", " ", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["\[Integral]", 
          RowBox[{
           RowBox[{"-", "a"}], "/", "2"}]], 
         RowBox[{"a", "/", "2"}]], " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"zv", ",", " ", "zu"}], ")"}], " ", "dT"}]}]}], " ", "=", 
      " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"0", ",", "0"}], ")"}], "  ", "to", " ", "find", " ", "the", 
       " ", "constants", " ", "of", " ", "integration"}]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"rawzu", "[", "T_", "]"}], "=", " ", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Integrate", "[", 
         RowBox[{
          RowBox[{"zuDT", "/.", 
           RowBox[{"{", 
            RowBox[{"zw", "->", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"zwSol", "[", "#", "]"}], "&"}], ")"}]}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"T", ",", "0", ",", "T"}], "}"}]}], "]"}], " ", "+", " ", 
        "cu1"}], ",", "T", ",", "Simplify"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cu1Exp", "=", 
     RowBox[{
      RowBox[{"SolveValues", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Integrate", "[", 
          RowBox[{
           RowBox[{"rawzu", "[", "T", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"T", ",", 
             RowBox[{
              RowBox[{"-", "a"}], "/", "2"}], ",", 
             RowBox[{"a", "/", "2"}]}], "}"}]}], "]"}], "==", "0"}], ",", 
        "cu1", ",", " ", 
        RowBox[{"Assumptions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["t", "2"]}], "!=", "0"}], "}"}]}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"zuSol", "[", "T_", "]"}], "=", " ", 
     RowBox[{"Collect", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"rawzu", "[", "T", "]"}], " ", "/.", " ", 
         RowBox[{"{", 
          RowBox[{"cu1", "->", " ", "cu1Exp"}], "}"}]}], "/.", 
        RowBox[{"{", 
         RowBox[{"Km", "->", " ", "KmExp"}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"d\[Kappa]3", ",", " ", "d\[Epsilon]", ",", "T"}], "}"}], ",",
        "Simplify"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"rawzv", "[", "T_", "]"}], "=", " ", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Integrate", "[", 
         RowBox[{
          RowBox[{"zvDT", "/.", 
           RowBox[{"{", 
            RowBox[{"zw", "->", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"zwSol", "[", "#", "]"}], "&"}], ")"}]}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"T", ",", "0", ",", "T"}], "}"}]}], "]"}], " ", "+", " ", 
        "cv1"}], ",", "T", ",", "Simplify"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cv1Exp", "=", 
     RowBox[{
      RowBox[{"SolveValues", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Integrate", "[", 
          RowBox[{
           RowBox[{"rawzv", "[", "T", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"T", ",", 
             RowBox[{
              RowBox[{"-", "a"}], "/", "2"}], ",", 
             RowBox[{"a", "/", "2"}]}], "}"}]}], "]"}], "==", "0"}], ",", 
        "cv1", ",", " ", 
        RowBox[{"Assumptions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["t", "2"]}], "!=", "0"}], "}"}]}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"zvSol", "[", "T_", "]"}], "=", " ", 
     RowBox[{"Collect", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"rawzv", "[", "T", "]"}], " ", "/.", " ", 
         RowBox[{"{", 
          RowBox[{"cv1", "->", " ", "cv1Exp"}], "}"}]}], "/.", 
        RowBox[{"{", 
         RowBox[{"Km", "->", " ", "KmExp"}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"d\[Kappa]3", ",", " ", "d\[Epsilon]", ",", "T"}], "}"}], ",",
        "Simplify"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.877151233190744*^9, 3.8771513870733852`*^9}, {
   3.8771519684245653`*^9, 3.877151977063991*^9}, {3.877243665704624*^9, 
   3.877243668499507*^9}, {3.8772494370504637`*^9, 3.877249437558106*^9}, {
   3.877250178939691*^9, 3.877250391341033*^9}, {3.877250470959556*^9, 
   3.877250527192195*^9}, {3.87725076652997*^9, 3.877250784911117*^9}, {
   3.877251091940624*^9, 3.877251100662589*^9}, 3.8772514504067297`*^9, {
   3.8775255806543083`*^9, 3.877525596753078*^9}, 3.8775850709056597`*^9, {
   3.883995070256777*^9, 3.883995070642242*^9}},
 CellLabel->"In[90]:=",ExpressionUUID->"78494090-3cf6-41c2-9295-4ff9b5f78a1f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"sanity", " ", "checks"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"If", "[", 
   RowBox[{"doSanityCheck", ",", "\[IndentingNewLine]", " ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "solved", " ", "zu", " ", "and", " ", "zv", " ", "satisfy", " ", 
      "differential", " ", 
      RowBox[{"equations", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Simplify", "[", 
            RowBox[{"zvDT", "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"zv", "->", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"zvSol", "[", "#", "]"}], "&"}], ")"}]}], ",", " ", 
               
               RowBox[{"zu", "->", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"zuSol", "[", "#", "]"}], "&"}], ")"}]}], ",", 
               RowBox[{"zw", "->", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"zwSol", "[", "#", "]"}], "&"}], ")"}]}]}], " ", 
              "}"}]}], "]"}], "-", 
           RowBox[{
            RowBox[{"zvSol", "'"}], "[", "T", "]"}]}], ")"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Km", "->", " ", "KmExp"}], ",", 
           RowBox[{"Db", "->", " ", "DbExp"}]}], "}"}]}], "]"}], "==", "0"}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Simplify", "[", 
            RowBox[{"zuDT", "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"zu", "->", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"zuSol", "[", "#", "]"}], "&"}], ")"}]}], ",", " ", 
               
               RowBox[{"zu", "->", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"zuSol", "[", "#", "]"}], "&"}], ")"}]}], ",", 
               RowBox[{"zw", "->", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"zwSol", "[", "#", "]"}], "&"}], ")"}]}]}], "  ", 
              "}"}]}], "]"}], "-", 
           RowBox[{
            RowBox[{"zuSol", "'"}], "[", "T", "]"}]}], ")"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Km", "->", " ", "KmExp"}], ",", 
           RowBox[{"Db", "->", " ", "DbExp"}]}], "}"}]}], "]"}], "==", "0"}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"check", "  ", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Integral]", 
           RowBox[{
            RowBox[{"-", "a"}], "/", "2"}]], 
          RowBox[{"a", "/", "2"}]], " ", 
         RowBox[{
          RowBox[{"zu", "[", "T", "]"}], " ", "dT"}]}]}], " ", "=", " ", 
       RowBox[{"0", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{"Integrate", "[", 
         RowBox[{
          RowBox[{"zuSol", "[", "T", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"T", ",", 
            RowBox[{
             RowBox[{"-", "a"}], "/", "2"}], ",", 
            RowBox[{"a", "/", "2"}]}], "}"}]}], "]"}], "]"}], "==", "0"}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"check", "  ", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Integral]", 
           RowBox[{
            RowBox[{"-", "a"}], "/", "2"}]], 
          RowBox[{"a", "/", "2"}]], " ", 
         RowBox[{
          RowBox[{"zv", "[", "T", "]"}], " ", "dT"}]}]}], " ", "=", " ", 
       RowBox[{"0", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{"Integrate", "[", 
         RowBox[{
          RowBox[{"zvSol", "[", "T", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"T", ",", 
            RowBox[{
             RowBox[{"-", "a"}], "/", "2"}], ",", 
            RowBox[{"a", "/", "2"}]}], "}"}]}], "]"}], "]"}], "==", "0"}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
        "sanity", " ", "check", " ", "with", " ", "the", " ", "first", " ", 
         "variation", " ", "of", " ", "potential", " ", "taking", " ", 
         "\[Delta]zw"}], " ", "=", " ", "Yw"}], ",", " ", 
       RowBox[{"\[Delta]zu", " ", "=", " ", "Yu"}], ",", " ", 
       RowBox[{"\[Delta]zv", " ", "=", " ", "Yv"}]}], "  ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{"Integrate", "[", 
         RowBox[{
          RowBox[{"Collect", "[", 
           RowBox[{
            RowBox[{"Simplify", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"eqToSolveForZ", "/.", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"zw", "->", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"zwSol", "[", "#", "]"}], "&"}], ")"}]}], ",", 
                   RowBox[{"zu", "->", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"zuSol", "[", "#", "]"}], "&"}], ")"}]}], ",", 
                   RowBox[{"zv", "->", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"zvSol", "[", "#", "]"}], "&"}], ")"}]}]}], 
                  "}"}]}], "/.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Db", "->", " ", "DbExp"}], ",", 
                  RowBox[{"Km", "->", " ", "KmExp"}]}], "}"}]}], "/.", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"fN", "->", " ", "fNExp"}], ",", " ", 
                 RowBox[{"gN", "->", " ", "gNExp"}]}], "}"}]}], "/.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"\[Delta]zw", "->", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"zwSol", "[", "#", "]"}], "&"}], ")"}]}], ",", 
                RowBox[{"\[Delta]zu", "->", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"zuSol", "[", "#", "]"}], "&"}], ")"}]}], ",", 
                RowBox[{"\[Delta]zv", "->", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"zvSol", "[", "#", "]"}], "&"}], ")"}]}]}], 
               "}"}]}], "]"}], ",", "T"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"T", ",", 
            RowBox[{
             RowBox[{"-", "a"}], "/", "2"}], ",", 
            RowBox[{"a", "/", "2"}]}], "}"}]}], "]"}], "]"}], "==", "0"}], 
      "]"}], ";"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.877151233190744*^9, 3.8771513870733852`*^9}, {
   3.8771519684245653`*^9, 3.877151977063991*^9}, {3.877243665704624*^9, 
   3.877243668499507*^9}, {3.8772494370504637`*^9, 3.877249437558106*^9}, {
   3.877250178939691*^9, 3.877250391341033*^9}, {3.877250470959556*^9, 
   3.877250527192195*^9}, {3.87725076652997*^9, 3.877250784911117*^9}, {
   3.877251091940624*^9, 3.877251100662589*^9}, {3.8772514504067297`*^9, 
   3.8772515607001867`*^9}, {3.877252037842298*^9, 3.877252081075424*^9}, {
   3.8772524408517103`*^9, 3.877252452159686*^9}, 3.87725250175589*^9, {
   3.877252783779668*^9, 3.877252784213183*^9}, {3.877509463902713*^9, 
   3.877509466163517*^9}, {3.8775275009970083`*^9, 3.8775275507124147`*^9}, {
   3.877534391860386*^9, 3.877534404542121*^9}, {3.877595969741909*^9, 
   3.877595981375039*^9}, {3.877596014600985*^9, 3.877596019388133*^9}, {
   3.877596950771454*^9, 3.877596984146822*^9}, {3.8776101957171173`*^9, 
   3.87761025455469*^9}},
 CellLabel->"In[96]:=",ExpressionUUID->"359acb86-63d8-40f0-bd9f-ec0b04696b5a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Strain energy", "Section",
 CellChangeTimes->{{3.877585120208435*^9, 3.87758515373746*^9}, {
  3.8775852858754168`*^9, 
  3.877585302158353*^9}},ExpressionUUID->"256cf7c2-6169-43cf-b481-\
eb534d4fa0e8"],

Cell[CellGroupData[{

Cell[TextData[{
 "Second order strain energy from ",
 Cell[BoxData[
  RowBox[{"h\[Dagger]", ".", " ", 
   SuperscriptBox["B", 
    RowBox[{"(", "1", ")"}]], ".", "z"}]],
  CellChangeTimes->{{3.876999716308838*^9, 3.876999719778428*^9}, {
    3.876999791262299*^9, 3.876999823148569*^9}, {3.876999966091852*^9, 
    3.876999988263636*^9}, {3.877000433521043*^9, 3.877000488885623*^9}, 
    3.877000838898486*^9, {3.877000890497925*^9, 3.877000919651627*^9}, {
    3.877002339293315*^9, 3.8770023412681837`*^9}, {3.8770024505128307`*^9, 
    3.877002455383127*^9}, {3.877002517741177*^9, 3.877002546092609*^9}, {
    3.877004056312842*^9, 3.877004115625627*^9}, {3.877004363315894*^9, 
    3.877004367884698*^9}, {3.877139755814892*^9, 3.877139757053953*^9}, {
    3.877142533228709*^9, 3.877142535111288*^9}, 3.877142665138546*^9, {
    3.877143419382751*^9, 3.87714343321734*^9}, {3.877143588609045*^9, 
    3.8771435899496098`*^9}, {3.877151616170932*^9, 3.877151616698037*^9}, {
    3.877324735567295*^9, 3.877324747264461*^9}, 3.877407822630435*^9, {
    3.8775223267905903`*^9, 3.877522361274061*^9}, 3.877524398091016*^9, {
    3.8775245021792803`*^9, 3.8775245198434763`*^9}, {3.8775246700027657`*^9, 
    3.877524682418738*^9}, {3.877532353741651*^9, 3.877532476873117*^9}, 
    3.877532509859695*^9, 3.8775799869985857`*^9},ExpressionUUID->
  "e8910f63-fda2-4ddc-a037-b0064fc91e63"],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", "2"], 
   RowBox[{"z", ".", " ", 
    SuperscriptBox["B", 
     RowBox[{"(", "2", ")"}]], ".", "z"}]}]],
  CellChangeTimes->{{3.8770006992073383`*^9, 3.877000707115068*^9}, {
    3.87700074290419*^9, 3.87700076226318*^9}, 3.877000798426526*^9, {
    3.8770008308440027`*^9, 3.8770008885164413`*^9}, {3.8770043294986*^9, 
    3.8770043505298033`*^9}, {3.877004567821703*^9, 3.8770045769380693`*^9}, {
    3.877004616275828*^9, 3.87700464266265*^9}, 3.877004673251775*^9, {
    3.877004717221848*^9, 3.877004725624597*^9}, {3.8770048353123837`*^9, 
    3.877004896227014*^9}, {3.877078603904949*^9, 3.877078623694674*^9}, {
    3.8771397590443087`*^9, 3.8771397602536383`*^9}, {3.877324711851568*^9, 
    3.877324727080205*^9}, {3.8775218354877987`*^9, 3.877521909865629*^9}, {
    3.877522379852137*^9, 3.8775224281916103`*^9}, {3.877522459645728*^9, 
    3.877522476259976*^9}, {3.877524690741798*^9, 3.877524706409527*^9}, {
    3.877532512959372*^9, 3.877532545849325*^9}, {3.8775328282943563`*^9, 
    3.877532829520975*^9}, {3.877532900227874*^9, 3.877532942604125*^9}, {
    3.877533113666583*^9, 3.8775331223748913`*^9}, {3.877533212250414*^9, 
    3.8775332134082193`*^9}},ExpressionUUID->
  "8d6c1c97-3baa-420d-bedf-a34c64687f24"]
}], "Subsection",
 CellChangeTimes->{{3.877585120208435*^9, 3.87758515373746*^9}, {
  3.8775852858754168`*^9, 3.87758528713083*^9}, {3.8775858363669643`*^9, 
  3.877585837294037*^9}},ExpressionUUID->"7439b397-073e-4632-adc8-\
45cdb644750a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"enrZTerms", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
         "t1dhB1z", "+", "t2dhB1z", "+", "t3dhB1z", "+", "t1zB2z", "+", 
          "t2zB2z"}], ")"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"zw", "->", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"zwSol", "[", "#", "]"}], "&"}], ")"}]}], ",", 
          RowBox[{"zu", "->", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"zuSol", "[", "#", "]"}], "&"}], ")"}]}], ",", 
          RowBox[{"zv", "->", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"zvSol", "[", "#", "]"}], "&"}], ")"}]}]}], "}"}]}], 
       ")"}], "\[IndentingNewLine]", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Db", "->", " ", "DbExp"}], ",", 
        RowBox[{"Km", "->", " ", "KmExp"}]}], "}"}]}], "\[IndentingNewLine]", 
     ",", 
     RowBox[{"{", 
      RowBox[{"T", ",", "d\[Kappa]3", ",", "d\[Epsilon]", ",", 
       RowBox[{"1", "-", 
        SuperscriptBox["\[Nu]", "2"]}], ",", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[Nu]", "2"]}], ",", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Nu]"}], ",", 
       RowBox[{"1", "+", "\[Nu]"}]}], "}"}], ",", "FullSimplify"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8772516069220333`*^9, 3.8772516609748173`*^9}, {
   3.87725170171436*^9, 3.8772517042424097`*^9}, {3.8772517484931993`*^9, 
   3.87725175442248*^9}, {3.8775256317688627`*^9, 3.877525642204968*^9}, {
   3.8775260527865763`*^9, 3.877526053339562*^9}, {3.87752755985883*^9, 
   3.8775275610838003`*^9}, 3.877585114943076*^9, {3.877585160737204*^9, 
   3.877585162159609*^9}, {3.879399363017563*^9, 3.879399373356024*^9}},
 CellLabel->"In[97]:=",ExpressionUUID->"db2e654c-4ca5-4652-a524-6ebe8589e500"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Integrate", " ", "along", " ", "T", " ", "from"}], " ", "-", 
    RowBox[{
     RowBox[{"a", "/", "2"}], " ", "to", " ", 
     RowBox[{"a", "/", "2"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"enrZ", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Integrate", "[", 
      RowBox[{"enrZTerms", ",", 
       RowBox[{"{", 
        RowBox[{"T", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}], ",", 
         RowBox[{"a", "/", "2"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "d\[Kappa]3", ",", "d\[Epsilon]", ",", "\[Kappa]3", ",", "\[Epsilon]", 
       ",", "a", ",", "c"}], "}"}], ",", "FullSimplify"}], "]"}]}]}]], "Input",\

 CellChangeTimes->{{3.877251726662792*^9, 3.87725173926589*^9}, {
  3.877251895278789*^9, 3.877251901600935*^9}, {3.877610293764292*^9, 
  3.877610306795602*^9}},
 CellLabel->"In[98]:=",ExpressionUUID->"e654cef1-ae81-4267-bab7-ce15a7866e77"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Strain energy from",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"h\[Dagger]", ".", 
      SuperscriptBox["B", 
       RowBox[{"(", "0", ")"}]], ".", "h\[Dagger]"}]}], ";"}]}]],
  ExpressionUUID->"2d0a8761-a97f-4cc5-8890-04d790b2f1a7"]
}], "Subsection",
 CellChangeTimes->{{3.877252215148398*^9, 3.877252236475752*^9}, {
   3.877252915350473*^9, 3.877252965971201*^9}, {3.87725300014675*^9, 
   3.8772530861849823`*^9}, {3.8772531171728086`*^9, 3.877253162976259*^9}, {
   3.8772532649452353`*^9, 3.8772532785119762`*^9}, {3.8772534572877197`*^9, 
   3.877253677211957*^9}, {3.87725380987669*^9, 3.877253848293049*^9}, {
   3.87725393222715*^9, 3.87725394408838*^9}, {3.877253986434499*^9, 
   3.877254001771378*^9}, {3.8772555191108227`*^9, 3.877255537684785*^9}, {
   3.877318359699605*^9, 3.8773183975991993`*^9}, {3.877324533192773*^9, 
   3.877324548730236*^9}, 3.877525447869939*^9, {3.877525649717209*^9, 
   3.877525664119175*^9}, {3.877527328792077*^9, 3.877527338596192*^9}, {
   3.877527445597076*^9, 3.877527455424843*^9}, {3.877585183866815*^9, 
   3.877585249251298*^9}},ExpressionUUID->"803fd1ba-efe9-4b57-abe9-\
b89c9d55f473"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"using", " ", "the", " ", "simplification", " ", "that", " ", 
      RowBox[{"dYw", "[", "T", "]"}]}], " ", "=", " ", "0"}], ",", " ", 
    RowBox[{
     RowBox[{"we", " ", "get", " ", "first"}], "-", 
     RowBox[{"line", " ", "terms", " ", "in", " ", 
      RowBox[{"Eq", ".", " ", "5.12"}]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"t1dhB0dh", " ", "=", " ", 
    RowBox[{
     FractionBox["Km", "2"], 
     SuperscriptBox[
      RowBox[{"dYv", "[", "T", "]"}], "2"]}]}], " ", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"second", " ", "line", " ", "terms", " ", "in", " ", 
     RowBox[{"Eq", ".", " ", "5.12"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"t2dhB0dh", " ", "=", 
    RowBox[{
     RowBox[{
      FractionBox["Db", "2"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"T", " ", "d\[Kappa]3"}], ")"}], "2"]}], "+", " ", 
     RowBox[{
      FractionBox["Km", "4"], 
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Nu]"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"dYu", "[", "T", "]"}], "2"]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "combine", " ", "first", " ", "and", " ", "second", " ", "line", " ", 
     "terms", " ", "and", " ", "integrate", " ", "along", " ", "width"}], " ",
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{"quadTermsdh", " ", "=", " ", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"Simplify", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"t1dhB0dh", " ", "+", " ", "t2dhB0dh"}], ")"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Km", "->", " ", "KmExp"}], ",", " ", 
            RowBox[{"Db", "->", " ", "DbExp"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"T", ",", 
          RowBox[{
           RowBox[{"-", "a"}], "/", "2"}], ",", 
          RowBox[{"a", "/", "2"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "d\[Kappa]3", ",", "d\[Epsilon]", ",", "\[Kappa]3", ",", "\[Epsilon]", 
        ",", "a", ",", "c"}], "}"}], ",", "FullSimplify"}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.877252215148398*^9, 3.877252236475752*^9}, {
   3.877252915350473*^9, 3.877252965971201*^9}, {3.87725300014675*^9, 
   3.8772530861849823`*^9}, {3.8772531171728086`*^9, 3.877253162976259*^9}, {
   3.8772532649452353`*^9, 3.8772532785119762`*^9}, {3.8772534572877197`*^9, 
   3.877253677211957*^9}, {3.87725380987669*^9, 3.877253848293049*^9}, {
   3.87725393222715*^9, 3.87725394408838*^9}, {3.877253986434499*^9, 
   3.877254001771378*^9}, {3.8772555191108227`*^9, 3.877255537684785*^9}, {
   3.877318359699605*^9, 3.8773183975991993`*^9}, {3.877324533192773*^9, 
   3.877324548730236*^9}, 3.877525447869939*^9, {3.877525649717209*^9, 
   3.877525664119175*^9}, {3.877527328792077*^9, 3.877527338596192*^9}, {
   3.877527445597076*^9, 3.877527455424843*^9}, {3.877585183866815*^9, 
   3.877585205152693*^9}, {3.877610333827875*^9, 3.8776103350822983`*^9}, {
   3.8776104397987633`*^9, 3.87761047992417*^9}, {3.8786438718758097`*^9, 
   3.878643872076762*^9}, {3.8786439361887302`*^9, 3.878643951569716*^9}, {
   3.878644035435439*^9, 3.87864403899957*^9}, {3.878644087950465*^9, 
   3.878644092497676*^9}, {3.883995119652454*^9, 3.883995120334597*^9}},
 CellLabel->"In[99]:=",ExpressionUUID->"6a5a0cea-a1b1-4cdb-b3e9-715bff6ff180"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Summing up the strain energies: ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"h\[Dagger]", ".", "B", ".", "h\[Dagger]"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{"h\[Dagger]", ".", 
       SuperscriptBox["B", 
        RowBox[{"(", "1", ")"}]], ".", "z"}], " ", "+", " ", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"z", " ", ".", 
        SuperscriptBox["B", 
         RowBox[{"(", "2", ")"}]], ".", "z"}]}]}], ")"}], "+", " ", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"h\[Dagger]", ".", 
      SuperscriptBox["B", 
       RowBox[{"(", "0", ")"}]], ".", "h\[Dagger]"}]}]}]}]],
  CellChangeTimes->{{3.877253694173807*^9, 3.877253745267943*^9}, {
    3.8772541214988832`*^9, 3.87725430886718*^9}, {3.877254405356011*^9, 
    3.8772544140428267`*^9}, {3.8772548678236723`*^9, 3.877254870565884*^9}, {
    3.8773187855522747`*^9, 3.877318974028625*^9}, 3.877509467055748*^9, {
    3.8775254601774073`*^9, 3.877525466146261*^9}, {3.8775256114247217`*^9, 
    3.877525618547274*^9}, {3.8775256712755013`*^9, 3.877525686344081*^9}, {
    3.877527193142293*^9, 3.877527262429788*^9}, 3.877585276035142*^9},
  ExpressionUUID->"b7303d08-3448-476a-a14a-d6278f46357f"]
}], "Subsection",
 CellChangeTimes->{{3.877253694173807*^9, 3.877253745267943*^9}, {
   3.8772541214988832`*^9, 3.87725430886718*^9}, {3.877254405356011*^9, 
   3.8772544140428267`*^9}, {3.8772548678236723`*^9, 3.877254870565884*^9}, {
   3.8773187855522747`*^9, 3.877318974028625*^9}, 3.877509467055748*^9, {
   3.8775254601774073`*^9, 3.877525466146261*^9}, {3.8775256114247217`*^9, 
   3.877525618547274*^9}, {3.8775256712755013`*^9, 3.877525686344081*^9}, {
   3.877527193142293*^9, 3.877527262429788*^9}, 3.877585276035142*^9, {
   3.877585523593192*^9, 3.877585534227646*^9}, {3.877585620282754*^9, 
   3.877585647953644*^9}, {3.877585814458819*^9, 3.877585823542014*^9}, {
   3.877585864068252*^9, 
   3.877585868870323*^9}},ExpressionUUID->"706099d1-e28d-44a0-8382-\
4fc0cbcc39d7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"calculate", " ", "energy", " ", "terms"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"enrTerms", " ", "=", " ", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"enrZ", " ", "+", " ", "quadTermsdh"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "d\[Kappa]3", ",", "d\[Epsilon]", ",", "\[Kappa]3", ",", "\[Epsilon]",
          ",", "a", ",", "c"}], "}"}], ",", "FullSimplify"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "energy", " ", "terms", " ", "given", " ", "in", " ", "the", " ", "paper",
      " ", "in", " ", "Appendix", " ", "B"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Eta]1", "[", 
      RowBox[{"\[Kappa]3b_", ",", " ", "cb_", ",", " ", "\[Nu]_"}], "]"}], 
     "=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Nu]"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"27", "+", 
          RowBox[{"71", " ", "\[Nu]"}]}], ")"}]}], "+", 
       FractionBox[
        RowBox[{"23", " ", 
         SuperscriptBox["cb", "2"]}], "144"], "+", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "360"]}], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           SuperscriptBox["\[Kappa]3b", "4"], "2640"], "+", 
          RowBox[{
           SuperscriptBox["\[Kappa]3b", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"38", "+", 
             RowBox[{"75", " ", "\[Nu]"}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
    ";"}], "\n", 
   RowBox[{"enrTermsPaper", " ", "=", " ", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"Y", " ", 
           SuperscriptBox["a", "5"], "  ", "t", " ", "\[Nu]"}], "180"]}], " ",
         "\[Kappa]3", " ", "d\[Epsilon]", " ", "d\[Kappa]3"}], "+", 
       RowBox[{
        FractionBox[
         RowBox[{"Y", " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["t", "3"]}], 
         RowBox[{"5040", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox["\[Nu]", "2"]}], ")"}]}]], 
        SuperscriptBox["d\[Kappa]3", "2"], " ", 
        RowBox[{"\[Eta]1", "[", 
         RowBox[{
          FractionBox["\[Kappa]3", "ksExp"], ",", " ", 
          FractionBox["c", "ksExp"], ",", "\[Nu]"}], "]"}]}]}], ")"}]}]}], 
   "\n", "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"Are", " ", "they", " ", 
     RowBox[{"equal", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"If", "[", 
    RowBox[{"doSanityCheck", ",", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"FullSimplify", "[", 
        RowBox[{"enrTermsPaper", "-", "enrTerms"}], "]"}], "==", "0"}], 
      "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.877253694173807*^9, 3.877253745267943*^9}, {
   3.8772541214988832`*^9, 3.87725430886718*^9}, {3.877254405356011*^9, 
   3.8772544140428267`*^9}, {3.8772548678236723`*^9, 3.877254870565884*^9}, {
   3.8773187855522747`*^9, 3.877318974028625*^9}, 3.877509467055748*^9, {
   3.8775254601774073`*^9, 3.877525466146261*^9}, {3.8775256114247217`*^9, 
   3.877525618547274*^9}, {3.8775256712755013`*^9, 3.877525686344081*^9}, {
   3.877527193142293*^9, 3.877527262429788*^9}, 3.877585276035142*^9, {
   3.877585644896393*^9, 3.8775856555902863`*^9}, 3.8775959882573147`*^9, 
   3.877596021135302*^9, {3.877610489725048*^9, 3.877610534071742*^9}, {
   3.878874332865234*^9, 3.87887433996073*^9}},
 CellLabel->
  "In[102]:=",ExpressionUUID->"88bd3060-f377-457a-bceb-692cf38b9489"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Boundary terms:  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["C", 
    RowBox[{"(", "0", ")"}]], ".", "h\[Dagger]", "    "}]],ExpressionUUID->
  "b0a12e6b-fd02-4ee4-ba75-f497a92dfe6b"]
}], "Subsection",
 CellChangeTimes->{{3.8772544215115547`*^9, 3.877254594817128*^9}, {
   3.8772546397579603`*^9, 3.877254736628612*^9}, {3.877254828898815*^9, 
   3.877254858503283*^9}, {3.877254893935596*^9, 3.877254969309733*^9}, {
   3.8772556349718637`*^9, 3.877255642621972*^9}, {3.877318726777773*^9, 
   3.8773187673672943`*^9}, {3.877318847923456*^9, 3.877318853822648*^9}, {
   3.877319018645241*^9, 3.877319034465781*^9}, 3.8774100376345243`*^9, 
   3.8775094679641237`*^9, {3.877527287935897*^9, 3.877527291335002*^9}, 
   3.877533847734109*^9, {3.877585909480234*^9, 3.877585939537022*^9}, {
   3.8775859854171877`*^9, 3.877585985417226*^9}, {3.8776580275535717`*^9, 
   3.877658031192871*^9}},ExpressionUUID->"a0639427-0d7d-401b-afd2-\
06e150fb3d9c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"after", " ", "setting", " ", 
      RowBox[{"dYw", "[", "T", "]"}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{"h\[Dagger]", ".", " ", 
       RowBox[{
        SubscriptBox["\[Del]", "h"], 
        RowBox[{"Yw", "[", "T", "]"}]}]}], " ", "=", " ", "0"}]}], ",", " ", 
    RowBox[{
     RowBox[{"we", " ", "get", " ", 
      RowBox[{
       SuperscriptBox["C", 
        RowBox[{"(", "0", ")"}]], ".", "h\[Dagger]"}]}], " ", "=", " ", 
     RowBox[{"0", " ", "and", " ", 
      RowBox[{
       SuperscriptBox["C", 
        RowBox[{"(", "1", ")"}]], ".", "z"}], " ", "as"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"bcEnrTerm", " ", "=", " ", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"n0SS", "[", "T", "]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"zv", "[", "T", "]"}], "-", " ", 
             RowBox[{"T", " ", "\[Kappa]3", " ", 
              RowBox[{"zw", "[", "T", "]"}]}]}], ")"}]}], " ", "+", " ", 
          RowBox[{"2", " ", 
           RowBox[{"m0ST", "[", "T", "]"}], " ", 
           RowBox[{
            RowBox[{"zw", "'"}], "[", "T", "]"}]}]}], ")"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"zw", "->", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"zwSol", "[", "#", "]"}], "&"}], ")"}]}], ",", 
          RowBox[{"zv", "->", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"zvSol", "[", "#", "]"}], "&"}], ")"}]}], ",", 
          RowBox[{"zu", "->", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"zuSol", "[", "#", "]"}], "&"}], ")"}]}]}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"T", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "/", "2"}], ",", 
         RowBox[{"a", "/", "2"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "boundary", " ", "terms", " ", "given", " ", "in", " ", "the", " ", 
     "paper", " ", "in", " ", "Appendix", " ", "B"}], " ", "*)"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Eta]2", "[", 
     RowBox[{"\[Kappa]3b_", ",", " ", "\[Nu]_"}], "]"}], "=", 
    RowBox[{"4", "-", 
     RowBox[{"11", " ", "\[Nu]"}], "+", 
     FractionBox[
      SuperscriptBox["\[Kappa]3b", "4"], 
      RowBox[{"950400", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Nu]"}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[Kappa]3b", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"34", "+", 
         RowBox[{"67", " ", "\[Nu]"}]}], ")"}]}], 
      RowBox[{"1440", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Nu]"}], ")"}]}]]}]}], "\n", "\n", 
   RowBox[{"bcEnrTermPaper", " ", "=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "720"], " ", 
      SuperscriptBox["a", "5"], " ", "t", " ", "Y", " ", "\[Nu]", " ", 
      SuperscriptBox["\[Kappa]3", "2"], " ", "d\[Epsilon]"}], "+", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["a", "3"], " ", 
        SuperscriptBox["t", "3"], " ", "Y", "  ", "\[Kappa]3", " ", 
        "d\[Kappa]3"}], 
       RowBox[{"2520", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Nu]"}], ")"}]}]], 
      RowBox[{"\[Eta]2", "[", 
       RowBox[{
        FractionBox["\[Kappa]3", "ksExp"], ",", "\[Nu]"}], "]"}]}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Are", " ", "they", " ", 
     RowBox[{"equal", "?"}]}], " ", "*)"}], "\n", 
   RowBox[{"If", "[", 
    RowBox[{"doSanityCheck", ",", 
     RowBox[{"CheckSanity", "[", 
      RowBox[{
       RowBox[{"FullSimplify", "[", 
        RowBox[{"bcEnrTermPaper", " ", "-", " ", "bcEnrTerm"}], "]"}], "==", 
       "0"}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8772544215115547`*^9, 3.877254594817128*^9}, {
   3.8772546397579603`*^9, 3.877254736628612*^9}, {3.877254828898815*^9, 
   3.877254858503283*^9}, {3.877254893935596*^9, 3.877254969309733*^9}, {
   3.8772556349718637`*^9, 3.877255642621972*^9}, {3.877318726777773*^9, 
   3.8773187673672943`*^9}, {3.877318847923456*^9, 3.877318853822648*^9}, {
   3.877319018645241*^9, 3.877319034465781*^9}, 3.8774100376345243`*^9, 
   3.8775094679641237`*^9, {3.877527287935897*^9, 3.877527291335002*^9}, 
   3.877533847734109*^9, {3.877585909480234*^9, 3.877585916963833*^9}, {
   3.877585962091365*^9, 3.877586003164895*^9}, {3.8775959924078283`*^9, 
   3.877596022378145*^9}, {3.8776105535311604`*^9, 3.8776105724111147`*^9}, {
   3.878874324951501*^9, 3.87887434388518*^9}, {3.883995132568698*^9, 
   3.883995134549767*^9}},
 CellLabel->
  "In[106]:=",ExpressionUUID->"22010956-16f7-4acb-a900-db0f6623b8a5"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Evaluator->"SecondLocalKernal",
WindowSize->{1674, 1051},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
TaggingRules-><|"TryRealOnly" -> False|>,
FrontEndVersion->"13.0 for Mac OS X ARM (64-bit) (February 4, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"dfc1b587-c6ba-4d12-93c7-ea823e186151"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 328, 5, 98, "Title",ExpressionUUID->"53d258d3-0c79-4c56-bf9c-acfb8a337b01"],
Cell[911, 29, 357, 7, 53, "Subtitle",ExpressionUUID->"2be9cc51-2303-4271-bd31-bb099221a161"],
Cell[1271, 38, 3291, 62, 178, "Input",ExpressionUUID->"4ae26b98-82ac-453c-ab96-733b68fdfb9d"],
Cell[CellGroupData[{
Cell[4587, 104, 160, 3, 67, "Section",ExpressionUUID->"32431199-a326-4a3e-abe8-5140e93b4a9b"],
Cell[4750, 109, 651, 12, 73, "Input",ExpressionUUID->"39704aad-1bb9-4774-b24c-5696be7e7846"],
Cell[CellGroupData[{
Cell[5426, 125, 1282, 18, 54, "Subsection",ExpressionUUID->"8d694171-5145-43c1-8940-513913dba0bc"],
Cell[6711, 145, 2334, 45, 116, "Input",ExpressionUUID->"c41766af-6b46-43da-8ec5-d103a050a45c"],
Cell[9048, 192, 1990, 39, 30, "Input",ExpressionUUID->"52fff9ff-d929-42ec-a608-8e89fec2c0e5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11075, 236, 1545, 22, 54, "Subsection",ExpressionUUID->"df72384d-429e-46dc-8ea1-541080dd4b93"],
Cell[12623, 260, 2571, 54, 171, "Input",ExpressionUUID->"6696d940-da3d-4e7d-9c63-7ed7519fd1a7"],
Cell[15197, 316, 1269, 31, 124, "Input",ExpressionUUID->"9347657c-b617-424b-8ef2-27764f5d432f"],
Cell[16469, 349, 1150, 25, 87, "Input",ExpressionUUID->"5a15fdf2-5314-48d7-b173-ad9e70210ee5"],
Cell[17622, 376, 2205, 55, 161, "Input",ExpressionUUID->"d1d70a15-415b-411a-add3-932d1fe000e9"],
Cell[19830, 433, 2601, 71, 274, "Input",ExpressionUUID->"26e0bcd8-5d38-47be-b4bf-298130cce3c0"],
Cell[22434, 506, 1562, 35, 94, "Input",ExpressionUUID->"935759a6-2c84-49af-a612-72f5c8f890dd"],
Cell[23999, 543, 2329, 58, 157, "Input",ExpressionUUID->"0e181627-175c-4692-adcb-556f5c89c417"],
Cell[26331, 603, 4699, 103, 175, "Input",ExpressionUUID->"2bc7175c-bee0-487c-91c6-c315ac8741a3"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[31079, 712, 2309, 36, 68, "Section",ExpressionUUID->"d35ec7dd-91c4-4d43-aa49-1de38f793db1"],
Cell[33391, 750, 1684, 33, 76, "Input",ExpressionUUID->"9e839389-12fa-49d5-be51-9607281b2660"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35112, 788, 4358, 71, 72, "Section",ExpressionUUID->"8210c24d-24d5-4e23-8cbb-76ba0290b39e"],
Cell[39473, 861, 4959, 114, 218, "Input",ExpressionUUID->"da0f40de-596e-403c-be46-81257da1e2d7"],
Cell[44435, 977, 3377, 80, 152, "Input",ExpressionUUID->"a4d7ab47-70ad-4391-b38a-8ba96cfb794f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47849, 1062, 181, 3, 67, "Section",ExpressionUUID->"63b21f53-65db-4f25-9800-003d25d0b471"],
Cell[CellGroupData[{
Cell[48055, 1069, 572, 8, 54, "Subsection",ExpressionUUID->"c246f70a-db31-4765-b25f-dcedf73a6352"],
Cell[48630, 1079, 1351, 29, 52, "Input",ExpressionUUID->"c8bddfd3-cbdb-41a6-bd41-1c5a2eb8d318"],
Cell[49984, 1110, 1378, 38, 52, "Input",ExpressionUUID->"d21f47d6-285f-4c7b-b2c3-0cb9ae648818"],
Cell[51365, 1150, 747, 16, 52, "Input",ExpressionUUID->"3fb1818b-244d-4fef-833c-375dbb0c4734"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52149, 1171, 166, 3, 54, "Subsection",ExpressionUUID->"b5c6d873-0835-4505-9285-303524ed0556"],
Cell[52318, 1176, 1844, 38, 52, "Input",ExpressionUUID->"9791a7fb-964c-4687-b595-1cc6f7acc22e"],
Cell[54165, 1216, 5990, 163, 398, "Input",ExpressionUUID->"d652d441-50b1-4d10-9612-e8e7f23f83a1"],
Cell[60158, 1381, 2549, 55, 115, "Input",ExpressionUUID->"ae8926cd-4ad3-4242-8473-67e633857e07"],
Cell[62710, 1438, 1166, 16, 30, "Input",ExpressionUUID->"cb9b9e28-c149-4174-8d83-d32661636d63"],
Cell[63879, 1456, 2263, 44, 56, "Input",ExpressionUUID->"07b23b9b-58eb-48ed-a764-18cae13f6a1b"],
Cell[66145, 1502, 2272, 51, 134, "Input",ExpressionUUID->"f4837019-e190-49ff-857e-b1a011aa50f4"],
Cell[68420, 1555, 1824, 33, 55, "Input",ExpressionUUID->"8addf72c-9220-4bd1-aff1-c5f27cf27835"],
Cell[70247, 1590, 2019, 38, 30, "Input",ExpressionUUID->"a041d4d2-6491-4c4c-9c02-a694097a3560"],
Cell[72269, 1630, 3389, 85, 120, "Input",ExpressionUUID->"2fe3840e-93d2-4d76-8599-4fab340d5363"]
}, Open  ]],
Cell[CellGroupData[{
Cell[75695, 1720, 722, 10, 54, "Subsection",ExpressionUUID->"9b7feb6f-bab4-421b-991f-7e76ae3ff93f"],
Cell[76420, 1732, 5475, 146, 434, "Input",ExpressionUUID->"09673c67-0042-44ee-a0f5-468672b30a4d"],
Cell[81898, 1880, 2696, 64, 117, "Input",ExpressionUUID->"0fe2909e-1d14-4177-b189-c68e840bf172"],
Cell[84597, 1946, 3944, 94, 185, "Input",ExpressionUUID->"837f8e32-0d23-4373-a429-facf2e89876b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[88578, 2045, 1451, 20, 54, "Subsection",ExpressionUUID->"e82d03b9-a802-49f6-a587-7b8f42320a38"],
Cell[90032, 2067, 4184, 95, 157, "Input",ExpressionUUID->"3fe71d85-e432-4482-994c-ab0d3d50343b"],
Cell[94219, 2164, 15051, 421, 561, "Input",ExpressionUUID->"ada966a5-8458-4c7a-8736-8566ff92f6a0"],
Cell[109273, 2587, 3179, 74, 182, "Input",ExpressionUUID->"977acfca-08a0-40a2-bbb6-0b255ac86712"],
Cell[112455, 2663, 1414, 37, 52, "Input",ExpressionUUID->"a96f9314-4402-428b-b59e-ba09d15fab0f"],
Cell[113872, 2702, 2983, 78, 94, "Input",ExpressionUUID->"16101f47-4779-4df9-8c43-ff07b647826d"],
Cell[116858, 2782, 1282, 27, 58, "Input",ExpressionUUID->"86cfe238-3da7-4ba7-81d4-5082983444ec"],
Cell[118143, 2811, 1171, 25, 51, "Input",ExpressionUUID->"ba09ec37-6b5d-4efb-aefc-a725093241fc"],
Cell[119317, 2838, 3250, 79, 120, "Input",ExpressionUUID->"39e09131-9f13-44c7-a8b3-af42115f5508"]
}, Open  ]],
Cell[CellGroupData[{
Cell[122604, 2922, 580, 9, 54, "Subsection",ExpressionUUID->"44aa933a-4706-44e0-827e-bc2a6da323db"],
Cell[123187, 2933, 1626, 39, 102, "Input",ExpressionUUID->"6c3582a3-9548-4d56-82ab-672a39a66feb"],
Cell[124816, 2974, 783, 21, 34, "Input",ExpressionUUID->"46c52b0a-bea6-4a39-8f22-fbd2e2170bcd"],
Cell[125602, 2997, 2579, 64, 117, "Input",ExpressionUUID->"ae5b8f90-7207-48b9-bb1c-460d61b8c71d"],
Cell[128184, 3063, 3465, 89, 142, "Input",ExpressionUUID->"84029c10-9bc6-4bbf-80ed-aefdeebc6bad"],
Cell[131652, 3154, 4375, 126, 189, "Input",ExpressionUUID->"a66fcfd8-baee-4be7-a22c-895028c18445"],
Cell[136030, 3282, 5157, 133, 297, "Input",ExpressionUUID->"54ef0ba8-76f6-471d-afa1-78a774108640"]
}, Open  ]],
Cell[CellGroupData[{
Cell[141224, 3420, 642, 9, 54, "Subsection",ExpressionUUID->"b62bac85-2529-402e-bb5b-15b1d3f1d1a9"],
Cell[141869, 3431, 5740, 155, 250, "Input",ExpressionUUID->"78494090-3cf6-41c2-9295-4ff9b5f78a1f"],
Cell[147612, 3588, 8166, 202, 318, "Input",ExpressionUUID->"359acb86-63d8-40f0-bd9f-ec0b04696b5a"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[155827, 3796, 208, 4, 67, "Section",ExpressionUUID->"256cf7c2-6169-43cf-b481-eb534d4fa0e8"],
Cell[CellGroupData[{
Cell[156060, 3804, 2929, 50, 59, "Subsection",ExpressionUUID->"7439b397-073e-4632-adc8-45cdb644750a"],
Cell[158992, 3856, 1945, 49, 77, "Input",ExpressionUUID->"db2e654c-4ca5-4652-a524-6ebe8589e500"],
Cell[160940, 3907, 1001, 26, 52, "Input",ExpressionUUID->"e654cef1-ae81-4267-bab7-ce15a7866e77"]
}, Open  ]],
Cell[CellGroupData[{
Cell[161978, 3938, 1214, 24, 59, "Subsection",ExpressionUUID->"803fd1ba-efe9-4b57-abe9-b89c9d55f473"],
Cell[163195, 3964, 3517, 78, 175, "Input",ExpressionUUID->"6a5a0cea-a1b1-4cdb-b3e9-715bff6ff180"]
}, Open  ]],
Cell[CellGroupData[{
Cell[166749, 4047, 2074, 43, 59, "Subsection",ExpressionUUID->"706099d1-e28d-44a0-8382-4fc0cbcc39d7"],
Cell[168826, 4092, 3702, 97, 239, "Input",ExpressionUUID->"88bd3060-f377-457a-bceb-692cf38b9489"]
}, Open  ]],
Cell[CellGroupData[{
Cell[172565, 4194, 970, 18, 54, "Subsection",ExpressionUUID->"a0639427-0d7d-401b-afd2-06e150fb3d9c"],
Cell[173538, 4214, 4845, 127, 231, "Input",ExpressionUUID->"22010956-16f7-4acb-a900-db0f6623b8a5"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

